Class: MetronomeSDK::Models::CommitSpecifierInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::CommitSpecifierInput
- Defined in:
- lib/metronome_sdk/models/commit_specifier_input.rb
Instance Attribute Summary collapse
-
#presentation_group_values ⇒ Hash{Symbol=>String}?
If provided, the specifier will apply to product usage with these set of presentation group values.
-
#pricing_group_values ⇒ Hash{Symbol=>String}?
If provided, the specifier will apply to product usage with these set of pricing group values.
-
#product_id ⇒ String?
If provided, the specifier will only apply to the product with the specified ID.
-
#product_tags ⇒ Array<String>?
If provided, the specifier will only apply to products with all the specified tags.
Instance Method Summary collapse
-
#initialize(presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CommitSpecifierInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::CommitSpecifierInput for more details.
|
|
# File 'lib/metronome_sdk/models/commit_specifier_input.rb', line 33
|
Instance Attribute Details
#presentation_group_values ⇒ Hash{Symbol=>String}?
If provided, the specifier will apply to product usage with these set of presentation group values.
11 |
# File 'lib/metronome_sdk/models/commit_specifier_input.rb', line 11 optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#pricing_group_values ⇒ Hash{Symbol=>String}?
If provided, the specifier will apply to product usage with these set of pricing group values.
18 |
# File 'lib/metronome_sdk/models/commit_specifier_input.rb', line 18 optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#product_id ⇒ String?
If provided, the specifier will only apply to the product with the specified ID.
24 |
# File 'lib/metronome_sdk/models/commit_specifier_input.rb', line 24 optional :product_id, String |
#product_tags ⇒ Array<String>?
If provided, the specifier will only apply to products with all the specified tags.
31 |
# File 'lib/metronome_sdk/models/commit_specifier_input.rb', line 31 optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |