Class: MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration
- Defined in:
- lib/metronome_sdk/models/contract.rb,
sig/metronome_sdk/models/contract.rbs
Overview
Defined Under Namespace
Modules: BillingProvider, DeliveryMethod
Instance Attribute Summary collapse
- #archived_at ⇒ Time?
-
#billing_provider ⇒ Symbol, MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
-
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider.
- #customer_id ⇒ String
-
#delivery_method ⇒ Symbol, MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
-
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method.
-
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
-
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerBillingProviderConfiguration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/contract.rb', line 370
|
Instance Attribute Details
#archived_at ⇒ Time?
328 |
# File 'lib/metronome_sdk/models/contract.rb', line 328 required :archived_at, Time, nil?: true |
#billing_provider ⇒ Symbol, MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
334 335 |
# File 'lib/metronome_sdk/models/contract.rb', line 334 required :billing_provider, enum: -> { MetronomeSDK::Contract::CustomerBillingProviderConfiguration::BillingProvider } |
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider. The structure of this object is specific to the billing provider.
342 |
# File 'lib/metronome_sdk/models/contract.rb', line 342 required :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#customer_id ⇒ String
347 |
# File 'lib/metronome_sdk/models/contract.rb', line 347 required :customer_id, String |
#delivery_method ⇒ Symbol, MetronomeSDK::Models::Contract::CustomerBillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
353 354 |
# File 'lib/metronome_sdk/models/contract.rb', line 353 required :delivery_method, enum: -> { MetronomeSDK::Contract::CustomerBillingProviderConfiguration::DeliveryMethod } |
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method. The structure of this object is specific to the delivery method.
361 362 |
# File 'lib/metronome_sdk/models/contract.rb', line 361 required :delivery_method_configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
368 |
# File 'lib/metronome_sdk/models/contract.rb', line 368 required :delivery_method_id, String |
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
323 |
# File 'lib/metronome_sdk/models/contract.rb', line 323 required :id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/contract.rb', line 407
|
Instance Method Details
#to_hash ⇒ {
356 |
# File 'sig/metronome_sdk/models/contract.rbs', line 356
def to_hash: -> {
|