Class: MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Defined Under Namespace
Classes: BillingProviderConfiguration
Instance Attribute Summary collapse
- #billing_provider_configuration ⇒ MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration
-
#effective_at ⇒ Time
The date this billing provider configuration became or becomes active.
-
#effective_until ⇒ Time?
The date this billing provider configuration is superseded by the next entry.
Instance Method Summary collapse
-
#initialize(billing_provider_configuration:, effective_at:, effective_until: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingProviderConfigurationSchedule for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_provider_configuration:, effective_at:, effective_until: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1702
|
Instance Attribute Details
#billing_provider_configuration ⇒ MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration
1686 1687 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1686 required :billing_provider_configuration, -> { MetronomeSDK::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration } |
#effective_at ⇒ Time
The date this billing provider configuration became or becomes active.
1693 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1693 required :effective_at, Time |
#effective_until ⇒ Time?
The date this billing provider configuration is superseded by the next entry. Null for the last entry in the schedule.
1700 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1700 optional :effective_until, Time |
Instance Method Details
#to_hash ⇒ {
1727 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 1727
def to_hash: -> {
|