Class: MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Overview
Defined Under Namespace
Modules: BillingProvider, DeliveryMethod
Instance Attribute Summary collapse
- #archived_at ⇒ Time?
-
#billing_provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
-
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider.
- #customer_id ⇒ String
-
#delivery_method ⇒ Symbol, MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
-
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method.
-
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
-
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingProviderConfiguration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1767
|
Instance Attribute Details
#archived_at ⇒ Time?
1725 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1725 required :archived_at, Time, nil?: true |
#billing_provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
1731 1732 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1731 required :billing_provider, enum: -> { MetronomeSDK::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::BillingProvider } |
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider. The structure of this object is specific to the billing provider.
1739 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1739 required :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#customer_id ⇒ String
1744 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1744 required :customer_id, String |
#delivery_method ⇒ Symbol, MetronomeSDK::Models::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
1750 1751 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1750 required :delivery_method, enum: -> { MetronomeSDK::ContractV2::BillingProviderConfigurationSchedule::BillingProviderConfiguration::DeliveryMethod } |
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method. The structure of this object is specific to the delivery method.
1758 1759 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1758 required :delivery_method_configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
1765 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1765 required :delivery_method_id, String |
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
1720 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1720 required :id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1804
|
Instance Method Details
#to_hash ⇒ {
1773 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 1773
def to_hash: -> {
|