Class: MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Overview
Defined Under Namespace
Modules: BillingProvider, DeliveryMethod
Instance Attribute Summary collapse
- #archived_at ⇒ Time?
-
#billing_provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
-
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider.
- #customer_id ⇒ String
-
#delivery_method ⇒ Symbol, MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
-
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method.
-
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
-
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerBillingProviderConfiguration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, billing_provider:, configuration:, customer_id:, delivery_method:, delivery_method_configuration:, delivery_method_id:) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2508
|
Instance Attribute Details
#archived_at ⇒ Time?
2466 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2466 required :archived_at, Time, nil?: true |
#billing_provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration::BillingProvider
The billing provider set for this configuration.
2472 2473 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2472 required :billing_provider, enum: -> { MetronomeSDK::ContractV2::CustomerBillingProviderConfiguration::BillingProvider } |
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the billing provider. The structure of this object is specific to the billing provider.
2480 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2480 required :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#customer_id ⇒ String
2485 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2485 required :customer_id, String |
#delivery_method ⇒ Symbol, MetronomeSDK::Models::ContractV2::CustomerBillingProviderConfiguration::DeliveryMethod
The method to use for delivering invoices to this customer.
2491 2492 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2491 required :delivery_method, enum: -> { MetronomeSDK::ContractV2::CustomerBillingProviderConfiguration::DeliveryMethod } |
#delivery_method_configuration ⇒ Hash{Symbol=>Object}
Configuration for the delivery method. The structure of this object is specific to the delivery method.
2499 2500 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2499 required :delivery_method_configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#delivery_method_id ⇒ String
ID of the delivery method to use for this customer.
2506 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2506 required :delivery_method_id, String |
#id ⇒ String
ID of this configuration; can be provided as the billing_provider_configuration_id when creating a contract.
2461 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2461 required :id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2545
|
Instance Method Details
#to_hash ⇒ {
2492 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 2492
def to_hash: -> {
|