Class: MetronomeSDK::Models::ContractV2::RecurringCredit::CommitDuration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::RecurringCredit::CommitDuration
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Overview
Defined Under Namespace
Modules: Unit
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(value:, unit: nil) ⇒ Object
constructor
The amount of time the created commits will be valid for.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:, unit: nil) ⇒ Object
The amount of time the created commits will be valid for
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3462
|
Instance Attribute Details
#unit ⇒ Symbol, ...
3460 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3460 optional :unit, enum: -> { MetronomeSDK::ContractV2::RecurringCredit::CommitDuration::Unit } |
#value ⇒ Float
3455 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3455 required :value, Float |
Instance Method Details
#to_hash ⇒ {
3323 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 3323
def to_hash: -> {
|