Class: MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Defined Under Namespace
Classes: RevenueSystemConfiguration
Instance Attribute Summary collapse
-
#effective_at ⇒ Time
The date this revenue system configuration became or becomes active.
-
#effective_until ⇒ Time?
The date this revenue system configuration is superseded by the next entry.
- #revenue_system_configuration ⇒ MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration?
Instance Method Summary collapse
-
#initialize(effective_at:, revenue_system_configuration:, effective_until: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RevenueSystemConfigurationSchedule for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effective_at:, revenue_system_configuration:, effective_until: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3770
|
Instance Attribute Details
#effective_at ⇒ Time
The date this revenue system configuration became or becomes active.
3752 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3752 required :effective_at, Time |
#effective_until ⇒ Time?
The date this revenue system configuration is superseded by the next entry. Null for the last entry in the schedule.
3768 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3768 optional :effective_until, Time |
#revenue_system_configuration ⇒ MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration?
3757 3758 3759 3760 3761 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3757 required :revenue_system_configuration, -> { MetronomeSDK::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration }, nil?: true |
Instance Method Details
#to_hash ⇒ {
3627 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 3627
def to_hash: -> {
|