Class: MetronomeSDK::Models::ContractV2::Subscription::BillingCycleConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::Subscription::BillingCycleConfig
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Overview
Defined Under Namespace
Modules: InvoicePlacement
Instance Attribute Summary collapse
-
#anchor_date ⇒ Time
The date this subscription's billing cycle is anchored to.
-
#invoice_placement ⇒ Symbol, MetronomeSDK::Models::ContractV2::Subscription::BillingCycleConfig::InvoicePlacement
Controls whether this subscription consolidates onto usage invoices or gets its own scheduled invoice.
Instance Method Summary collapse
-
#initialize(anchor_date:, invoice_placement:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingCycleConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anchor_date:, invoice_placement:) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::Subscription::BillingCycleConfig for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 4409
|
Instance Attribute Details
#anchor_date ⇒ Time
The date this subscription's billing cycle is anchored to.
4399 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 4399 required :anchor_date, Time |
#invoice_placement ⇒ Symbol, MetronomeSDK::Models::ContractV2::Subscription::BillingCycleConfig::InvoicePlacement
Controls whether this subscription consolidates onto usage invoices or gets its own scheduled invoice.
4406 4407 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 4406 required :invoice_placement, enum: -> { MetronomeSDK::ContractV2::Subscription::BillingCycleConfig::InvoicePlacement } |
Instance Method Details
#to_hash ⇒ {
4232 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 4232
def to_hash: -> {
|