Module: MetronomeSDK::Models::ContractWithoutAmendments::ScheduledChargesOnUsageInvoices

Extended by:
Internal::Type::Enum
Defined in:
lib/metronome_sdk/models/contract_without_amendments.rb,
sig/metronome_sdk/models/contract_without_amendments.rbs

Overview

Determines which scheduled and commit charges to consolidate onto the Contract's usage invoice. The charge's timestamp must match the usage invoice's ending_before date for consolidation to occur. This field cannot be modified after a Contract has been created. If this field is omitted, charges will appear on a separate invoice from usage charges.

See Also:

  • MetronomeSDK::Models::ContractWithoutAmendments#scheduled_charges_on_usage_invoices

Constant Summary collapse

ALL =

Returns:

  • (:ALL)
:ALL

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[MetronomeSDK::Models::ContractWithoutAmendments::scheduled_charges_on_usage_invoices]

Returns:

  • (::Array[MetronomeSDK::Models::ContractWithoutAmendments::scheduled_charges_on_usage_invoices])


1138
# File 'sig/metronome_sdk/models/contract_without_amendments.rbs', line 1138

def self?.values: -> ::Array[MetronomeSDK::Models::ContractWithoutAmendments::scheduled_charges_on_usage_invoices]