Module: MetronomeSDK::Models::PaymentGateConfig::PaymentGateType

Extended by:
Internal::Type::Enum
Defined in:
lib/metronome_sdk/models/payment_gate_config.rb,
sig/metronome_sdk/models/payment_gate_config.rbs

Overview

Gate access to the commit balance based on successful collection of payment. Select STRIPE for Metronome to facilitate payment via Stripe. Select EXTERNAL to facilitate payment using your own payment integration. Select NONE if you do not wish to payment gate the commit balance.

See Also:

  • MetronomeSDK::Models::PaymentGateConfig#payment_gate_type

Constant Summary collapse

NONE =

Returns:

  • (:NONE)
:NONE
STRIPE =

Returns:

  • (:STRIPE)
:STRIPE
EXTERNAL =

Returns:

  • (:EXTERNAL)
:EXTERNAL

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[MetronomeSDK::Models::PaymentGateConfig::payment_gate_type]

Returns:

  • (::Array[MetronomeSDK::Models::PaymentGateConfig::payment_gate_type])


55
# File 'sig/metronome_sdk/models/payment_gate_config.rbs', line 55

def self?.values: -> ::Array[MetronomeSDK::Models::PaymentGateConfig::payment_gate_type]