Class: MetronomeSDK::Models::PaymentGateConfig::PrecalculatedTaxConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/payment_gate_config.rb,
sig/metronome_sdk/models/payment_gate_config.rbs

Overview

See Also:

  • MetronomeSDK::Models::PaymentGateConfig#precalculated_tax_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializePrecalculatedTaxConfig

Returns a new instance of PrecalculatedTaxConfig.

Parameters:

  • tax_amount: (Float)
  • tax_name: (String)


67
# File 'sig/metronome_sdk/models/payment_gate_config.rbs', line 67

def initialize: (tax_amount: Float, ?tax_name: String) -> void

Instance Attribute Details

#tax_amountFloat

Amount of tax to be applied. This should be in the same currency and denomination as the commit's invoice schedule

Parameters:

  • value (Float)

Returns:

  • (Float)


71
# File 'lib/metronome_sdk/models/payment_gate_config.rb', line 71

required :tax_amount, Float

#tax_nameString?

Name of the tax to be applied. This may be used in an invoice line item description.

Parameters:

  • (String)

Returns:

  • (String, nil)


78
# File 'lib/metronome_sdk/models/payment_gate_config.rb', line 78

optional :tax_name, String

Instance Method Details

#to_hash{ tax_amount: Float, tax_name: String }

Returns:

  • ({ tax_amount: Float, tax_name: String })


69
# File 'sig/metronome_sdk/models/payment_gate_config.rbs', line 69

def to_hash: -> { tax_amount: Float, tax_name: String }