Module: MetronomeSDK::Models::PaymentGateConfigV2::PaymentGateType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/metronome_sdk/models/payment_gate_config_v2.rb,
sig/metronome_sdk/models/payment_gate_config_v2.rbs
Overview
Gate access to the commit balance based on successful collection of payment. Select STRIPE for Metronome to facilitate payment via Stripe. Select EXTERNAL to facilitate payment using your own payment integration. Select NONE if you do not wish to payment gate the commit balance.
Constant Summary collapse
- NONE =
:NONE- STRIPE =
:STRIPE- EXTERNAL =
:EXTERNAL
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[MetronomeSDK::Models::PaymentGateConfigV2::payment_gate_type]
55 |
# File 'sig/metronome_sdk/models/payment_gate_config_v2.rbs', line 55
def self?.values: -> ::Array[MetronomeSDK::Models::PaymentGateConfigV2::payment_gate_type]
|