Class: MetronomeSDK::Models::PaymentGateConfigV2::PrecalculatedTaxConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::PaymentGateConfigV2::PrecalculatedTaxConfig
- Defined in:
- lib/metronome_sdk/models/payment_gate_config_v2.rb,
sig/metronome_sdk/models/payment_gate_config_v2.rbs
Overview
Instance Attribute Summary collapse
-
#tax_amount ⇒ Float
Amount of tax to be applied.
-
#tax_name ⇒ String?
Name of the tax to be applied.
Instance Method Summary collapse
-
#initialize ⇒ PrecalculatedTaxConfig
constructor
A new instance of PrecalculatedTaxConfig.
- #to_hash ⇒ { tax_amount: Float, tax_name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ PrecalculatedTaxConfig
Returns a new instance of PrecalculatedTaxConfig.
67 |
# File 'sig/metronome_sdk/models/payment_gate_config_v2.rbs', line 67
def initialize: (tax_amount: Float, ?tax_name: String) -> void
|
Instance Attribute Details
#tax_amount ⇒ Float
Amount of tax to be applied. This should be in the same currency and denomination as the commit's invoice schedule
71 |
# File 'lib/metronome_sdk/models/payment_gate_config_v2.rb', line 71 required :tax_amount, Float |
#tax_name ⇒ String?
Name of the tax to be applied. This may be used in an invoice line item description.
78 |
# File 'lib/metronome_sdk/models/payment_gate_config_v2.rb', line 78 optional :tax_name, String |
Instance Method Details
#to_hash ⇒ { tax_amount: Float, tax_name: String }
69 |
# File 'sig/metronome_sdk/models/payment_gate_config_v2.rbs', line 69
def to_hash: -> { tax_amount: Float, tax_name: String }
|