Class: MetronomeSDK::Models::PrepaidBalanceThresholdConfiguration::Commit

Inherits:
BaseThresholdCommit show all
Defined in:
lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb,
sig/metronome_sdk/models/prepaid_balance_threshold_configuration.rbs

Overview

See Also:

  • MetronomeSDK::Models::PrepaidBalanceThresholdConfiguration#commit

Instance Attribute Summary collapse

Attributes inherited from BaseThresholdCommit

#description, #name, #priority, #product_id

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



86
# File 'sig/metronome_sdk/models/prepaid_balance_threshold_configuration.rbs', line 86

def initialize: (

Instance Attribute Details

#applicable_product_idsArray<String>?

Which products the threshold commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.

Parameters:

  • _ (::Array[String])

Returns:

  • (Array<String>, nil)


86
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 86

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#applicable_product_tagsArray<String>?

Which tags the threshold commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.

Parameters:

  • _ (::Array[String])

Returns:

  • (Array<String>, nil)


94
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 94

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#specifiersArray<MetronomeSDK::Models::CommitSpecifierInput>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer's usage needs to meet the condition of at least one of the specifiers to contribute to a commit's or credit's drawdown. This field cannot be used together with applicable_product_ids or applicable_product_tags.



103
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 103

optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }

Instance Method Details

#to_hash{

Returns:

  • ({)


92
# File 'sig/metronome_sdk/models/prepaid_balance_threshold_configuration.rbs', line 92

def to_hash: -> {