Class: MetronomeSDK::Models::SpendThresholdConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::SpendThresholdConfiguration
- Defined in:
- lib/metronome_sdk/models/spend_threshold_configuration.rb
Defined Under Namespace
Classes: DiscountConfiguration
Instance Attribute Summary collapse
- #commit ⇒ MetronomeSDK::Models::BaseThresholdCommit
- #discount_configuration ⇒ MetronomeSDK::Models::SpendThresholdConfiguration::DiscountConfiguration?
-
#is_enabled ⇒ Boolean
When set to false, the contract will not be evaluated against the threshold_amount.
- #payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfig
-
#threshold_amount ⇒ Float
Specify the threshold amount for the contract.
Instance Method Summary collapse
-
#initialize(commit:, is_enabled:, payment_gate_config:, threshold_amount:, discount_configuration: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SpendThresholdConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(commit:, is_enabled:, payment_gate_config:, threshold_amount:, discount_configuration: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::SpendThresholdConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 36
|
Instance Attribute Details
#commit ⇒ MetronomeSDK::Models::BaseThresholdCommit
9 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 9 required :commit, -> { MetronomeSDK::BaseThresholdCommit } |
#discount_configuration ⇒ MetronomeSDK::Models::SpendThresholdConfiguration::DiscountConfiguration?
34 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 34 optional :discount_configuration, -> { MetronomeSDK::SpendThresholdConfiguration::DiscountConfiguration } |
#is_enabled ⇒ Boolean
When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.
17 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 17 required :is_enabled, MetronomeSDK::Internal::Type::Boolean |
#payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfig
22 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 22 required :payment_gate_config, -> { MetronomeSDK::PaymentGateConfig } |
#threshold_amount ⇒ Float
Specify the threshold amount for the contract. Each time the contract’s usage hits this amount, a threshold charge will be initiated.
29 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 29 required :threshold_amount, Float |