Class: MetronomeSDK::Models::SpendThresholdConfiguration::DiscountConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/spend_threshold_configuration.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(payment_fraction:) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::SpendThresholdConfiguration::DiscountConfiguration for more details.

Parameters:

  • payment_fraction (Float)

    The fraction of the original amount that the customer pays after applying the di



# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 60

Instance Attribute Details

#payment_fractionFloat

The fraction of the original amount that the customer pays after applying the discount. For example, 0.85 means the customer pays 85% of the original amount (a 15% discount).

Returns:

  • (Float)


58
# File 'lib/metronome_sdk/models/spend_threshold_configuration.rb', line 58

required :payment_fraction, Float