Class: MetronomeSDK::Models::Subscription::SeatConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/subscription.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(seat_group_key:) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::Subscription::SeatConfig for more details.

Parameters:

  • seat_group_key (String)

    The property name, sent on usage events, that identifies the seat ID associated



# File 'lib/metronome_sdk/models/subscription.rb', line 340

Instance Attribute Details

#seat_group_keyString

The property name, sent on usage events, that identifies the seat ID associated with the usage event. For example, the property name might be seat_id or user_id. The property must be set as a group key on billable metrics and a presentation/pricing group key on contract products. This allows linked recurring credits with an allocation per seat to be consumed by only one seat’s usage.

Returns:

  • (String)


338
# File 'lib/metronome_sdk/models/subscription.rb', line 338

required :seat_group_key, String