Class: MetronomeSDK::Models::V1::ContractAddManualBalanceEntryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractAddManualBalanceEntryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
Amount to add to the segment.
-
#contract_id ⇒ String?
ID of the contract to update.
-
#customer_id ⇒ String
ID of the customer whose balance is to be updated.
-
#id ⇒ String
ID of the balance (commit or credit) to update.
-
#per_group_amounts ⇒ Hash{Symbol=>Float}?
If using individually configured commits/credits attached to seat managed subscriptions, the amount to add for each seat.
-
#reason ⇒ String
Reason for the manual adjustment.
-
#segment_id ⇒ String
ID of the segment to update.
-
#timestamp ⇒ Time?
RFC 3339 timestamp indicating when the manual adjustment takes place.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, amount:, customer_id:, reason:, segment_id:, contract_id: nil, per_group_amounts: nil, timestamp: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContractAddManualBalanceEntryParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, customer_id:, reason:, segment_id:, contract_id: nil, per_group_amounts: nil, timestamp: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAddManualBalanceEntryParams for more details.
|
|
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 61
|
Instance Attribute Details
#amount ⇒ Float
Amount to add to the segment. A negative number will draw down from the balance.
21 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 21 required :amount, Float |
#contract_id ⇒ String?
ID of the contract to update. Leave blank to update a customer level balance.
45 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 45 optional :contract_id, String |
#customer_id ⇒ String
ID of the customer whose balance is to be updated.
27 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 27 required :customer_id, String |
#id ⇒ String
ID of the balance (commit or credit) to update.
15 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 15 required :id, String |
#per_group_amounts ⇒ Hash{Symbol=>Float}?
If using individually configured commits/credits attached to seat managed subscriptions, the amount to add for each seat. Must sum to total amount.
52 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 52 optional :per_group_amounts, MetronomeSDK::Internal::Type::HashOf[Float] |
#reason ⇒ String
Reason for the manual adjustment. This will be displayed in the ledger.
33 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 33 required :reason, String |
#segment_id ⇒ String
ID of the segment to update.
39 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 39 required :segment_id, String |
#timestamp ⇒ Time?
RFC 3339 timestamp indicating when the manual adjustment takes place. If not provided, it will default to the start of the segment.
59 |
# File 'lib/metronome_sdk/models/v1/contract_add_manual_balance_entry_params.rb', line 59 optional :timestamp, Time |