Class: MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_amend_params.rb,
sig/metronome_sdk/models/v1/contract_amend_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge#schedule

Defined Under Namespace

Classes: RecurringSchedule, ScheduleItem

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_type_id: nil, do_not_invoice: nil, recurring_schedule: nil, schedule_items: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule for more details.

Must provide either schedule_items or recurring_schedule.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1593

Instance Attribute Details

#credit_type_idString?

Defaults to USD (cents) if not passed.

Parameters:

  • (String)

Returns:

  • (String, nil)


1568
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1568

optional :credit_type_id, String

#do_not_invoiceBoolean?

This field is only applicable to commit invoice schedules. If true, this schedule will not generate an invoice.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1575
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1575

optional :do_not_invoice, MetronomeSDK::Internal::Type::Boolean

#recurring_scheduleMetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule?

Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.



1583
1584
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1583

optional :recurring_schedule,
-> { MetronomeSDK::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule }

#schedule_itemsArray<MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::ScheduleItem>?

Either provide amount or provide both unit_price and quantity.



1590
1591
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1590

optional :schedule_items,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::ContractAmendParams::ScheduledCharge::Schedule::ScheduleItem] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1702

Instance Method Details

#to_hash{

Returns:

  • ({)


1473
# File 'sig/metronome_sdk/models/v1/contract_amend_params.rbs', line 1473

def to_hash: -> {