Class: MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v1/contract_amend_params.rb,
sig/metronome_sdk/models/v1/contract_amend_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule#recurring_schedule

Defined Under Namespace

Modules: AmountDistribution, Frequency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule for more details.

Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1658

Instance Attribute Details

#amountFloat?

Amount for the charge. Can be provided instead of unit_price and quantity. If amount is sent, the unit_price is assumed to be the amount and quantity is inferred to be 1.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1640
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1640

optional :amount, Float

#amount_distributionSymbol, MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::AmountDistribution

Parameters:

  • value (MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::amount_distribution)

Returns:



1613
1614
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1613

required :amount_distribution,
enum: -> { MetronomeSDK::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::AmountDistribution }

#ending_beforeTime

RFC 3339 timestamp (exclusive).

Parameters:

  • value (Time)

Returns:

  • (Time)


1620
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1620

required :ending_before, Time

#frequencySymbol, MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::Frequency

Parameters:

  • value (MetronomeSDK::Models::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::frequency)

Returns:



1625
1626
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1625

required :frequency,
enum: -> { MetronomeSDK::V1::ContractAmendParams::ScheduledCharge::Schedule::RecurringSchedule::Frequency }

#quantityFloat?

Quantity for the charge. Will be multiplied by unit_price to determine the amount and must be specified with unit_price. If specified amount cannot be provided.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1648
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1648

optional :quantity, Float

#starting_atTime

RFC 3339 timestamp (inclusive).

Parameters:

  • value (Time)

Returns:

  • (Time)


1632
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1632

required :starting_at, Time

#unit_priceFloat?

Unit price for the charge. Will be multiplied by quantity to determine the amount and must be specified with quantity. If specified amount cannot be provided.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1656
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1656

optional :unit_price, Float

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1689

Instance Method Details

#to_hash{

Returns:

  • ({)


1522
# File 'sig/metronome_sdk/models/v1/contract_amend_params.rbs', line 1522

def to_hash: -> {