Class: MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig
- Defined in:
- lib/metronome_sdk/models/v1/contract_create_params.rb
Overview
Defined Under Namespace
Modules: PaymentGateType, TaxType Classes: PrecalculatedTaxConfig, StripeConfig
Instance Attribute Summary collapse
-
#payment_gate_type ⇒ Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::PaymentGateType
Gate access to the commit balance based on successful collection of payment.
-
#precalculated_tax_config ⇒ MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::PrecalculatedTaxConfig?
Only applicable if using PRECALCULATED as your tax type.
-
#stripe_config ⇒ MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::StripeConfig?
Only applicable if using STRIPE as your payment gate type.
-
#tax_type ⇒ Symbol, ...
Stripe tax is only supported for Stripe payment gateway.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(tax_amount:, tax_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PrecalculatedTaxConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tax_amount:, tax_name: nil) ⇒ Object
Some parameter documentations has been truncated, see PrecalculatedTaxConfig for more details.
Only applicable if using PRECALCULATED as your tax type.
|
|
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 824
|
Instance Attribute Details
#payment_gate_type ⇒ Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::PaymentGateType
Gate access to the commit balance based on successful collection of payment. Select STRIPE for Metronome to facilitate payment via Stripe. Select EXTERNAL to facilitate payment using your own payment integration. Select NONE if you do not wish to payment gate the commit balance.
798 799 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 798 required :payment_gate_type, enum: -> { MetronomeSDK::V1::ContractCreateParams::Commit::PaymentGateConfig::PaymentGateType } |
#precalculated_tax_config ⇒ MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::PrecalculatedTaxConfig?
Only applicable if using PRECALCULATED as your tax type.
805 806 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 805 optional :precalculated_tax_config, -> { MetronomeSDK::V1::ContractCreateParams::Commit::PaymentGateConfig::PrecalculatedTaxConfig } |
#stripe_config ⇒ MetronomeSDK::Models::V1::ContractCreateParams::Commit::PaymentGateConfig::StripeConfig?
Only applicable if using STRIPE as your payment gate type.
812 813 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 812 optional :stripe_config, -> { MetronomeSDK::V1::ContractCreateParams::Commit::PaymentGateConfig::StripeConfig } |
#tax_type ⇒ Symbol, ...
Stripe tax is only supported for Stripe payment gateway. Select NONE if you do not wish Metronome to calculate tax on your behalf. Leaving this field blank will default to NONE.
821 822 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 821 optional :tax_type, enum: -> { MetronomeSDK::V1::ContractCreateParams::Commit::PaymentGateConfig::TaxType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 852
|