Class: MetronomeSDK::Models::V1::ContractCreateParams::Commit::SpendTrackerAttributes
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractCreateParams::Commit::SpendTrackerAttributes
- Defined in:
- lib/metronome_sdk/models/v1/contract_create_params.rb,
sig/metronome_sdk/models/v1/contract_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#counts_as_discounted ⇒ Boolean
If true, this commit will be included in spend trackers with discounted set to DISCOUNTED_ONLY.
Instance Method Summary collapse
-
#initialize ⇒ SpendTrackerAttributes
constructor
A new instance of SpendTrackerAttributes.
- #to_hash ⇒ { counts_as_discounted: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ SpendTrackerAttributes
Returns a new instance of SpendTrackerAttributes.
753 |
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 753
def initialize: (counts_as_discounted: bool) -> void
|
Instance Attribute Details
#counts_as_discounted ⇒ Boolean
If true, this commit will be included in spend trackers with discounted set to DISCOUNTED_ONLY
818 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 818 required :counts_as_discounted, MetronomeSDK::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { counts_as_discounted: bool }
755 |
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 755
def to_hash: -> { counts_as_discounted: bool }
|