Class: MetronomeSDK::Models::V1::ContractCreateParams::RecurringCommit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb

Defined Under Namespace

Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, InvoiceAmount, SubscriptionConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object

The amount the customer should be billed for the commit. Not required.

Parameters:

  • credit_type_id (String)
  • quantity (Float)
  • unit_price (Float)


# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1892

Instance Attribute Details

#access_amountMetronomeSDK::Models::V1::ContractCreateParams::RecurringCommit::AccessAmount

The amount of commit to grant.



1762
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1762

required :access_amount, -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::AccessAmount }

#applicable_product_idsArray<String>?

Will be passed down to the individual commits

Returns:

  • (Array<String>, nil)


1793
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1793

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#applicable_product_tagsArray<String>?

Will be passed down to the individual commits

Returns:

  • (Array<String>, nil)


1799
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1799

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#commit_durationMetronomeSDK::Models::V1::ContractCreateParams::RecurringCommit::CommitDuration

Defines the length of the access schedule for each created commit/credit. The value represents the number of units. Unit defaults to “PERIODS”, where the length of a period is determined by the recurrence_frequency.



1770
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1770

required :commit_duration, -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::CommitDuration }

#descriptionString?

Will be passed down to the individual commits

Returns:

  • (String, nil)


1805
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1805

optional :description, String

#ending_beforeTime?

Determines when the contract will stop creating recurring commits. optional

Returns:

  • (Time, nil)


1811
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1811

optional :ending_before, Time

#hierarchy_configurationMetronomeSDK::Models::CommitHierarchyConfiguration?

Optional configuration for recurring commit/credit hierarchy access control



1817
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1817

optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration }

#invoice_amountMetronomeSDK::Models::V1::ContractCreateParams::RecurringCommit::InvoiceAmount?

The amount the customer should be billed for the commit. Not required.



1823
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1823

optional :invoice_amount, -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::InvoiceAmount }

#nameString?

displayed on invoices. will be passed through to the individual commits

Returns:

  • (String, nil)


1829
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1829

optional :name, String

#netsuite_sales_order_idString?

Will be passed down to the individual commits

Returns:

  • (String, nil)


1835
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1835

optional :netsuite_sales_order_id, String

#priorityFloat

Will be passed down to the individual commits

Returns:

  • (Float)


1776
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1776

required :priority, Float

#product_idString

Returns:

  • (String)


1781
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1781

required :product_id, String

#prorationSymbol, ...

Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).



1842
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1842

optional :proration, enum: -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::Proration }

#rate_typeSymbol, ...

Whether the created commits will use the commit rate or list rate



1848
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1848

optional :rate_type, enum: -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::RateType }

#recurrence_frequencySymbol, ...

The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit’s starting_at rather than the usage invoice dates.



1858
1859
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1858

optional :recurrence_frequency,
enum: -> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::RecurrenceFrequency }

#rollover_fractionFloat?

Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.

Returns:

  • (Float, nil)


1867
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1867

optional :rollover_fraction, Float

#specifiersArray<MetronomeSDK::Models::CommitSpecifierInput>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown. This field cannot be used together with ‘applicable_product_ids` or `applicable_product_tags`.



1876
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1876

optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }

#starting_atTime

determines the start time for the first commit

Returns:

  • (Time)


1787
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1787

required :starting_at, Time

#subscription_configMetronomeSDK::Models::V1::ContractCreateParams::RecurringCommit::SubscriptionConfig?

Attach a subscription to the recurring commit/credit.



1882
1883
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1882

optional :subscription_config,
-> { MetronomeSDK::V1::ContractCreateParams::RecurringCommit::SubscriptionConfig }

#temporary_idString?

A temporary ID that can be used to reference the recurring commit for commit specific overrides.

Returns:

  • (String, nil)


1890
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1890

optional :temporary_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1996