Class: MetronomeSDK::Models::V1::ContractCreateParams::Subscription::Proration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb,
sig/metronome_sdk/models/v1/contract_create_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::ContractCreateParams::Subscription#proration

Defined Under Namespace

Modules: InvoiceBehavior Classes: Rounding

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(invoice_behavior: nil, is_prorated: nil, rounding: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::Subscription::Proration for more details.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3407

Instance Attribute Details

#invoice_behaviorSymbol, ...

Indicates how mid-period quantity adjustments are invoiced. BILL_IMMEDIATELY: Only available when collection schedule is ADVANCE. The quantity increase will be billed immediately on the scheduled date. BILL_ON_NEXT_COLLECTION_DATE: The quantity increase will be billed for in-arrears at the end of the period.



3393
3394
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3393

optional :invoice_behavior,
enum: -> { MetronomeSDK::V1::ContractCreateParams::Subscription::Proration::InvoiceBehavior }

#is_proratedBoolean?

Indicates if the partial period will be prorated or charged a full amount.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


3400
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3400

optional :is_prorated, MetronomeSDK::Internal::Type::Boolean

#roundingMetronomeSDK::Models::V1::ContractCreateParams::Subscription::Proration::Rounding?



3405
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3405

optional :rounding, -> { MetronomeSDK::V1::ContractCreateParams::Subscription::Proration::Rounding }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3431

Instance Method Details

#to_hash{

Returns:

  • ({)


3083
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 3083

def to_hash: -> {