Class: MetronomeSDK::Models::V1::ContractCreateParams::Subscription::SeatConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb,
sig/metronome_sdk/models/v1/contract_create_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::ContractCreateParams::Subscription#seat_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



3237
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 3237

def initialize: (

Instance Attribute Details

#initial_seat_idsArray<String>

The initial assigned seats on this subscription.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


3585
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3585

required :initial_seat_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#initial_unassigned_seatsFloat?

The initial amount of unassigned seats on this subscription.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


3602
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3602

optional :initial_unassigned_seats, Float

#seat_group_keyString

The property name, sent on usage events, that identifies the seat ID associated with the usage event. For example, the property name might be seat_id or user_id. The property must be set as a group key on billable metrics and a presentation/pricing group key on contract products. This allows linked recurring credits with an allocation per seat to be consumed by only one seat's usage.

Parameters:

  • value (String)

Returns:

  • (String)


3596
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3596

required :seat_group_key, String

Instance Method Details

#to_hash{

Returns:

  • ({)


3243
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 3243

def to_hash: -> {