Class: MetronomeSDK::Models::V1::ContractCreateParams::UsageStatementSchedule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb

Defined Under Namespace

Modules: Day, Frequency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(frequency:, billing_anchor_date: nil, day: nil, invoice_generation_starting_at: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::UsageStatementSchedule for more details.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3476

Instance Attribute Details

#billing_anchor_dateTime?

Required when using CUSTOM_DATE. This option lets you set a historical billing anchor date, aligning future billing cycles with a chosen cadence. For example, if a contract starts on 2024-09-15 and you set the anchor date to 2024-09-10 with a MONTHLY frequency, the first usage statement will cover 09-15 to 10-10. Subsequent statements will follow the 10th of each month.

Returns:

  • (Time, nil)


3459
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3459

optional :billing_anchor_date, Time

#daySymbol, ...

If not provided, defaults to the first day of the month.



3465
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3465

optional :day, enum: -> { MetronomeSDK::V1::ContractCreateParams::UsageStatementSchedule::Day }

#frequencySymbol, MetronomeSDK::Models::V1::ContractCreateParams::UsageStatementSchedule::Frequency



3448
3449
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3448

required :frequency,
enum: -> { MetronomeSDK::V1::ContractCreateParams::UsageStatementSchedule::Frequency }

#invoice_generation_starting_atTime?

The date Metronome should start generating usage invoices. If unspecified, contract start date will be used. This is useful to set if you want to import historical invoices via our ‘Create Historical Invoices’ API rather than having Metronome automatically generate them.

Returns:

  • (Time, nil)


3474
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3474

optional :invoice_generation_starting_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 3498