Class: MetronomeSDK::Models::V1::ContractGetNetBalanceParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb

Overview

Defined Under Namespace

Modules: InvoiceInclusionMode

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_id:, credit_type_id: nil, filters: nil, invoice_inclusion_mode: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractGetNetBalanceParams for more details.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb', line 40

Instance Attribute Details

#credit_type_idString?

The ID of the credit type (can be fiat or a custom pricing unit) to get the balance for. Defaults to USD (cents) if not specified.

Returns:

  • (String, nil)


22
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb', line 22

optional :credit_type_id, String

#customer_idString

The ID of the customer.

Returns:

  • (String)


15
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb', line 15

required :customer_id, String

#filtersArray<MetronomeSDK::Models::BalanceFilter>?

Balance filters are OR’d together, so if a given commit or credit matches any of the filters, it will be included in the net balance.

Returns:



29
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb', line 29

optional :filters, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::BalanceFilter] }

#invoice_inclusion_modeSymbol, ...

Controls which invoices are considered when calculating the remaining balance. ‘FINALIZED` considers only deductions from finalized invoices. `FINALIZED_AND_DRAFT` also includes deductions from pending draft invoices.



37
38
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_params.rb', line 37

optional :invoice_inclusion_mode,
enum: -> { MetronomeSDK::V1::ContractGetNetBalanceParams::InvoiceInclusionMode }