Class: MetronomeSDK::Models::V1::ContractGetNetBalanceResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_get_net_balance_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(balance:, credit_type_id:) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractGetNetBalanceResponse::Data for more details.

Parameters:

  • balance (Float)

    The combined net balance that the customer has access to use at this moment acro

  • credit_type_id (String)

    The ID of the credit type (can be fiat or a custom pricing unit) that the balanc



# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_response.rb', line 32

Instance Attribute Details

#balanceFloat

The combined net balance that the customer has access to use at this moment across all pertinent commits and credits.

Returns:

  • (Float)


23
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_response.rb', line 23

required :balance, Float

#credit_type_idString

The ID of the credit type (can be fiat or a custom pricing unit) that the balance is for.

Returns:

  • (String)


30
# File 'lib/metronome_sdk/models/v1/contract_get_net_balance_response.rb', line 30

required :credit_type_id, String