Class: MetronomeSDK::Models::V1::ContractGetSubscriptionSeatsHistoryParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb,
sig/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rbs

Overview

See Also:

  • MetronomeSDK::Resources::V1::Contracts#get_subscription_seats_history

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::MetronomeSDK

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contract_id:, customer_id:, subscription_id:, covering_date: nil, cursor: nil, ending_before: nil, limit: nil, starting_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractGetSubscriptionSeatsHistoryParams for more details.

Parameters:

  • contract_id (String)
  • customer_id (String)
  • subscription_id (String)
  • covering_date (Time, nil) (defaults to: nil)

    Get the seats history segment for the covering date. Cannot be used with `starti

  • cursor (String, nil) (defaults to: nil)

    Cursor for pagination. Use the value from the next_page field of the previous

  • ending_before (Time, nil) (defaults to: nil)

    Include seats history segments that are active at or before this timestamp. Use

  • limit (Integer, nil) (defaults to: nil)

    Maximum number of seat schedule entries to return. Defaults to 10. Required rang

  • starting_at (Time, nil) (defaults to: nil)

    Include seats history segments that are active at or after this timestamp. Use w

  • request_options (MetronomeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 63

Instance Attribute Details

#contract_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 14

required :contract_id, String

#covering_dateTime?

Get the seats history segment for the covering date. Cannot be used with starting_at or ending_before.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


31
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 31

optional :covering_date, Time, nil?: true

#cursorString?

Cursor for pagination. Use the value from the next_page field of the previous response to retrieve the next page of results.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 38

optional :cursor, String, nil?: true

#customer_idString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 19

required :customer_id, String

#ending_beforeTime?

Include seats history segments that are active at or before this timestamp. Use with starting_at to get a specific time range. If not set, there's no upper bound.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


46
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 46

optional :ending_before, Time, nil?: true

#limitInteger?

Maximum number of seat schedule entries to return. Defaults to 10. Required range: 1 <= x <= 10.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


53
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 53

optional :limit, Integer, nil?: true

#starting_atTime?

Include seats history segments that are active at or after this timestamp. Use with ending_before to get a specific time range. If not set, there's no lower bound.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


61
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 61

optional :starting_at, Time, nil?: true

#subscription_idString

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rb', line 24

required :subscription_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/metronome_sdk/models/v1/contract_get_subscription_seats_history_params.rbs', line 49

def to_hash: -> {