Class: MetronomeSDK::Models::V1::ContractListSeatBalancesResponse::Data::Balance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractListSeatBalancesResponse::Data::Balance
- Defined in:
- lib/metronome_sdk/models/v1/contract_list_seat_balances_response.rb
Instance Attribute Summary collapse
-
#balance ⇒ Float
The total balance across all commits and credits for this seat, of this credit type.
- #credit_type_id ⇒ String
-
#starting_balance ⇒ Float
The total initial balances of all commits and credits for this seat, of this credit type.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balances:, seat_id:, commits: nil, credits: nil) ⇒ Object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_response.rb', line 60 class Balance < MetronomeSDK::Internal::Type::BaseModel # @!attribute balance # The total balance across all commits and credits for this seat, of this credit # type. # # @return [Float] required :balance, Float # @!attribute credit_type_id # # @return [String] required :credit_type_id, String # @!attribute starting_balance # The total initial balances of all commits and credits for this seat, of this # credit type. # # @return [Float] required :starting_balance, Float # @!method initialize(balance:, credit_type_id:, starting_balance:) # Some parameter documentations has been truncated, see # {MetronomeSDK::Models::V1::ContractListSeatBalancesResponse::Data::Balance} for # more details. # # @param balance [Float] The total balance across all commits and credits for this seat, of this credit t # # @param credit_type_id [String] # # @param starting_balance [Float] The total initial balances of all commits and credits for this seat, of this cre end |
Instance Attribute Details
#balance ⇒ Float
The total balance across all commits and credits for this seat, of this credit type.
66 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_response.rb', line 66 required :balance, Float |
#credit_type_id ⇒ String
71 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_response.rb', line 71 required :credit_type_id, String |
#starting_balance ⇒ Float
The total initial balances of all commits and credits for this seat, of this credit type.
78 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_response.rb', line 78 required :starting_balance, Float |