Class: MetronomeSDK::Models::V1::ContractRetrieveRateScheduleParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb,
sig/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rbs

Overview

See Also:

  • MetronomeSDK::Resources::V1::Contracts#retrieve_rate_schedule

Defined Under Namespace

Classes: Selector

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::MetronomeSDK

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



41
# File 'sig/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rbs', line 41

def initialize: (

Instance Attribute Details

#atTime?

optional timestamp which overlaps with the returned rate schedule segments. When not specified, the current timestamp will be used.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


40
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 40

optional :at, Time

#contract_idString

ID of the contract to get the rate schedule for.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 15

required :contract_id, String

#customer_idString

ID of the customer for whose contract to get the rate schedule for.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 21

required :customer_id, String

#limitInteger?

Max number of results that should be returned

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


27
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 27

optional :limit, Integer

#next_pageString?

Cursor that indicates where the next page of results should start.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 33

optional :next_page, String

#selectorsArray<MetronomeSDK::Models::V1::ContractRetrieveRateScheduleParams::Selector>?

List of rate selectors, rates matching ANY of the selectors will be included in the response. Passing no selectors will result in all rates being returned.



47
48
# File 'lib/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rb', line 47

optional :selectors,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::ContractRetrieveRateScheduleParams::Selector] }

Instance Method Details

#to_hash{

Returns:

  • ({)


51
# File 'sig/metronome_sdk/models/v1/contract_retrieve_rate_schedule_params.rbs', line 51

def to_hash: -> {