Class: MetronomeSDK::Models::V1::Contracts::ProductRetrieveResponse::Data::Update
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb,
sig/metronome_sdk/models/v1/contracts/product_retrieve_response.rbs
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(created_at:, created_by:, billable_metric_id: nil, composite_product_ids: nil, composite_tags: nil, exclude_free_usage: nil, is_refundable: nil, name: nil, netsuite_internal_item_id: nil, netsuite_overage_item_id: nil, presentation_group_key: nil, pricing_group_key: nil, quantity_conversion: nil, quantity_rounding: nil, starting_at: nil, tags: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Update for more details.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, created_by:, billable_metric_id: nil, composite_product_ids: nil, composite_tags: nil, exclude_free_usage: nil, is_refundable: nil, name: nil, netsuite_internal_item_id: nil, netsuite_overage_item_id: nil, presentation_group_key: nil, pricing_group_key: nil, quantity_conversion: nil, quantity_rounding: nil, starting_at: nil, tags: nil) ⇒ Object
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 190
|
Instance Attribute Details
#billable_metric_id ⇒ String?
99
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 99
optional :billable_metric_id, String
|
#composite_product_ids ⇒ Array<String>?
104
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 104
optional :composite_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String]
|
109
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 109
optional :composite_tags, MetronomeSDK::Internal::Type::ArrayOf[String]
|
#created_at ⇒ Time
89
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 89
required :created_at, Time
|
#created_by ⇒ String
94
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 94
required :created_by, String
|
#exclude_free_usage ⇒ Boolean?
114
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 114
optional :exclude_free_usage, MetronomeSDK::Internal::Type::Boolean
|
#is_refundable ⇒ Boolean?
119
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 119
optional :is_refundable, MetronomeSDK::Internal::Type::Boolean
|
#name ⇒ String?
124
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 124
optional :name, String
|
#netsuite_internal_item_id ⇒ String?
This field's availability is dependent on your client's configuration.
130
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 130
optional :netsuite_internal_item_id, String
|
#netsuite_overage_item_id ⇒ String?
This field's availability is dependent on your client's configuration.
136
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 136
optional :netsuite_overage_item_id, String
|
#presentation_group_key ⇒ Array<String>?
For USAGE products only. Groups usage line items on invoices. The superset of
values in the pricing group key and presentation group key must be set as one
compound group key on the billable metric.
144
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 144
optional :presentation_group_key, MetronomeSDK::Internal::Type::ArrayOf[String]
|
#pricing_group_key ⇒ Array<String>?
For USAGE products only. If set, pricing for this product will be determined for
each pricing_group_key value, as opposed to the product as a whole. The superset
of values in the pricing group key and presentation group key must be set as one
compound group key on the billable metric.
153
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 153
optional :pricing_group_key, MetronomeSDK::Internal::Type::ArrayOf[String]
|
Optional. Only valid for USAGE products. If provided, the quantity will be
converted using the provided conversion factor and operation. For example, if
the operation is "multiply" and the conversion factor is 100, then the quantity
will be multiplied by 100. This can be used in cases where data is sent in one
unit and priced in another. For example, data could be sent in MB and priced in
GB. In this case, the conversion factor would be 1024 and the operation would be
"divide".
165
166
167
168
169
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 165
optional :quantity_conversion,
-> {
MetronomeSDK::V1::Contracts::QuantityConversion
},
nil?: true
|
Optional. Only valid for USAGE products. If provided, the quantity will be
rounded using the provided rounding method and decimal places. For example, if
the method is "round up" and the decimal places is 0, then the quantity will be
rounded up to the nearest integer.
178
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 178
optional :quantity_rounding, -> { MetronomeSDK::V1::Contracts::QuantityRounding }, nil?: true
|
#starting_at ⇒ Time?
183
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 183
optional :starting_at, Time
|
188
|
# File 'lib/metronome_sdk/models/v1/contracts/product_retrieve_response.rb', line 188
optional :tags, MetronomeSDK::Internal::Type::ArrayOf[String]
|
Instance Method Details
#to_hash ⇒ {
182
|
# File 'sig/metronome_sdk/models/v1/contracts/product_retrieve_response.rbs', line 182
def to_hash: -> {
|