Module: MetronomeSDK::Models::V1::Contracts::ProductUpdateParams::SqlBreakdownGranularity

Extended by:
Internal::Type::Enum
Defined in:
lib/metronome_sdk/models/v1/contracts/product_update_params.rb

Overview

Defines the breakdown behavior when calculating usage from SQL Billable Metrics. If set to ‘service_period’ (default), the usage will be evaluated once for all events the invoice service period and the usage will be applied at the last instant of the invoice. If set to ‘hour’, it will be broken down and evaluated for each hour. For most use cases, ‘hour’ is recommended. The setting has no effect for Streaming Billable Metrics.

Constant Summary collapse

HOUR =
:HOUR
SERVICE_PERIOD =
:SERVICE_PERIOD

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contracts/product_update_params.rb', line 187