Class: MetronomeSDK::Models::V1::Contracts::RateCardUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::Contracts::RateCardUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v1/contracts/rate_card_update_params.rb,
sig/metronome_sdk/models/v1/contracts/rate_card_update_params.rbs
Overview
Defined Under Namespace
Classes: Alias
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::MetronomeSDK
Instance Attribute Summary collapse
-
#aliases ⇒ Array<MetronomeSDK::Models::V1::Contracts::RateCardUpdateParams::Alias>?
Reference this alias when creating a contract.
- #description ⇒ String?
-
#name ⇒ String?
Used only in UI/API.
-
#rate_card_id ⇒ String
ID of the rate card to update.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
34 |
# File 'sig/metronome_sdk/models/v1/contracts/rate_card_update_params.rbs', line 34
def initialize: (
|
Instance Attribute Details
#aliases ⇒ Array<MetronomeSDK::Models::V1::Contracts::RateCardUpdateParams::Alias>?
Reference this alias when creating a contract. If the same alias is assigned to multiple rate cards, it will reference the rate card to which it was most recently assigned. It is not exposed to end customers.
24 25 |
# File 'lib/metronome_sdk/models/v1/contracts/rate_card_update_params.rb', line 24 optional :aliases, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Contracts::RateCardUpdateParams::Alias] } |
#description ⇒ String?
30 |
# File 'lib/metronome_sdk/models/v1/contracts/rate_card_update_params.rb', line 30 optional :description, String |
#name ⇒ String?
Used only in UI/API. It is not exposed to end customers.
36 |
# File 'lib/metronome_sdk/models/v1/contracts/rate_card_update_params.rb', line 36 optional :name, String |
#rate_card_id ⇒ String
ID of the rate card to update
16 |
# File 'lib/metronome_sdk/models/v1/contracts/rate_card_update_params.rb', line 16 required :rate_card_id, String |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/metronome_sdk/models/v1/contracts/rate_card_update_params.rbs', line 42
def to_hash: -> {
|