Class: MetronomeSDK::Models::V1::CreditGrantListResponse::Balance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/credit_grant_list_response.rb,
sig/metronome_sdk/models/v1/credit_grant_list_response.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::CreditGrantListResponse#balance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



118
# File 'sig/metronome_sdk/models/v1/credit_grant_list_response.rbs', line 118

def initialize: (

Instance Attribute Details

#effective_atTime

The end_date of the customer's current billing period.

Parameters:

  • value (Time)

Returns:

  • (Time)


154
# File 'lib/metronome_sdk/models/v1/credit_grant_list_response.rb', line 154

required :effective_at, Time

#excluding_pendingFloat

The grant's current balance including all posted deductions. If the grant has expired, this amount will be 0.

Parameters:

  • value (Float)

Returns:

  • (Float)


161
# File 'lib/metronome_sdk/models/v1/credit_grant_list_response.rb', line 161

required :excluding_pending, Float

#including_pendingFloat

The grant's current balance including all posted and pending deductions. If the grant expires before the end of the customer's current billing period, this amount will be 0.

Parameters:

  • value (Float)

Returns:

  • (Float)


169
# File 'lib/metronome_sdk/models/v1/credit_grant_list_response.rb', line 169

required :including_pending, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


124
# File 'sig/metronome_sdk/models/v1/credit_grant_list_response.rbs', line 124

def to_hash: -> {