Module: MetronomeSDK::Models::V1::CustomerCreateParams::CustomerBillingProviderConfiguration::TaxProvider

Extended by:
Internal::Type::Enum
Defined in:
lib/metronome_sdk/models/v1/customer_create_params.rb,
sig/metronome_sdk/models/v1/customer_create_params.rbs

Overview

Specifies which tax provider Metronome should use for tax calculation when billing through Stripe. This is only supported for Stripe billing provider configurations with auto_charge_payment_intent or manual_charge_payment_intent collection methods.

See Also:

  • MetronomeSDK::Models::V1::CustomerCreateParams::CustomerBillingProviderConfiguration#tax_provider

Constant Summary collapse

ANROK =

Returns:

  • (:anrok)
:anrok
AVALARA =

Returns:

  • (:avalara)
:avalara
STRIPE =

Returns:

  • (:stripe)
:stripe

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[MetronomeSDK::Models::V1::CustomerCreateParams::CustomerBillingProviderConfiguration::tax_provider]

Returns:

  • (::Array[MetronomeSDK::Models::V1::CustomerCreateParams::CustomerBillingProviderConfiguration::tax_provider])


335
# File 'sig/metronome_sdk/models/v1/customer_create_params.rbs', line 335

def self?.values: -> ::Array[MetronomeSDK::Models::V1::CustomerCreateParams::CustomerBillingProviderConfiguration::tax_provider]