Class: MetronomeSDK::Models::V1::CustomerListBillableMetricsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb,
sig/metronome_sdk/models/v1/customer_list_billable_metrics_response.rbs

Overview

See Also:

  • MetronomeSDK::Resources::V1::Customers#list_billable_metrics

Defined Under Namespace

Modules: AggregationType

Constant Summary collapse

MetronomeSDK =

Returns:

  • (:EventTypeFilter)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, name:, aggregate: nil, aggregate_keys: nil, aggregation_key: nil, aggregation_type: nil, archived_at: nil, custom_fields: nil, event_type_filter: nil, filter: nil, group_by: nil, group_keys: nil, property_filters: nil, sql: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::CustomerListBillableMetricsResponse for more details.

Parameters:

  • id (String)
  • name (String)
  • aggregate (String) (defaults to: nil)

    (DEPRECATED) use aggregation_type instead

  • aggregate_keys (Array<String>) (defaults to: nil)

    (DEPRECATED) use aggregation_key instead

  • aggregation_key (String) (defaults to: nil)

    A key that specifies which property of the event is used to aggregate data. This

  • aggregation_type (Symbol, MetronomeSDK::Models::V1::CustomerListBillableMetricsResponse::AggregationType) (defaults to: nil)

    Specifies the type of aggregation performed on matching events.

  • archived_at (Time) (defaults to: nil)

    RFC 3339 timestamp indicating when the billable metric was archived. If not prov

  • custom_fields (Hash{Symbol=>String}) (defaults to: nil)

    Custom fields to be added eg. { "key1": "value1", "key2": "value2" }

  • event_type_filter (MetronomeSDK::Models::EventTypeFilter) (defaults to: nil)

    An optional filtering rule to match the 'event_type' property of an event.

  • filter (Hash{Symbol=>Object}) (defaults to: nil)

    (DEPRECATED) use property_filters & event_type_filter instead

  • group_by (Array<String>) (defaults to: nil)

    (DEPRECATED) use group_keys instead

  • group_keys (Array<Array<String>>) (defaults to: nil)

    Property names that are used to group usage costs on an invoice. Each entry repr

  • property_filters (Array<MetronomeSDK::Models::PropertyFilter>) (defaults to: nil)

    A list of filters to match events to this billable metric. Each filter defines a

  • sql (String) (defaults to: nil)

    The SQL query associated with the billable metric



# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 97

Instance Attribute Details

#aggregateString?

(DEPRECATED) use aggregation_type instead

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 22

optional :aggregate, String

#aggregate_keysArray<String>?

(DEPRECATED) use aggregation_key instead

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


28
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 28

optional :aggregate_keys, MetronomeSDK::Internal::Type::ArrayOf[String]

#aggregation_keyString?

A key that specifies which property of the event is used to aggregate data. This key must be one of the property filter names and is not applicable when the aggregation type is 'count'.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 36

optional :aggregation_key, String

#aggregation_typeSymbol, ...

Specifies the type of aggregation performed on matching events.



42
43
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 42

optional :aggregation_type,
enum: -> { MetronomeSDK::Models::V1::CustomerListBillableMetricsResponse::AggregationType }

#archived_atTime?

RFC 3339 timestamp indicating when the billable metric was archived. If not provided, the billable metric is not archived.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


50
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 50

optional :archived_at, Time

#custom_fieldsHash{Symbol=>String}?

Custom fields to be added eg. { "key1": "value1", "key2": "value2" }

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


56
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 56

optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String]

#event_type_filterMetronomeSDK::Models::EventTypeFilter?

An optional filtering rule to match the 'event_type' property of an event.



62
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 62

optional :event_type_filter, -> { MetronomeSDK::EventTypeFilter }

#filterHash{Symbol=>Object}?

(DEPRECATED) use property_filters & event_type_filter instead

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


68
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 68

optional :filter, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown]

#group_byArray<String>?

(DEPRECATED) use group_keys instead

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


74
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 74

optional :group_by, MetronomeSDK::Internal::Type::ArrayOf[String]

#group_keysArray<Array<String>>?

Property names that are used to group usage costs on an invoice. Each entry represents a set of properties used to slice events into distinct buckets.

Parameters:

  • (::Array[::Array[String]])

Returns:

  • (Array<Array<String>>, nil)


81
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 81

optional :group_keys, MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Internal::Type::ArrayOf[String]]

#idString

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 11

required :id, String

#nameString

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 16

required :name, String

#property_filtersArray<MetronomeSDK::Models::PropertyFilter>?

A list of filters to match events to this billable metric. Each filter defines a rule on an event property. All rules must pass for the event to match the billable metric.

Returns:



89
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 89

optional :property_filters, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::PropertyFilter] }

#sqlString?

The SQL query associated with the billable metric

Parameters:

  • (String)

Returns:

  • (String, nil)


95
# File 'lib/metronome_sdk/models/v1/customer_list_billable_metrics_response.rb', line 95

optional :sql, String

Instance Method Details

#to_hash{

Returns:

  • ({)


98
# File 'sig/metronome_sdk/models/v1/customer_list_billable_metrics_response.rbs', line 98

def to_hash: -> {