Module: MetronomeSDK::Models::V1::CustomerPreviewEventsParams::Mode

Extended by:
Internal::Type::Enum
Defined in:
lib/metronome_sdk/models/v1/customer_preview_events_params.rb,
sig/metronome_sdk/models/v1/customer_preview_events_params.rbs

Overview

Controls how the provided events are combined with existing usage data. Use replace to calculate the preview as if these are the only events for the customer, ignoring all historical usage. Use merge to combine these events with the customer's existing usage. Defaults to replace.

Constant Summary collapse

REPLACE =

Returns:

  • (:replace)
:replace
MERGE =

Returns:

  • (:merge)
:merge

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customer_preview_events_params.rb', line 101

Instance Method Details

#self?.values::Array[MetronomeSDK::Models::V1::CustomerPreviewEventsParams::mode]

Returns:

  • (::Array[MetronomeSDK::Models::V1::CustomerPreviewEventsParams::mode])


93
# File 'sig/metronome_sdk/models/v1/customer_preview_events_params.rbs', line 93

def self?.values: -> ::Array[MetronomeSDK::Models::V1::CustomerPreviewEventsParams::mode]