Class: MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb

Defined Under Namespace

Modules: BillingProvider, TaxProvider

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, billing_provider: nil, configuration: nil, customer_id: nil, delivery_method_id: nil, tax_provider: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data for more details.

Parameters:



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 17

class Data < MetronomeSDK::Internal::Type::BaseModel
  # @!attribute id
  #   ID of the created configuration
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute billing_provider
  #   The billing provider set for this configuration.
  #
  #   @return [Symbol, MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::BillingProvider, nil]
  optional :billing_provider,
           enum: -> { MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::BillingProvider }

  # @!attribute configuration
  #   Configuration for the billing provider. The structure of this object is specific
  #   to the billing provider and delivery method combination.
  #
  #   @return [Hash{Symbol=>Object}, nil]
  optional :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown]

  # @!attribute customer_id
  #   ID of the customer this configuration is associated with.
  #
  #   @return [String, nil]
  optional :customer_id, String

  # @!attribute delivery_method_id
  #   ID of the delivery method used for this customer configuration.
  #
  #   @return [String, nil]
  optional :delivery_method_id, String

  # @!attribute tax_provider
  #   The tax provider set for this configuration.
  #
  #   @return [Symbol, MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::TaxProvider, nil]
  optional :tax_provider,
           enum: -> { MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::TaxProvider }

  # @!method initialize(id: nil, billing_provider: nil, configuration: nil, customer_id: nil, delivery_method_id: nil, tax_provider: nil)
  #   Some parameter documentations has been truncated, see
  #   {MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data} for
  #   more details.
  #
  #   @param id [String] ID of the created configuration
  #
  #   @param billing_provider [Symbol, MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::BillingProvider] The billing provider set for this configuration.
  #
  #   @param configuration [Hash{Symbol=>Object}] Configuration for the billing provider. The structure of this object is specific
  #
  #   @param customer_id [String] ID of the customer this configuration is associated with.
  #
  #   @param delivery_method_id [String] ID of the delivery method used for this customer configuration.
  #
  #   @param tax_provider [Symbol, MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::TaxProvider] The tax provider set for this configuration.

  # The billing provider set for this configuration.
  #
  # @see MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data#billing_provider
  module BillingProvider
    extend MetronomeSDK::Internal::Type::Enum

    AWS_MARKETPLACE = :aws_marketplace
    STRIPE = :stripe
    NETSUITE = :netsuite
    CUSTOM = :custom
    AZURE_MARKETPLACE = :azure_marketplace
    QUICKBOOKS_ONLINE = :quickbooks_online
    WORKDAY = :workday
    GCP_MARKETPLACE = :gcp_marketplace
    METRONOME = :metronome

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The tax provider set for this configuration.
  #
  # @see MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data#tax_provider
  module TaxProvider
    extend MetronomeSDK::Internal::Type::Enum

    ANROK = :anrok
    AVALARA = :avalara
    STRIPE = :stripe

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#billing_providerSymbol, ...

The billing provider set for this configuration.



28
29
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 28

optional :billing_provider,
enum: -> { MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::BillingProvider }

#configurationHash{Symbol=>Object}?

Configuration for the billing provider. The structure of this object is specific to the billing provider and delivery method combination.

Returns:

  • (Hash{Symbol=>Object}, nil)


36
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 36

optional :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown]

#customer_idString?

ID of the customer this configuration is associated with.

Returns:

  • (String, nil)


42
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 42

optional :customer_id, String

#delivery_method_idString?

ID of the delivery method used for this customer configuration.

Returns:

  • (String, nil)


48
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 48

optional :delivery_method_id, String

#idString?

ID of the created configuration

Returns:

  • (String, nil)


22
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 22

optional :id, String

#tax_providerSymbol, ...

The tax provider set for this configuration.



54
55
# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 54

optional :tax_provider,
enum: -> { MetronomeSDK::Models::V1::CustomerSetBillingConfigurationsResponse::Data::TaxProvider }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customer_set_billing_configurations_response.rb', line 90