Class: MetronomeSDK::Models::V1::Customers::AlertRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb

Overview

Defined Under Namespace

Modules: PlansOrContracts Classes: GroupValue, SeatFilter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(key:, value:) ⇒ Object

Scopes threshold notification evaluation to a specific presentation group key on individual line items. Only present for spend notifications.

Parameters:

  • key (String)
  • value (String)


# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 74

Instance Attribute Details

#alert_idString

The Metronome ID of the threshold notification

Returns:

  • (String)


16
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 16

required :alert_id, String

#customer_idString

The Metronome ID of the customer

Returns:

  • (String)


22
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 22

required :customer_id, String

#group_valuesArray<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::GroupValue>?

Only present for ‘spend_threshold_reached` notifications. Retrieve the notification for a specific group key-value pair.



29
30
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 29

optional :group_values,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::GroupValue] }

#plans_or_contractsSymbol, ...

When parallel threshold notifications are enabled during migration, this flag denotes whether to fetch notifications for plans or contracts.



37
38
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 37

optional :plans_or_contracts,
enum: -> { MetronomeSDK::V1::Customers::AlertRetrieveParams::PlansOrContracts }

#seat_filterMetronomeSDK::Models::V1::Customers::AlertRetrieveParams::SeatFilter?

Only allowed for ‘low_remaining_seat_balance_reached` notifications. This filters alerts by the seat group key-value pair.



45
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 45

optional :seat_filter, -> { MetronomeSDK::V1::Customers::AlertRetrieveParams::SeatFilter }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 90