Class: MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb,
sig/metronome_sdk/models/v1/customers/alert_retrieve_params.rbs

Defined Under Namespace

Classes: CustomFieldFilter, Exclude

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alert_id:, customer_id:, alert_specifiers: nil, group_values: nil, plans_or_contracts: nil, seat_filter: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::Customers::AlertRetrieveParams for more details.

Parameters:



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 73

class AlertSpecifier < MetronomeSDK::Internal::Type::BaseModel
  # @!attribute custom_field_filters
  #   A list of custom field filters for notification types that support advanced
  #   filtering
  #
  #   @return [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter>]
  required :custom_field_filters,
           -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter] }

  # @!attribute exclude
  #   If provided, the specifier will not apply to balances that matches the inclusion
  #   criteria and any of the excluding values.
  #
  #   @return [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude>, nil]
  optional :exclude,
           -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude] }

  # @!method initialize(custom_field_filters:, exclude: nil)
  #   Some parameter documentations has been truncated, see
  #   {MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier} for
  #   more details.
  #
  #   @param custom_field_filters [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter>] A list of custom field filters for notification types that support advanced filt
  #
  #   @param exclude [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude>] If provided, the specifier will not apply to balances that matches the inclusion

  class CustomFieldFilter < MetronomeSDK::Internal::Type::BaseModel
    # @!attribute entity
    #
    #   @return [Symbol, MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter::Entity]
    required :entity,
             enum: -> { MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter::Entity }

    # @!attribute key
    #
    #   @return [String]
    required :key, String

    # @!attribute value
    #
    #   @return [String]
    required :value, String

    # @!method initialize(entity:, key:, value:)
    #   @param entity [Symbol, MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter::Entity]
    #   @param key [String]
    #   @param value [String]

    # @see MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter#entity
    module Entity
      extend MetronomeSDK::Internal::Type::Enum

      CONTRACT = :Contract
      COMMIT = :Commit
      CONTRACT_CREDIT = :ContractCredit
      CONTRACT_CREDIT_OR_COMMIT = :ContractCreditOrCommit

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class Exclude < MetronomeSDK::Internal::Type::BaseModel
    # @!attribute custom_field_filters
    #   A list of custom field filters for notification types that support advanced
    #   filtering
    #
    #   @return [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter>, nil]
    optional :custom_field_filters,
             -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter] }

    # @!method initialize(custom_field_filters: nil)
    #   Some parameter documentations has been truncated, see
    #   {MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude}
    #   for more details.
    #
    #   @param custom_field_filters [Array<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter>] A list of custom field filters for notification types that support advanced filt

    class CustomFieldFilter < MetronomeSDK::Internal::Type::BaseModel
      # @!attribute entity
      #
      #   @return [Symbol, MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter::Entity]
      required :entity,
               enum: -> { MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter::Entity }

      # @!attribute key
      #
      #   @return [String]
      required :key, String

      # @!attribute value
      #
      #   @return [String]
      required :value, String

      # @!method initialize(entity:, key:, value:)
      #   @param entity [Symbol, MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter::Entity]
      #   @param key [String]
      #   @param value [String]

      # @see MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude::CustomFieldFilter#entity
      module Entity
        extend MetronomeSDK::Internal::Type::Enum

        CONTRACT = :Contract
        COMMIT = :Commit
        CONTRACT_CREDIT = :ContractCredit
        CONTRACT_CREDIT_OR_COMMIT = :ContractCreditOrCommit

        # @!method self.values
        #   @return [Array<Symbol>]
      end
    end
  end
end

Instance Attribute Details

#custom_field_filtersArray<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter>

A list of custom field filters for notification types that support advanced filtering

Parameters:

  • value (::Array[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter])

Returns:



79
80
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 79

required :custom_field_filters,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::CustomFieldFilter] }

#excludeArray<MetronomeSDK::Models::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude>?

If provided, the specifier will not apply to balances that matches the inclusion criteria and any of the excluding values.



87
88
# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 87

optional :exclude,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::AlertRetrieveParams::AlertSpecifier::Exclude] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customers/alert_retrieve_params.rb', line 130

Instance Method Details

#to_hash{

Returns:

  • ({)


88
# File 'sig/metronome_sdk/models/v1/customers/alert_retrieve_params.rbs', line 88

def to_hash: -> {