Class: MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier
- Defined in:
- lib/metronome_sdk/models/v1/customers/customer_alert.rb,
sig/metronome_sdk/models/v1/customers/customer_alert.rbs
Defined Under Namespace
Classes: CustomFieldFilter, Exclude
Instance Attribute Summary collapse
-
#custom_field_filters ⇒ Array<MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier::CustomFieldFilter>?
A list of custom field filters for notification types that support advanced filtering.
-
#exclude ⇒ Array<MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier::Exclude>?
If provided, the specifier will not apply to balances that matches the inclusion criteria and any of the excluding values.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
215 |
# File 'sig/metronome_sdk/models/v1/customers/customer_alert.rbs', line 215
def initialize: (
|
Instance Attribute Details
#custom_field_filters ⇒ Array<MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier::CustomFieldFilter>?
A list of custom field filters for notification types that support advanced filtering
227 228 |
# File 'lib/metronome_sdk/models/v1/customers/customer_alert.rb', line 227 optional :custom_field_filters, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::CustomerAlert::Alert::AlertSpecifier::CustomFieldFilter] } |
#exclude ⇒ Array<MetronomeSDK::Models::V1::Customers::CustomerAlert::Alert::AlertSpecifier::Exclude>?
If provided, the specifier will not apply to balances that matches the inclusion criteria and any of the excluding values.
235 236 |
# File 'lib/metronome_sdk/models/v1/customers/customer_alert.rb', line 235 optional :exclude, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V1::Customers::CustomerAlert::Alert::AlertSpecifier::Exclude] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/customers/customer_alert.rb', line 278
|
Instance Method Details
#to_hash ⇒ {
220 |
# File 'sig/metronome_sdk/models/v1/customers/customer_alert.rbs', line 220
def to_hash: -> {
|