Class: MetronomeSDK::Models::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customers/invoice.rb,
sig/metronome_sdk/models/v1/customers/invoice.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::Customers::Invoice::CorrectionRecord#corrected_external_invoice

Defined Under Namespace

Modules: BillingProviderType, ExternalStatus Classes: Tax

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_provider_type:, billing_provider_error: nil, external_payment_id: nil, external_status: nil, invoice_id: nil, invoiced_sub_total: nil, invoiced_total: nil, issued_at_timestamp: nil, pdf_url: nil, tax: nil) ⇒ Object

Parameters:



# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1009


Instance Attribute Details

#billing_provider_errorString?

Error message from the billing provider, if available.

Parameters:

  • (String)

Returns:

  • (String, nil)


960
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 960

optional :billing_provider_error, String

#billing_provider_typeSymbol, MetronomeSDK::Models::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::BillingProviderType

Parameters:

  • value (MetronomeSDK::Models::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::billing_provider_type)

Returns:



953
954
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 953

required :billing_provider_type,
enum: -> { MetronomeSDK::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::BillingProviderType }

#external_payment_idString?

The ID of the payment in the external system, if available.

Parameters:

  • (String)

Returns:

  • (String, nil)


966
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 966

optional :external_payment_id, String

#external_statusSymbol, ...



971
972
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 971

optional :external_status,
enum: -> { MetronomeSDK::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::ExternalStatus }

#invoice_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


977
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 977

optional :invoice_id, String

#invoiced_sub_totalFloat?

The subtotal amount invoiced, if available from the billing provider.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


983
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 983

optional :invoiced_sub_total, Float

#invoiced_totalFloat?

The total amount invoiced, if available from the billing provider.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


989
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 989

optional :invoiced_total, Float

#issued_at_timestampTime?

Parameters:

  • (Time)

Returns:

  • (Time, nil)


994
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 994

optional :issued_at_timestamp, Time

#pdf_urlString?

A URL to the PDF of the invoice, if available from the billing provider.

Parameters:

  • (String)

Returns:

  • (String, nil)


1000
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1000

optional :pdf_url, String

#taxMetronomeSDK::Models::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::Tax?

Tax details for the invoice, if available from the billing provider.



1006
1007
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1006

optional :tax,
-> { MetronomeSDK::V1::Customers::Invoice::CorrectionRecord::CorrectedExternalInvoice::Tax }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1044


Instance Method Details

#to_hash{

Returns:

  • ({)


945
# File 'sig/metronome_sdk/models/v1/customers/invoice.rbs', line 945

def to_hash: -> {