Class: MetronomeSDK::Models::V1::Customers::Invoice::ExternalInvoice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customers/invoice.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingProviderType, ExternalStatus Classes: Tax

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_provider_type:, billing_provider_error: nil, external_payment_id: nil, external_status: nil, invoice_id: nil, invoiced_sub_total: nil, invoiced_total: nil, issued_at_timestamp: nil, pdf_url: nil, tax: nil) ⇒ Object

Parameters:



# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1154

Instance Attribute Details

#billing_provider_errorString?

Error message from the billing provider, if available.

Returns:

  • (String, nil)


1106
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1106

optional :billing_provider_error, String

#billing_provider_typeSymbol, MetronomeSDK::Models::V1::Customers::Invoice::ExternalInvoice::BillingProviderType



1099
1100
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1099

required :billing_provider_type,
enum: -> { MetronomeSDK::V1::Customers::Invoice::ExternalInvoice::BillingProviderType }

#external_payment_idString?

The ID of the payment in the external system, if available.

Returns:

  • (String, nil)


1112
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1112

optional :external_payment_id, String

#external_statusSymbol, ...



1117
1118
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1117

optional :external_status,
enum: -> { MetronomeSDK::V1::Customers::Invoice::ExternalInvoice::ExternalStatus }

#invoice_idString?

Returns:

  • (String, nil)


1123
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1123

optional :invoice_id, String

#invoiced_sub_totalFloat?

The subtotal amount invoiced, if available from the billing provider.

Returns:

  • (Float, nil)


1129
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1129

optional :invoiced_sub_total, Float

#invoiced_totalFloat?

The total amount invoiced, if available from the billing provider.

Returns:

  • (Float, nil)


1135
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1135

optional :invoiced_total, Float

#issued_at_timestampTime?

Returns:

  • (Time, nil)


1140
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1140

optional :issued_at_timestamp, Time

#pdf_urlString?

A URL to the PDF of the invoice, if available from the billing provider.

Returns:

  • (String, nil)


1146
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1146

optional :pdf_url, String

#taxMetronomeSDK::Models::V1::Customers::Invoice::ExternalInvoice::Tax?

Tax details for the invoice, if available from the billing provider.



1152
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1152

optional :tax, -> { MetronomeSDK::V1::Customers::Invoice::ExternalInvoice::Tax }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1189