Class: MetronomeSDK::Models::V1::Customers::Invoice::RevenueSystemInvoice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/customers/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(revenue_system_external_entity_type:, revenue_system_provider:, sync_status:, error_message: nil, revenue_system_external_entity_id: nil) ⇒ Object

Parameters:

  • revenue_system_external_entity_type (String)
  • revenue_system_provider (String)
  • sync_status (String)
  • error_message (String) (defaults to: nil)

    The error message from the revenue system, if available.

  • revenue_system_external_entity_id (String) (defaults to: nil)


# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1421

Instance Attribute Details

#error_messageString?

The error message from the revenue system, if available.

Returns:

  • (String, nil)


1414
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1414

optional :error_message, String

#revenue_system_external_entity_idString?

Returns:

  • (String, nil)


1419
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1419

optional :revenue_system_external_entity_id, String

#revenue_system_external_entity_typeString

Returns:

  • (String)


1398
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1398

required :revenue_system_external_entity_type, String

#revenue_system_providerString

Returns:

  • (String)


1403
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1403

required :revenue_system_provider, String

#sync_statusString

Returns:

  • (String)


1408
# File 'lib/metronome_sdk/models/v1/customers/invoice.rb', line 1408

required :sync_status, String