Class: MetronomeSDK::Models::V1::Customers::InvoiceListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::Customers::InvoiceListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v1/customers/invoice_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#contract_id ⇒ String?
Only return invoices for the specified contract.
-
#credit_type_id ⇒ String?
Only return invoices for the specified credit type.
- #customer_id ⇒ String
-
#ending_before ⇒ Time?
RFC 3339 timestamp (exclusive).
-
#limit ⇒ Integer?
Max number of results that should be returned.
-
#next_page ⇒ String?
Cursor that indicates where the next page of results should start.
-
#skip_zero_qty_line_items ⇒ Boolean?
If set, all zero quantity line items will be filtered out of the response.
-
#sort ⇒ Symbol, ...
Invoice sort order by issued_at, e.g.
-
#starting_on ⇒ Time?
RFC 3339 timestamp (inclusive).
-
#status ⇒ String?
Invoice status, e.g.
-
#type ⇒ Symbol, ...
Filter invoices by type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(customer_id:, contract_id: nil, credit_type_id: nil, ending_before: nil, limit: nil, next_page: nil, skip_zero_qty_line_items: nil, sort: nil, starting_on: nil, status: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InvoiceListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, contract_id: nil, credit_type_id: nil, ending_before: nil, limit: nil, next_page: nil, skip_zero_qty_line_items: nil, sort: nil, starting_on: nil, status: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::Customers::InvoiceListParams for more details.
|
|
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 80
|
Instance Attribute Details
#contract_id ⇒ String?
Only return invoices for the specified contract
21 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 21 optional :contract_id, String |
#credit_type_id ⇒ String?
Only return invoices for the specified credit type
27 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 27 optional :credit_type_id, String |
#customer_id ⇒ String
15 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 15 required :customer_id, String |
#ending_before ⇒ Time?
RFC 3339 timestamp (exclusive). Invoices will only be returned for billing periods that end before this time.
34 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 34 optional :ending_before, Time |
#limit ⇒ Integer?
Max number of results that should be returned
40 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 40 optional :limit, Integer |
#next_page ⇒ String?
Cursor that indicates where the next page of results should start.
46 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 46 optional :next_page, String |
#skip_zero_qty_line_items ⇒ Boolean?
If set, all zero quantity line items will be filtered out of the response
52 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 52 optional :skip_zero_qty_line_items, MetronomeSDK::Internal::Type::Boolean |
#sort ⇒ Symbol, ...
Invoice sort order by issued_at, e.g. date_asc or date_desc. Defaults to date_asc.
59 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 59 optional :sort, enum: -> { MetronomeSDK::V1::Customers::InvoiceListParams::Sort } |
#starting_on ⇒ Time?
RFC 3339 timestamp (inclusive). Invoices will only be returned for billing periods that start at or after this time.
66 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 66 optional :starting_on, Time |
#status ⇒ String?
Invoice status, e.g. DRAFT, FINALIZED, or VOID
72 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 72 optional :status, String |
#type ⇒ Symbol, ...
Filter invoices by type. Defaults to returning all invoice types.
78 |
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 78 optional :type, enum: -> { MetronomeSDK::V1::Customers::InvoiceListParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/customers/invoice_list_params.rb', line 116
|