Class: MetronomeSDK::Models::V1::DashboardGetEmbeddableURLParams::BmGroupKeyOverride

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rb,
sig/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



89
# File 'sig/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rbs', line 89

def initialize: (

Instance Attribute Details

#display_nameString?

The display name for the billable metric group key

Parameters:

  • (String)

Returns:

  • (String, nil)


80
# File 'lib/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rb', line 80

optional :display_name, String

#group_key_nameString

The name of the billable metric group key.

Parameters:

  • value (String)

Returns:

  • (String)


74
# File 'lib/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rb', line 74

required :group_key_name, String

#value_display_namesHash{Symbol=>Object}?

<key, value> pairs of the billable metric group key values and their display names. e.g. "Asia", "b": "Euro"

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


87
# File 'lib/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rb', line 87

optional :value_display_names, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown]

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/metronome_sdk/models/v1/dashboard_get_embeddable_url_params.rbs', line 95

def to_hash: -> {