Class: MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit
- Defined in:
- lib/metronome_sdk/models/v1/package_create_params.rb
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Duration, InvoiceAmount, StartingAtOffset, SubscriptionConfig
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::CommitDuration
Defines the length of the access schedule for each created commit/credit.
-
#description ⇒ String?
Will be passed down to the individual commits.
-
#duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits.
-
#invoice_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit.
-
#name ⇒ String?
displayed on invoices.
-
#priority ⇒ Float
Will be passed down to the individual commits.
- #product_id ⇒ String
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
-
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
constructor
The amount the customer should be billed for the commit.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
The amount the customer should be billed for the commit. Not required.
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1414
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::AccessAmount
The amount of commit to grant.
1293 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1293 required :access_amount, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1326 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1326 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1332 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1332 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::CommitDuration
Defines the length of the access schedule for each created commit/credit. The value represents the number of units. Unit defaults to “PERIODS”, where the length of a period is determined by the recurrence_frequency.
1301 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1301 required :commit_duration, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::CommitDuration } |
#description ⇒ String?
Will be passed down to the individual commits
1338 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1338 optional :description, String |
#duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits. optional
1345 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1345 optional :duration, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::Duration } |
#invoice_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit. Not required.
1351 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1351 optional :invoice_amount, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::InvoiceAmount } |
#name ⇒ String?
displayed on invoices. will be passed through to the individual commits
1357 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1357 optional :name, String |
#priority ⇒ Float
Will be passed down to the individual commits
1307 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1307 required :priority, Float |
#product_id ⇒ String
1312 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1312 required :product_id, String |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1364 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1364 optional :proration, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::Proration } |
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate
1370 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1370 optional :rate_type, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit’s starting_at rather than the usage invoice dates.
1380 1381 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1380 optional :recurrence_frequency, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1389 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1389 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown. This field cannot be used together with ‘applicable_product_ids` or `applicable_product_tags`.
1398 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1398 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] } |
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit
1319 1320 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1319 required :starting_at_offset, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::StartingAtOffset } |
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1404 1405 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1404 optional :subscription_config, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig } |
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
1412 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1412 optional :temporary_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1514
|