Module: MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig::Allocation
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/metronome_sdk/models/v1/package_create_params.rb,
sig/metronome_sdk/models/v1/package_create_params.rbs
Overview
If set to POOLED, allocation added per seat is pooled across the account. If set to INDIVIDUAL, each seat in the subscription will have its own allocation.
Constant Summary collapse
- INDIVIDUAL =
:INDIVIDUAL- POOLED =
:POOLED
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig::allocation]
1739 |
# File 'sig/metronome_sdk/models/v1/package_create_params.rbs', line 1739
def self?.values: -> ::Array[MetronomeSDK::Models::V1::PackageCreateParams::RecurringCommit::SubscriptionConfig::allocation]
|