Class: MetronomeSDK::Models::V1::PackageCreateParams::Subscription::Proration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::PackageCreateParams::Subscription::Proration
- Defined in:
- lib/metronome_sdk/models/v1/package_create_params.rb,
sig/metronome_sdk/models/v1/package_create_params.rbs
Overview
Defined Under Namespace
Modules: InvoiceBehavior Classes: Rounding
Instance Attribute Summary collapse
-
#invoice_behavior ⇒ Symbol, ...
Indicates how mid-period quantity adjustments are invoiced.
-
#is_prorated ⇒ Boolean?
Indicates if the partial period will be prorated or charged a full amount.
- #rounding ⇒ MetronomeSDK::Models::V1::PackageCreateParams::Subscription::Proration::Rounding?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(invoice_behavior: nil, is_prorated: nil, rounding: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Proration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(invoice_behavior: nil, is_prorated: nil, rounding: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::PackageCreateParams::Subscription::Proration for more details.
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2693
|
Instance Attribute Details
#invoice_behavior ⇒ Symbol, ...
Indicates how mid-period quantity adjustments are invoiced.
BILL_IMMEDIATELY: Only available when collection schedule is ADVANCE. The
quantity increase will be billed immediately on the scheduled date.
BILL_ON_NEXT_COLLECTION_DATE: The quantity increase will be billed for
in-arrears at the end of the period.
2679 2680 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2679 optional :invoice_behavior, enum: -> { MetronomeSDK::V1::PackageCreateParams::Subscription::Proration::InvoiceBehavior } |
#is_prorated ⇒ Boolean?
Indicates if the partial period will be prorated or charged a full amount.
2686 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2686 optional :is_prorated, MetronomeSDK::Internal::Type::Boolean |
#rounding ⇒ MetronomeSDK::Models::V1::PackageCreateParams::Subscription::Proration::Rounding?
2691 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2691 optional :rounding, -> { MetronomeSDK::V1::PackageCreateParams::Subscription::Proration::Rounding } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2717
|
Instance Method Details
#to_hash ⇒ {
2548 |
# File 'sig/metronome_sdk/models/v1/package_create_params.rbs', line 2548
def to_hash: -> {
|