Class: MetronomeSDK::Models::V1::PackageListContractsOnPackageParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(package_id:, limit: nil, next_page: nil, covering_date: nil, include_archived: nil, starting_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::PackageListContractsOnPackageParams for more details.

Parameters:

  • package_id (String)
  • limit (Integer) (defaults to: nil)

    Max number of results that should be returned

  • next_page (String) (defaults to: nil)

    Cursor that indicates where the next page of results should start.

  • covering_date (Time) (defaults to: nil)

    Optional RFC 3339 timestamp. Only include contracts active on the provided date.

  • include_archived (Boolean) (defaults to: nil)

    Default false. Determines whether to include archived contracts in the results

  • starting_at (Time) (defaults to: nil)

    Optional RFC 3339 timestamp. Only include contracts that started on or after thi

  • request_options (MetronomeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 48

Instance Attribute Details

#covering_dateTime?

Optional RFC 3339 timestamp. Only include contracts active on the provided date. This cannot be provided if starting_at filter is provided.

Returns:

  • (Time, nil)


33
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 33

optional :covering_date, Time

#include_archivedBoolean?

Default false. Determines whether to include archived contracts in the results

Returns:

  • (Boolean, nil)


39
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 39

optional :include_archived, MetronomeSDK::Internal::Type::Boolean

#limitInteger?

Max number of results that should be returned

Returns:

  • (Integer, nil)


20
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 20

optional :limit, Integer

#next_pageString?

Cursor that indicates where the next page of results should start.

Returns:

  • (String, nil)


26
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 26

optional :next_page, String

#package_idString

Returns:

  • (String)


14
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 14

required :package_id, String

#starting_atTime?

Optional RFC 3339 timestamp. Only include contracts that started on or after this date. This cannot be provided if covering_date filter is provided.

Returns:

  • (Time, nil)


46
# File 'lib/metronome_sdk/models/v1/package_list_contracts_on_package_params.rb', line 46

optional :starting_at, Time