Class: MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit
- Defined in:
- lib/metronome_sdk/models/v1/package_retrieve_response.rb
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Duration, InvoiceAmount, Product, StartingAtOffset, SubscriptionConfig
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::CommitDuration
The amount of time each of the created commits will be valid for.
- #description ⇒ String?
-
#duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits.
- #id ⇒ String
-
#invoice_amount ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit.
- #name ⇒ String?
- #priority ⇒ Float
- #product ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Product
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#rate_type ⇒ Symbol, MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::RateType
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
constructor
The amount the customer should be billed for the commit.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
The amount the customer should be billed for the commit.
|
|
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1472
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::AccessAmount
The amount of commit to grant.
1357 1358 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1357 required :access_amount, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1397 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1397 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1403 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1403 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::CommitDuration
The amount of time each of the created commits will be valid for
1364 1365 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1364 required :commit_duration, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::CommitDuration } |
#description ⇒ String?
1408 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1408 optional :description, String |
#duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits. optional
1415 1416 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1415 optional :duration, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Duration } |
#id ⇒ String
1351 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1351 required :id, String |
#invoice_amount ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit.
1422 1423 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1422 optional :invoice_amount, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::InvoiceAmount } |
#name ⇒ String?
1428 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1428 optional :name, String |
#priority ⇒ Float
1370 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1370 required :priority, Float |
#product ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Product
1375 1376 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1375 required :product, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Product } |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1435 1436 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1435 optional :proration, enum: -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::Proration } |
#rate_type ⇒ Symbol, MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::RateType
Whether the created commits will use the commit rate or list rate
1382 1383 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1382 required :rate_type, enum: -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit’s starting_at rather than the usage invoice dates.
1446 1447 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1446 optional :recurrence_frequency, enum: -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1455 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1455 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown.
1463 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1463 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifier] } |
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit
1390 1391 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1390 required :starting_at_offset, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::StartingAtOffset } |
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1469 1470 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1469 optional :subscription_config, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::RecurringCommit::SubscriptionConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 1563
|