Class: MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription
- Defined in:
- lib/metronome_sdk/models/v1/package_retrieve_response.rb
Defined Under Namespace
Modules: CollectionSchedule, QuantityManagementMode Classes: Duration, Proration, SeatConfig, StartingAtOffset, SubscriptionRate
Instance Attribute Summary collapse
- #collection_schedule ⇒ Symbol, MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::CollectionSchedule
-
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg.
- #description ⇒ String?
- #duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Duration?
- #fiat_credit_type_id ⇒ String?
- #id ⇒ String?
- #initial_quantity ⇒ Float?
- #name ⇒ String?
- #proration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Proration
-
#quantity_management_mode ⇒ Symbol, ...
Determines how the subscription’s quantity is controlled.
- #seat_config ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SeatConfig?
- #starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::StartingAtOffset?
- #subscription_rate ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SubscriptionRate
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(seat_group_key:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SeatConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(seat_group_key:) ⇒ Object
Some parameter documentations has been truncated, see SeatConfig for more details.
|
|
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2271
|
Instance Attribute Details
#collection_schedule ⇒ Symbol, MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::CollectionSchedule
2193 2194 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2193 required :collection_schedule, enum: -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::CollectionSchedule } |
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg. { “key1”: “value1”, “key2”: “value2” }
2217 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2217 optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String] |
#description ⇒ String?
2222 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2222 optional :description, String |
#duration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Duration?
2227 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2227 optional :duration, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Duration } |
#fiat_credit_type_id ⇒ String?
2232 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2232 optional :fiat_credit_type_id, String |
#id ⇒ String?
2211 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2211 optional :id, String |
#initial_quantity ⇒ Float?
2237 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2237 optional :initial_quantity, Float |
#name ⇒ String?
2242 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2242 optional :name, String |
#proration ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Proration
2199 2200 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2199 required :proration, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::Proration } |
#quantity_management_mode ⇒ Symbol, ...
Determines how the subscription’s quantity is controlled. Defaults to QUANTITY_ONLY. QUANTITY_ONLY: The subscription quantity is specified directly on the subscription. ‘initial_quantity` must be provided with this option. Compatible with recurring commits/credits that use POOLED allocation. SEAT_BASED: Use when you want to pass specific seat identifiers (e.g. add user_123) to increment and decrement a subscription quantity, rather than directly providing the quantity. You must use a SEAT_BASED subscription to use a linked recurring credit with an allocation per seat. `seat_config` must be provided with this option.
2256 2257 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2256 optional :quantity_management_mode, enum: -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::QuantityManagementMode } |
#seat_config ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SeatConfig?
2262 2263 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2262 optional :seat_config, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SeatConfig } |
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::StartingAtOffset?
2268 2269 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2268 optional :starting_at_offset, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::StartingAtOffset } |
#subscription_rate ⇒ MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SubscriptionRate
2205 2206 |
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2205 required :subscription_rate, -> { MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::SubscriptionRate } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/package_retrieve_response.rb', line 2309
|