Module: MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::QuantityManagementMode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/metronome_sdk/models/v1/package_retrieve_response.rb,
sig/metronome_sdk/models/v1/package_retrieve_response.rbs
Overview
Determines how the subscription's quantity is controlled. Defaults to
QUANTITY_ONLY. QUANTITY_ONLY: The subscription quantity is specified
directly on the subscription. initial_quantity must be provided with this
option. Compatible with recurring commits/credits that use POOLED allocation.
SEAT_BASED: Use when you want to pass specific seat identifiers (e.g. add
user_123) to increment and decrement a subscription quantity, rather than
directly providing the quantity. You must use a SEAT_BASED subscription to use a
linked recurring credit with an allocation per seat. seat_config must be
provided with this option.
Constant Summary collapse
- SEAT_BASED =
:SEAT_BASED- QUANTITY_ONLY =
:QUANTITY_ONLY
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::quantity_management_mode]
2806 |
# File 'sig/metronome_sdk/models/v1/package_retrieve_response.rbs', line 2806
def self?.values: -> ::Array[MetronomeSDK::Models::V1::PackageRetrieveResponse::Data::Subscription::quantity_management_mode]
|