Class: MetronomeSDK::Models::V1::UsageListParams::BillableMetric::GroupBy

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/usage_list_params.rb,
sig/metronome_sdk/models/v1/usage_list_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V1::UsageListParams::BillableMetric#group_by

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(key:, values: nil) ⇒ GroupBy

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::UsageListParams::BillableMetric::GroupBy for more details.

Parameters:

  • key (String)

    The name of the group_by key to use

  • values (Array<String>) (defaults to: nil)

    Values of the group_by key to return in the query. If this field is omitted, all

  • key: (String)
  • values: (::Array[String]) (defaults to: nil)


# File 'lib/metronome_sdk/models/v1/usage_list_params.rb', line 112

Instance Attribute Details

#keyString

The name of the group_by key to use

Parameters:

  • value (String)

Returns:

  • (String)


103
# File 'lib/metronome_sdk/models/v1/usage_list_params.rb', line 103

required :key, String

#valuesArray<String>?

Values of the group_by key to return in the query. If this field is omitted, all available values will be returned, up to a maximum of 200.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


110
# File 'lib/metronome_sdk/models/v1/usage_list_params.rb', line 110

optional :values, MetronomeSDK::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{ key: String, values: ::Array[String] }

Returns:

  • ({ key: String, values: ::Array[String] })


107
# File 'sig/metronome_sdk/models/v1/usage_list_params.rbs', line 107

def to_hash: -> { key: String, values: ::Array[String] }