Class: MetronomeSDK::Models::V1::UsageListWithGroupsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ending_before:, group_key:, group_value:, starting_on:, value:, group: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::UsageListWithGroupsResponse for more details.

Parameters:

  • ending_before (Time)
  • group_key (String, nil)

    Use ‘group` instead. The group key for single-key grouping.

  • group_value (String, nil)

    Use ‘group` instead. The group value for single-key grouping.

  • starting_on (Time)
  • value (Float, nil)
  • group (Hash{Symbol=>String}) (defaults to: nil)

    Map of group key to their value for this usage aggregate.



# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 48

Instance Attribute Details

#ending_beforeTime

Returns:

  • (Time)


11
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 11

required :ending_before, Time

#groupHash{Symbol=>String}?

Map of group key to their value for this usage aggregate. For simple group keys, this should be a single key e.g. ‘“US-East”` For compound group keys, this should contain the values of each group key that forms the compound e.g. `“US-East”, “team”: “engineering”`

Returns:

  • (Hash{Symbol=>String}, nil)


46
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 46

optional :group, MetronomeSDK::Internal::Type::HashOf[String]

#group_keyString?

Deprecated.

Use ‘group` instead. The group key for single-key grouping.

Returns:

  • (String, nil)


19
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 19

required :group_key, String, nil?: true

#group_valueString?

Deprecated.

Use ‘group` instead. The group value for single-key grouping.

Returns:

  • (String, nil)


27
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 27

required :group_value, String, nil?: true

#starting_onTime

Returns:

  • (Time)


32
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 32

required :starting_on, Time

#valueFloat?

Returns:

  • (Float, nil)


37
# File 'lib/metronome_sdk/models/v1/usage_list_with_groups_response.rb', line 37

required :value, Float, nil?: true