Class: MetronomeSDK::Models::V2::ContractEditCommitParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditCommitParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_commit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_commit_params.rbs
Overview
Defined Under Namespace
Modules: RateType Classes: AccessSchedule, InvoiceSchedule
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
- #access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCommitParams::AccessSchedule?
-
#applicable_contract_ids ⇒ Array<String>?
Which contracts the customer-level commit applies to.
-
#applicable_product_ids ⇒ Array<String>?
Which products the commit applies to.
-
#applicable_product_tags ⇒ Array<String>?
Which tags the commit applies to.
-
#commit_id ⇒ String
ID of the commit to edit.
-
#customer_id ⇒ String
ID of the customer whose commit is being edited.
-
#description ⇒ String?
Updated description for the commit.
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for commit hierarchy access control.
-
#invoice_contract_id ⇒ String?
ID of contract to use for invoicing.
- #invoice_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCommitParams::InvoiceSchedule?
-
#name ⇒ String?
Updated name for the commit.
-
#priority ⇒ Float?
If multiple commits are applicable, the one with the lower priority will apply first.
- #product_id ⇒ String?
-
#rate_type ⇒ Symbol, ...
If provided, updates the commit to use the specified rate type for current and future invoices.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(id:, amount: nil, quantity: nil, timestamp: nil, unit_price: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount: nil, quantity: nil, timestamp: nil, unit_price: nil) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 227
|
Instance Attribute Details
#access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCommitParams::AccessSchedule?
26 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 26 optional :access_schedule, -> { MetronomeSDK::V2::ContractEditCommitParams::AccessSchedule } |
#applicable_contract_ids ⇒ Array<String>?
Which contracts the customer-level commit applies to. If set to null, the commit applies to all of the customer's contracts. This field cannot be edited for POSTPAID commits or contract-level commits.
34 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 34 optional :applicable_contract_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_ids ⇒ Array<String>?
Which products the commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.
42 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 42 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_tags ⇒ Array<String>?
Which tags the commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.
50 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 50 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#commit_id ⇒ String
ID of the commit to edit
15 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 15 required :commit_id, String |
#customer_id ⇒ String
ID of the customer whose commit is being edited
21 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 21 required :customer_id, String |
#description ⇒ String?
Updated description for the commit
56 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 56 optional :description, String |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for commit hierarchy access control
62 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 62 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#invoice_contract_id ⇒ String?
ID of contract to use for invoicing
68 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 68 optional :invoice_contract_id, String |
#invoice_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCommitParams::InvoiceSchedule?
73 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 73 optional :invoice_schedule, -> { MetronomeSDK::V2::ContractEditCommitParams::InvoiceSchedule } |
#name ⇒ String?
Updated name for the commit
79 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 79 optional :name, String |
#priority ⇒ Float?
If multiple commits are applicable, the one with the lower priority will apply first.
86 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 86 optional :priority, Float, nil?: true |
#product_id ⇒ String?
91 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 91 optional :product_id, String |
#rate_type ⇒ Symbol, ...
If provided, updates the commit to use the specified rate type for current and future invoices. Previously finalized invoices will need to be voided and regenerated to reflect the rate type change.
99 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 99 optional :rate_type, enum: -> { MetronomeSDK::V2::ContractEditCommitParams::RateType } |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit
or credit. A customer's usage needs to meet the condition of at least one of the
specifiers to contribute to a commit's or credit's drawdown. This field cannot
be used together with applicable_product_ids or applicable_product_tags.
Instead, to target usage by product or product tag, pass those values in the
body of specifiers.
110 111 112 |
# File 'lib/metronome_sdk/models/v2/contract_edit_commit_params.rb', line 110 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
101 |
# File 'sig/metronome_sdk/models/v2/contract_edit_commit_params.rbs', line 101
def to_hash: -> {
|