Class: MetronomeSDK::Models::V2::ContractEditCreditParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditCreditParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_credit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_credit_params.rbs
Overview
Defined Under Namespace
Modules: RateType Classes: AccessSchedule
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
- #access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCreditParams::AccessSchedule?
-
#applicable_contract_ids ⇒ Array<String>?
Which contracts the customer-level credit applies to.
-
#applicable_product_ids ⇒ Array<String>?
Which products the credit applies to.
-
#applicable_product_tags ⇒ Array<String>?
Which tags the credit applies to.
-
#credit_id ⇒ String
ID of the credit to edit.
-
#customer_id ⇒ String
ID of the customer whose credit is being edited.
-
#description ⇒ String?
Updated description for the credit.
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control.
-
#name ⇒ String?
Updated name for the credit.
-
#priority ⇒ Float?
If multiple commits are applicable, the one with the lower priority will apply first.
- #product_id ⇒ String?
-
#rate_type ⇒ Symbol, ...
If provided, updates the credit to use the specified rate type for current and future invoices.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(id:, amount: nil, ending_before: nil, starting_at: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount: nil, ending_before: nil, starting_at: nil) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 210
|
Instance Attribute Details
#access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditCreditParams::AccessSchedule?
26 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 26 optional :access_schedule, -> { MetronomeSDK::V2::ContractEditCreditParams::AccessSchedule } |
#applicable_contract_ids ⇒ Array<String>?
Which contracts the customer-level credit applies to. If set to null, the credit applies to all of the customer's contracts. This field cannot be set on a contract-level credit.
34 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 34 optional :applicable_contract_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_ids ⇒ Array<String>?
Which products the credit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the credit applies to all products.
41 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 41 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_tags ⇒ Array<String>?
Which tags the credit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the credit applies to all products.
48 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 48 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#credit_id ⇒ String
ID of the credit to edit
15 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 15 required :credit_id, String |
#customer_id ⇒ String
ID of the customer whose credit is being edited
21 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 21 required :customer_id, String |
#description ⇒ String?
Updated description for the credit
54 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 54 optional :description, String |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control
60 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 60 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#name ⇒ String?
Updated name for the credit
66 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 66 optional :name, String |
#priority ⇒ Float?
If multiple commits are applicable, the one with the lower priority will apply first.
73 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 73 optional :priority, Float, nil?: true |
#product_id ⇒ String?
78 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 78 optional :product_id, String |
#rate_type ⇒ Symbol, ...
If provided, updates the credit to use the specified rate type for current and future invoices. Previously finalized invoices will need to be voided and regenerated to reflect the rate type change.
86 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 86 optional :rate_type, enum: -> { MetronomeSDK::V2::ContractEditCreditParams::RateType } |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit
or credit. A customer's usage needs to meet the condition of at least one of the
specifiers to contribute to a commit's or credit's drawdown. This field cannot
be used together with applicable_product_ids or applicable_product_tags.
Instead, to target usage by product or product tag, pass those values in the
body of specifiers.
97 98 99 |
# File 'lib/metronome_sdk/models/v2/contract_edit_credit_params.rb', line 97 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
87 |
# File 'sig/metronome_sdk/models/v2/contract_edit_credit_params.rbs', line 87
def to_hash: -> {
|