Class: MetronomeSDK::Models::V2::ContractEditParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb
Overview
Defined Under Namespace
Classes: AddBillingProviderConfigurationUpdate, AddCommit, AddCredit, AddDiscount, AddOverride, AddProfessionalService, AddRecurringCommit, AddRecurringCredit, AddResellerRoyalty, AddRevenueSystemConfigurationUpdate, AddScheduledCharge, AddSubscription, ArchiveCommit, ArchiveCredit, ArchiveScheduledCharge, RemoveOverride, UpdateCommit, UpdateCredit, UpdatePrepaidBalanceThresholdConfiguration, UpdateRecurringCommit, UpdateRecurringCredit, UpdateScheduledCharge, UpdateSpendThresholdConfiguration, UpdateSubscription
Instance Attribute Summary collapse
-
#add_billing_provider_configuration_update ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate?
Update the billing provider configuration on the contract.
- #add_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddCommit>?
- #add_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddCredit>?
- #add_discounts ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddDiscount>?
- #add_overrides ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddOverride>?
- #add_prepaid_balance_threshold_configuration ⇒ MetronomeSDK::Models::PrepaidBalanceThresholdConfigurationV2?
-
#add_professional_services ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddProfessionalService>?
This field’s availability is dependent on your client’s configuration.
- #add_recurring_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit>?
- #add_recurring_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCredit>?
- #add_reseller_royalties ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddResellerRoyalty>?
-
#add_revenue_system_configuration_update ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate?
Update the revenue system configuration on the contract.
- #add_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge>?
- #add_spend_threshold_configuration ⇒ MetronomeSDK::Models::SpendThresholdConfigurationV2?
-
#add_subscriptions ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddSubscription>?
Optional list of [subscriptions](docs.metronome.com/manage-product-access/create-subscription/) to add to the contract.
-
#allow_contract_ending_before_finalized_invoice ⇒ Boolean?
If true, allows setting the contract end date earlier than the end_timestamp of existing finalized invoices.
-
#archive_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveCommit>?
IDs of commits to archive.
-
#archive_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveCredit>?
IDs of credits to archive.
-
#archive_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveScheduledCharge>?
IDs of scheduled charges to archive.
-
#contract_id ⇒ String
ID of the contract being edited.
-
#customer_id ⇒ String
ID of the customer whose contract is being edited.
-
#remove_overrides ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::RemoveOverride>?
IDs of overrides to remove.
-
#uniqueness_key ⇒ String?
Optional uniqueness key to prevent duplicate contract edits.
- #update_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateCommit>?
-
#update_contract_end_date ⇒ Time?
RFC 3339 timestamp indicating when the contract will end (exclusive).
-
#update_contract_name ⇒ String?
Value to update the contract name to.
- #update_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateCredit>?
-
#update_net_payment_terms_days ⇒ Float?
Number of days after issuance of invoice after which the invoice is due (e.g. Net 30).
- #update_prepaid_balance_threshold_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration?
-
#update_recurring_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateRecurringCommit>?
Edits to these recurring commits will only affect commits whose access schedules has not started.
-
#update_recurring_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateRecurringCredit>?
Edits to these recurring credits will only affect credits whose access schedules has not started.
- #update_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateScheduledCharge>?
- #update_spend_threshold_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration?
-
#update_subscriptions ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription>?
Optional list of subscriptions to update.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(payment_fraction: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateSpendThresholdConfiguration::DiscountConfiguration for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(payment_fraction: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration::DiscountConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1407
|
Instance Attribute Details
#add_billing_provider_configuration_update ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate?
Update the billing provider configuration on the contract. Currently only supports adding a billing provider configuration to a contract that does not already have one.
29 30 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 29 optional :add_billing_provider_configuration_update, -> { MetronomeSDK::V2::ContractEditParams::AddBillingProviderConfigurationUpdate } |
#add_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddCommit>?
35 36 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 35 optional :add_commits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddCommit] } |
#add_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddCredit>?
41 42 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 41 optional :add_credits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddCredit] } |
#add_discounts ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddDiscount>?
47 48 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 47 optional :add_discounts, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddDiscount] } |
#add_overrides ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddOverride>?
53 54 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 53 optional :add_overrides, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddOverride] } |
#add_prepaid_balance_threshold_configuration ⇒ MetronomeSDK::Models::PrepaidBalanceThresholdConfigurationV2?
59 60 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 59 optional :add_prepaid_balance_threshold_configuration, -> { MetronomeSDK::PrepaidBalanceThresholdConfigurationV2 } |
#add_professional_services ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddProfessionalService>?
This field’s availability is dependent on your client’s configuration.
66 67 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 66 optional :add_professional_services, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddProfessionalService] } |
#add_recurring_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit>?
72 73 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 72 optional :add_recurring_commits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddRecurringCommit] } |
#add_recurring_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCredit>?
78 79 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 78 optional :add_recurring_credits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddRecurringCredit] } |
#add_reseller_royalties ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddResellerRoyalty>?
84 85 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 84 optional :add_reseller_royalties, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddResellerRoyalty] } |
#add_revenue_system_configuration_update ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate?
Update the revenue system configuration on the contract. Currently only supports adding a revenue system configuration to a contract that does not already have one.
93 94 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 93 optional :add_revenue_system_configuration_update, -> { MetronomeSDK::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate } |
#add_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge>?
99 100 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 99 optional :add_scheduled_charges, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddScheduledCharge] } |
#add_spend_threshold_configuration ⇒ MetronomeSDK::Models::SpendThresholdConfigurationV2?
105 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 105 optional :add_spend_threshold_configuration, -> { MetronomeSDK::SpendThresholdConfigurationV2 } |
#add_subscriptions ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddSubscription>?
Optional list of [subscriptions](docs.metronome.com/manage-product-access/create-subscription/) to add to the contract.
113 114 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 113 optional :add_subscriptions, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddSubscription] } |
#allow_contract_ending_before_finalized_invoice ⇒ Boolean?
If true, allows setting the contract end date earlier than the end_timestamp of existing finalized invoices. Finalized invoices will be unchanged; if you want to incorporate the new end date, you can void and regenerate finalized usage invoices. Defaults to true.
123 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 123 optional :allow_contract_ending_before_finalized_invoice, MetronomeSDK::Internal::Type::Boolean |
#archive_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveCommit>?
IDs of commits to archive
129 130 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 129 optional :archive_commits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::ArchiveCommit] } |
#archive_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveCredit>?
IDs of credits to archive
136 137 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 136 optional :archive_credits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::ArchiveCredit] } |
#archive_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::ArchiveScheduledCharge>?
IDs of scheduled charges to archive
143 144 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 143 optional :archive_scheduled_charges, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::ArchiveScheduledCharge] } |
#contract_id ⇒ String
ID of the contract being edited
15 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 15 required :contract_id, String |
#customer_id ⇒ String
ID of the customer whose contract is being edited
21 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 21 required :customer_id, String |
#remove_overrides ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::RemoveOverride>?
IDs of overrides to remove
150 151 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 150 optional :remove_overrides, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::RemoveOverride] } |
#uniqueness_key ⇒ String?
Optional uniqueness key to prevent duplicate contract edits.
157 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 157 optional :uniqueness_key, String |
#update_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateCommit>?
162 163 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 162 optional :update_commits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateCommit] } |
#update_contract_end_date ⇒ Time?
RFC 3339 timestamp indicating when the contract will end (exclusive).
169 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 169 optional :update_contract_end_date, Time, nil?: true |
#update_contract_name ⇒ String?
Value to update the contract name to. If not provided, the contract name will remain unchanged.
176 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 176 optional :update_contract_name, String, nil?: true |
#update_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateCredit>?
181 182 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 181 optional :update_credits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateCredit] } |
#update_net_payment_terms_days ⇒ Float?
Number of days after issuance of invoice after which the invoice is due (e.g. Net 30).
189 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 189 optional :update_net_payment_terms_days, Float, nil?: true |
#update_prepaid_balance_threshold_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration?
194 195 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 194 optional :update_prepaid_balance_threshold_configuration, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration } |
#update_recurring_commits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateRecurringCommit>?
Edits to these recurring commits will only affect commits whose access schedules has not started. Expired commits, and commits with an active access schedule will remain unchanged.
203 204 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 203 optional :update_recurring_commits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateRecurringCommit] } |
#update_recurring_credits ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateRecurringCredit>?
Edits to these recurring credits will only affect credits whose access schedules has not started. Expired credits, and credits with an active access schedule will remain unchanged.
212 213 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 212 optional :update_recurring_credits, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateRecurringCredit] } |
#update_scheduled_charges ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateScheduledCharge>?
218 219 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 218 optional :update_scheduled_charges, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateScheduledCharge] } |
#update_spend_threshold_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration?
224 225 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 224 optional :update_spend_threshold_configuration, -> { MetronomeSDK::V2::ContractEditParams::UpdateSpendThresholdConfiguration } |
#update_subscriptions ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription>?
Optional list of subscriptions to update.
231 232 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 231 optional :update_subscriptions, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 413
|