Class: MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate::Schedule

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate#schedule

Defined Under Namespace

Modules: EffectiveAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(effective_at:) ⇒ Object

Indicates when the billing provider will be active on the contract. Any charges accrued during the schedule will be billed to the indicated billing provider.

Parameters:



# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 417

Instance Attribute Details

#effective_atSymbol, MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate::Schedule::EffectiveAt

When the billing provider update will take effect.

Parameters:

  • value (MetronomeSDK::Models::V2::ContractEditParams::AddBillingProviderConfigurationUpdate::Schedule::effective_at)

Returns:



414
415
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 414

required :effective_at,
enum: -> { MetronomeSDK::V2::ContractEditParams::AddBillingProviderConfigurationUpdate::Schedule::EffectiveAt }

Instance Method Details

#to_hash{

Returns:

  • ({)


421
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 421

def to_hash: -> {