Class: MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs

Overview

See Also:

  • MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig#stripe_config

Defined Under Namespace

Modules: PaymentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(payment_type:, invoice_metadata: nil, on_session_payment: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig for more details.

Only applicable if using STRIPE as your payment gateway type.

Parameters:



# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 987

Instance Attribute Details

#invoice_metadataHash{Symbol=>String}?

Metadata to be added to the Stripe invoice. Only applicable if using INVOICE as your payment type.

Returns:

  • (Hash{Symbol=>String}, nil)


972
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 972

optional :invoice_metadata, MetronomeSDK::Internal::Type::HashOf[String]

#on_session_paymentBoolean?

If true, the payment will be made assuming the customer is present (i.e. on session).

If false, the payment will be made assuming the customer is not present (i.e. off session). For cardholders from a country with an e-mandate requirement (e.g. India), the payment may be declined.

If left blank, will default to false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


985
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 985

optional :on_session_payment, MetronomeSDK::Internal::Type::Boolean

#payment_typeSymbol, MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig::PaymentType

If left blank, will default to INVOICE

Parameters:

  • value (MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig::payment_type)

Returns:



964
965
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 964

required :payment_type,
enum: -> { MetronomeSDK::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig::PaymentType }

Instance Method Details

#to_hash{

Returns:

  • ({)


908
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 908

def to_hash: -> {