Class: MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, InvoiceAmount, ProrationRounding, SubscriptionConfig
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::CommitDuration
Defines the length of the access schedule for each created commit/credit.
-
#description ⇒ String?
Will be passed down to the individual commits.
-
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits.
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control.
-
#invoice_amount ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit.
-
#name ⇒ String?
displayed on invoices.
-
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits.
-
#priority ⇒ Float
Will be passed down to the individual commits.
- #product_id ⇒ String
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::ProrationRounding?
Optional rounding configuration for prorated recurring commit amounts.
-
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at ⇒ Time
determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
-
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
constructor
The amount the customer should be billed for the commit.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
The amount the customer should be billed for the commit. Not required.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2022
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::AccessAmount
The amount of commit to grant.
1882 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1882 required :access_amount, -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1913 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1913 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1919 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1919 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::CommitDuration
Defines the length of the access schedule for each created commit/credit. The value represents the number of units. Unit defaults to "PERIODS", where the length of a period is determined by the recurrence_frequency.
1890 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1890 required :commit_duration, -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::CommitDuration } |
#description ⇒ String?
Will be passed down to the individual commits
1925 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1925 optional :description, String |
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits. optional
1931 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1931 optional :ending_before, Time |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control
1937 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1937 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#invoice_amount ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit. Not required.
1943 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1943 optional :invoice_amount, -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::InvoiceAmount } |
#name ⇒ String?
displayed on invoices. will be passed through to the individual commits
1949 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1949 optional :name, String |
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits
1955 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1955 optional :netsuite_sales_order_id, String |
#priority ⇒ Float
Will be passed down to the individual commits
1896 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1896 required :priority, Float |
#product_id ⇒ String
1901 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1901 required :product_id, String |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1962 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1962 optional :proration, enum: -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::Proration } |
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::ProrationRounding?
Optional rounding configuration for prorated recurring commit amounts.
1968 1969 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1968 optional :proration_rounding, -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::ProrationRounding } |
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate
1975 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1975 optional :rate_type, enum: -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit's starting_at rather than the usage invoice dates. - Daily recurring commits have a limit of one per contract, and are unable to be created with seat-based subscriptions
1986 1987 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1986 optional :recurrence_frequency, enum: -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1995 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1995 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit
or credit. A customer's usage needs to meet the condition of at least one of the
specifiers to contribute to a commit's or credit's drawdown. This field cannot
be used together with applicable_product_ids or applicable_product_tags.
Instead, to target usage by product or product tag, pass those values in the
body of specifiers.
2006 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2006 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] } |
#starting_at ⇒ Time
determines the start time for the first commit
1907 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1907 required :starting_at, Time |
#subscription_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRecurringCommit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
2012 2013 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2012 optional :subscription_config, -> { MetronomeSDK::V2::ContractEditParams::AddRecurringCommit::SubscriptionConfig } |
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
2020 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2020 optional :temporary_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2129
|
Instance Method Details
#to_hash ⇒ {
1838 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 1838
def to_hash: -> {
|