Class: MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Overview
Defined Under Namespace
Modules: AmountDistribution, Frequency
Instance Attribute Summary collapse
-
#amount ⇒ Float?
Amount for the charge.
- #amount_distribution ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::AmountDistribution
-
#ending_before ⇒ Time
RFC 3339 timestamp (exclusive).
- #frequency ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::Frequency
-
#quantity ⇒ Float?
Quantity for the charge.
-
#starting_at ⇒ Time
RFC 3339 timestamp (inclusive).
-
#unit_price ⇒ Float?
Unit price for the charge.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RecurringSchedule for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule for more details.
Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3147
|
Instance Attribute Details
#amount ⇒ Float?
Amount for the charge. Can be provided instead of unit_price and quantity. If amount is sent, the unit_price is assumed to be the amount and quantity is inferred to be 1.
3129 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3129 optional :amount, Float |
#amount_distribution ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::AmountDistribution
3102 3103 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3102 required :amount_distribution, enum: -> { MetronomeSDK::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::AmountDistribution } |
#ending_before ⇒ Time
RFC 3339 timestamp (exclusive).
3109 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3109 required :ending_before, Time |
#frequency ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::Frequency
3114 3115 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3114 required :frequency, enum: -> { MetronomeSDK::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule::Frequency } |
#quantity ⇒ Float?
Quantity for the charge. Will be multiplied by unit_price to determine the amount and must be specified with unit_price. If specified amount cannot be provided.
3137 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3137 optional :quantity, Float |
#starting_at ⇒ Time
RFC 3339 timestamp (inclusive).
3121 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3121 required :starting_at, Time |
#unit_price ⇒ Float?
Unit price for the charge. Will be multiplied by quantity to determine the amount and must be specified with quantity. If specified amount cannot be provided.
3145 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3145 optional :unit_price, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3178
|
Instance Method Details
#to_hash ⇒ {
2886 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 2886
def to_hash: -> {
|