Class: MetronomeSDK::Models::V2::ContractEditParams::AddSubscription::BillingCycleConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddSubscription::BillingCycleConfig
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Overview
Defined Under Namespace
Modules: InvoicePlacement
Instance Attribute Summary collapse
-
#anchor_date ⇒ Time?
The date to anchor the billing cycle to.
-
#invoice_placement ⇒ Symbol, ...
Controls whether this subscription consolidates onto usage invoices or gets its own scheduled invoice.
Instance Method Summary collapse
-
#initialize(anchor_date: nil, invoice_placement: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingCycleConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anchor_date: nil, invoice_placement: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::AddSubscription::BillingCycleConfig for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3630
|
Instance Attribute Details
#anchor_date ⇒ Time?
The date to anchor the billing cycle to. If omitted, defaults to the contract's usage invoice billing cycle anchor date.
3620 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3620 optional :anchor_date, Time |
#invoice_placement ⇒ Symbol, ...
Controls whether this subscription consolidates onto usage invoices or gets its own scheduled invoice. Defaults to ON_USAGE_INVOICE if omitted.
3627 3628 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3627 optional :invoice_placement, enum: -> { MetronomeSDK::V2::ContractEditParams::AddSubscription::BillingCycleConfig::InvoicePlacement } |
Instance Method Details
#to_hash ⇒ {
3323 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 3323
def to_hash: -> {
|