Class: MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Defined Under Namespace
Classes: Commit, DiscountConfiguration, ThresholdBalanceSpecifier
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
- #commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
-
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
- #discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
-
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount.
- #payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
-
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
-
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract.
-
#threshold_balance_specifiers ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier>?
Determines which balances are excluded from remaining balance calculation for threshold billing.
Instance Method Summary collapse
-
#initialize(amount:, spend_tracker_alias:) ⇒ Object
constructor
Update the discount cap.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, spend_tracker_alias:) ⇒ Object
Update the discount cap. Set to null to remove an existing cap.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4326
|
Instance Attribute Details
#commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
4268 4269 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4268 optional :commit, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit } |
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
4276 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4276 optional :custom_credit_type_id, String, nil?: true |
#discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
4281 4282 4283 4284 4285 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4281 optional :discount_configuration, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration }, nil?: true |
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.
4293 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4293 optional :is_enabled, MetronomeSDK::Internal::Type::Boolean |
#payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
4298 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4298 optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 } |
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
4304 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4304 optional :recharge_to_amount, Float |
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract. Each time the contract's balance lowers to this amount, a threshold charge will be initiated.
4311 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4311 optional :threshold_amount, Float |
#threshold_balance_specifiers ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier>?
Determines which balances are excluded from remaining balance calculation for threshold billing.
4318 4319 4320 4321 4322 4323 4324 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4318 optional :threshold_balance_specifiers, -> do MetronomeSDK::Internal::Type::ArrayOf[ MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier ] end, nil?: true |
Instance Method Details
#to_hash ⇒ {
4034 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 4034
def to_hash: -> {
|