Class: MetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_params.rb

Defined Under Namespace

Classes: DiscountConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(commit: nil, discount_configuration: nil, is_enabled: nil, payment_gate_config: nil, threshold_amount: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration for more details.

Parameters:



# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4277

Instance Attribute Details

#commitMetronomeSDK::Models::UpdateBaseThresholdCommit?



4246
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4246

optional :commit, -> { MetronomeSDK::UpdateBaseThresholdCommit }

#discount_configurationMetronomeSDK::Models::V2::ContractEditParams::UpdateSpendThresholdConfiguration::DiscountConfiguration?



4251
4252
4253
4254
4255
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4251

optional :discount_configuration,
-> {
  MetronomeSDK::V2::ContractEditParams::UpdateSpendThresholdConfiguration::DiscountConfiguration
},
nil?: true

#is_enabledBoolean?

When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.

Returns:

  • (Boolean, nil)


4263
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4263

optional :is_enabled, MetronomeSDK::Internal::Type::Boolean

#payment_gate_configMetronomeSDK::Models::PaymentGateConfigV2?



4268
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4268

optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 }

#threshold_amountFloat?

Specify the threshold amount for the contract. Each time the contract’s usage hits this amount, a threshold charge will be initiated.

Returns:

  • (Float, nil)


4275
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4275

optional :threshold_amount, Float