Class: MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_params.rb

Defined Under Namespace

Classes: QuantityManagementModeUpdate, QuantityUpdate, SeatUpdates

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(starting_at:, quantity: nil, quantity_delta: nil) ⇒ Object

Some parameter documentations has been truncated, see QuantityUpdate for more details.

Parameters:

  • starting_at (Time)
  • quantity (Float) (defaults to: nil)

    The new quantity for the subscription. Must be provided if quantity_delta is not

  • quantity_delta (Float) (defaults to: nil)

    The delta to add to the subscription’s quantity. Must be provided if quantity is



# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4344

Instance Attribute Details

#ending_beforeTime?

Returns:

  • (Time, nil)


4320
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4320

optional :ending_before, Time, nil?: true

#quantity_management_mode_updateMetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::QuantityManagementModeUpdate?

Update the subscription’s quantity management mode from QUANTITY_ONLY to SEAT_BASED with the provided seat_group_key.



4327
4328
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4327

optional :quantity_management_mode_update,
-> { MetronomeSDK::V2::ContractEditParams::UpdateSubscription::QuantityManagementModeUpdate }

#quantity_updatesArray<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::QuantityUpdate>?

Quantity changes are applied on the effective date based on the order which they are sent. For example, if I scheduled the quantity to be 12 on May 21 and then scheduled a quantity delta change of -1, the result from that day would be 11.



4336
4337
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4336

optional :quantity_updates,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription::QuantityUpdate] }

#seat_updatesMetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates?



4342
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4342

optional :seat_updates, -> { MetronomeSDK::V2::ContractEditParams::UpdateSubscription::SeatUpdates }

#subscription_idString

Returns:

  • (String)


4315
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4315

required :subscription_id, String