Class: MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(quantity:, starting_at:) ⇒ RemoveUnassignedSeat

Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat for more details.

Parameters:

  • quantity (Float)

    The number of unassigned seats on the subscription will increase/decrease by thi

  • starting_at (Time)

    Unassigned seats will be updated starting at this date.

  • quantity: (Float)
  • starting_at: (Time)


# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5365

Instance Attribute Details

#quantityFloat

The number of unassigned seats on the subscription will increase/decrease by this delta. Must be greater than 0.

Parameters:

  • value (Float)

Returns:

  • (Float)


5357
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5357

required :quantity, Float

#starting_atTime

Unassigned seats will be updated starting at this date.

Parameters:

  • value (Time)

Returns:

  • (Time)


5363
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5363

required :starting_at, Time

Instance Method Details

#to_hash{ quantity: Float, starting_at: Time }

Returns:

  • ({ quantity: Float, starting_at: Time })


5014
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 5014

def to_hash: -> { quantity: Float, starting_at: Time }