Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Contract, Product, ProrationRounding
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::CommitDuration
The amount of time the created commits will be valid for.
- #contract ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Contract?
-
#description ⇒ String?
Will be passed down to the individual commits.
-
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits.
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control.
- #id ⇒ String
-
#name ⇒ String?
Displayed on invoices.
-
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits.
-
#priority ⇒ Float
Will be passed down to the individual commits.
- #product ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Product
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::ProrationRounding?
Rounding configuration for prorated recurring credit amounts.
-
#rate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::RateType
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at ⇒ Time
Determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1581
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::AccessAmount
The amount of commit to grant.
1448 1449 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1448 required :access_amount, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1487 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1487 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1493 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1493 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::CommitDuration
The amount of time the created commits will be valid for
1455 1456 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1455 required :commit_duration, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::CommitDuration } |
#contract ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Contract?
1498 1499 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1498 optional :contract, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Contract } |
#description ⇒ String?
Will be passed down to the individual commits
1505 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1505 optional :description, String |
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits. Optional
1511 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1511 optional :ending_before, Time |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control
1517 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1517 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#id ⇒ String
1442 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1442 required :id, String |
#name ⇒ String?
Displayed on invoices. Will be passed through to the individual commits
1523 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1523 optional :name, String |
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits
1529 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1529 optional :netsuite_sales_order_id, String |
#priority ⇒ Float
Will be passed down to the individual commits
1462 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1462 required :priority, Float |
#product ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Product
1467 1468 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1467 required :product, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Product } |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1536 1537 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1536 optional :proration, enum: -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::Proration } |
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::ProrationRounding?
Rounding configuration for prorated recurring credit amounts.
1543 1544 1545 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1543 optional :proration_rounding, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::ProrationRounding }, nil?: true |
#rate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::RateType
Whether the created commits will use the commit rate or list rate
1474 1475 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1474 required :rate_type, enum: -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit's starting_at rather than the usage invoice dates. - Daily recurring commits have a limit of one per contract, and are unable to be created with seat-based subscriptions
1556 1557 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1556 optional :recurrence_frequency, enum: -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::AddRecurringCredit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1565 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1565 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer's usage needs to meet the condition of at least one of the specifiers to contribute to a commit's or credit's drawdown.
1573 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1573 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifier] } |
#starting_at ⇒ Time
Determines the start time for the first commit
1481 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1481 required :starting_at, Time |
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1579 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1579 optional :subscription_config, -> { MetronomeSDK::RecurringCommitSubscriptionConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 1678
|
Instance Method Details
#to_hash ⇒ {
1596 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 1596
def to_hash: -> {
|