Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs
Defined Under Namespace
Modules: RateType Classes: AccessSchedule
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
- #access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit::AccessSchedule?
-
#applicable_product_ids ⇒ Array<String>?
Which products the credit applies to.
-
#applicable_product_tags ⇒ Array<String>?
Which tags the credit applies to.
- #description ⇒ String?
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control.
- #id ⇒ String
- #name ⇒ String?
- #netsuite_sales_order_id ⇒ String?
-
#priority ⇒ Float?
If multiple credits are applicable, the one with the lower priority will apply first.
- #product_id ⇒ String?
-
#rate_type ⇒ Symbol, ...
If set, the credit's rate type was updated to the specified value.
- #rollover_fraction ⇒ Float?
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
Instance Method Summary collapse
- #initialize(id:, amount: nil, ending_before: nil, starting_at: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount: nil, ending_before: nil, starting_at: nil) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2932
|
Instance Attribute Details
#access_schedule ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit::AccessSchedule?
2855 2856 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2855 optional :access_schedule, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit::AccessSchedule } |
#applicable_product_ids ⇒ Array<String>?
Which products the credit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the credit applies to all products.
2864 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2864 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_tags ⇒ Array<String>?
Which tags the credit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the credit applies to all products.
2872 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2872 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#description ⇒ String?
2877 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2877 optional :description, String |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control
2883 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2883 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#id ⇒ String
2850 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2850 required :id, String |
#name ⇒ String?
2888 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2888 optional :name, String |
#netsuite_sales_order_id ⇒ String?
2893 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2893 optional :netsuite_sales_order_id, String, nil?: true |
#priority ⇒ Float?
If multiple credits are applicable, the one with the lower priority will apply first.
2900 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2900 optional :priority, Float, nil?: true |
#product_id ⇒ String?
2905 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2905 optional :product_id, String |
#rate_type ⇒ Symbol, ...
If set, the credit's rate type was updated to the specified value.
2911 2912 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2911 optional :rate_type, enum: -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateCredit::RateType } |
#rollover_fraction ⇒ Float?
2917 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2917 optional :rollover_fraction, Float, nil?: true |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit
or credit. A customer's usage needs to meet the condition of at least one of the
specifiers to contribute to a commit's or credit's drawdown. This field cannot
be used together with applicable_product_ids or applicable_product_tags.
Instead, to target usage by product or product tag, pass those values in the
body of specifiers.
2928 2929 2930 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 2928 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
2882 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 2882
def to_hash: -> {
|