Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdatePrepaidBalanceThresholdConfiguration::Commit

Inherits:
UpdateBaseThresholdCommit show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs

Overview

See Also:

  • MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdatePrepaidBalanceThresholdConfiguration#commit

Instance Attribute Summary collapse

Attributes inherited from UpdateBaseThresholdCommit

#description, #name, #priority, #product_id

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



3322
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 3322

def initialize: (

Instance Attribute Details

#applicable_product_idsArray<String>?

Which products the threshold commit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the commit applies to all products.

Returns:

  • (Array<String>, nil)


3399
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3399

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true

#applicable_product_tagsArray<String>?

Which tags the threshold commit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the commit applies to all products.

Returns:

  • (Array<String>, nil)


3406
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3406

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true

#specifiersArray<MetronomeSDK::Models::CommitSpecifierInput>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer's usage needs to meet the condition of at least one of the specifiers to contribute to a commit's or credit's drawdown. This field cannot be used together with applicable_product_ids or applicable_product_tags. Instead, to target usage by product or product tag, pass those values in the body of specifiers.



3417
3418
3419
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3417

optional :specifiers,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] },
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


3328
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 3328

def to_hash: -> {