Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb
Overview
Defined Under Namespace
Classes: Cap
Instance Attribute Summary collapse
-
#cap ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration::Cap?
Update the discount cap.
-
#payment_fraction ⇒ Float?
The fraction of the original amount that the customer pays after applying the discount.
Instance Method Summary collapse
-
#initialize(cap: nil, payment_fraction: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DiscountConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cap: nil, payment_fraction: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3639
|
Instance Attribute Details
#cap ⇒ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration::Cap?
Update the discount cap. Set to null to remove an existing cap.
3627 3628 3629 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3627 optional :cap, -> { MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSpendThresholdConfiguration::DiscountConfiguration::Cap }, nil?: true |
#payment_fraction ⇒ Float?
The fraction of the original amount that the customer pays after applying the discount. Set to null to remove the discount fraction. For example, 0.85 means the customer pays 85% of the original amount (a 15% discount).
3637 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3637 optional :payment_fraction, Float, nil?: true |