Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs
Instance Attribute Summary collapse
-
#quantity ⇒ Float
The number of unassigned seats on the subscription will increase/decrease by this delta.
-
#starting_at ⇒ Time
Unassigned seats will be updated starting at this date.
Instance Method Summary collapse
-
#initialize ⇒ AddUnassignedSeat
constructor
A new instance of AddUnassignedSeat.
- #to_hash ⇒ { quantity: Float, starting_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ AddUnassignedSeat
Returns a new instance of AddUnassignedSeat.
4183 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 4183
def initialize: (quantity: Float, starting_at: Time) -> void
|
Instance Attribute Details
#quantity ⇒ Float
The number of unassigned seats on the subscription will increase/decrease by this delta. Must be greater than 0.
4259 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4259 required :quantity, Float |
#starting_at ⇒ Time
Unassigned seats will be updated starting at this date.
4265 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4265 required :starting_at, Time |
Instance Method Details
#to_hash ⇒ { quantity: Float, starting_at: Time }
4185 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 4185
def to_hash: -> { quantity: Float, starting_at: Time }
|