Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs
Instance Attribute Summary collapse
-
#quantity ⇒ Float
The number of unassigned seats on the subscription will increase/decrease by this delta.
-
#starting_at ⇒ Time
Unassigned seats will be updated starting at this date.
Instance Method Summary collapse
-
#initialize(quantity:, starting_at:) ⇒ RemoveUnassignedSeat
constructor
Some parameter documentations has been truncated, see RemoveUnassignedSeat for more details.
- #to_hash ⇒ { quantity: Float, starting_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(quantity:, starting_at:) ⇒ RemoveUnassignedSeat
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4309
|
Instance Attribute Details
#quantity ⇒ Float
The number of unassigned seats on the subscription will increase/decrease by this delta. Must be greater than 0.
4301 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4301 required :quantity, Float |
#starting_at ⇒ Time
Unassigned seats will be updated starting at this date.
4307 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4307 required :starting_at, Time |
Instance Method Details
#to_hash ⇒ { quantity: Float, starting_at: Time }
4217 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 4217
def to_hash: -> { quantity: Float, starting_at: Time }
|