Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Contract, InvoiceAmount, Product, ProrationRounding
Constant Summary collapse
- MetronomeSDK =
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration
The amount of time the created commits will be valid for.
- #contract ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Contract?
-
#description ⇒ String?
Will be passed down to the individual commits.
-
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits.
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control.
- #id ⇒ String
-
#invoice_amount ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit.
-
#name ⇒ String?
Displayed on invoices.
-
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits.
-
#priority ⇒ Float
Will be passed down to the individual commits.
- #product ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Product
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::ProrationRounding?
Rounding configuration for prorated recurring commit amounts.
-
#rate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RateType
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at ⇒ Time
Determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
constructor
The amount the customer should be billed for the commit.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object
The amount the customer should be billed for the commit. Not required.
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1124
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::AccessAmount
The amount of commit to grant.
984 985 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 984 required :access_amount, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1023 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1023 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1029 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1029 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration
The amount of time the created commits will be valid for
991 992 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 991 required :commit_duration, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration } |
#contract ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Contract?
1034 1035 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1034 optional :contract, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Contract } |
#description ⇒ String?
Will be passed down to the individual commits
1041 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1041 optional :description, String |
#ending_before ⇒ Time?
Determines when the contract will stop creating recurring commits. Optional
1047 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1047 optional :ending_before, Time |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for recurring credit hierarchy access control
1053 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1053 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#id ⇒ String
978 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 978 required :id, String |
#invoice_amount ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::InvoiceAmount?
The amount the customer should be billed for the commit. Not required.
1059 1060 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1059 optional :invoice_amount, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::InvoiceAmount } |
#name ⇒ String?
Displayed on invoices. Will be passed through to the individual commits
1066 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1066 optional :name, String |
#netsuite_sales_order_id ⇒ String?
Will be passed down to the individual commits
1072 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1072 optional :netsuite_sales_order_id, String |
#priority ⇒ Float
Will be passed down to the individual commits
998 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 998 required :priority, Float |
#product ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Product
1003 1004 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1003 required :product, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Product } |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1079 1080 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1079 optional :proration, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Proration } |
#proration_rounding ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::ProrationRounding?
Rounding configuration for prorated recurring commit amounts.
1086 1087 1088 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1086 optional :proration_rounding, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::ProrationRounding }, nil?: true |
#rate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RateType
Whether the created commits will use the commit rate or list rate
1010 1011 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1010 required :rate_type, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit's starting_at rather than the usage invoice dates. - Daily recurring commits have a limit of one per contract, and are unable to be created with seat-based subscriptions
1099 1100 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1099 optional :recurrence_frequency, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1108 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1108 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer's usage needs to meet the condition of at least one of the specifiers to contribute to a commit's or credit's drawdown.
1116 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1116 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifier] } |
#starting_at ⇒ Time
Determines the start time for the first commit
1017 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1017 required :starting_at, Time |
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1122 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1122 optional :subscription_config, -> { MetronomeSDK::RecurringCommitSubscriptionConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1223
|
Instance Method Details
#to_hash ⇒ {
1173 |
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 1173
def to_hash: -> {
|