Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs
Overview
Defined Under Namespace
Modules: Unit
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(value:, unit: nil) ⇒ Object
constructor
The amount of time the created commits will be valid for.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:, unit: nil) ⇒ Object
The amount of time the created commits will be valid for
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1210
|
Instance Attribute Details
#unit ⇒ Symbol, ...
1207 1208 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1207 optional :unit, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration::Unit } |
#value ⇒ Float
1202 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1202 required :value, Float |
Instance Method Details
#to_hash ⇒ {
1243 |
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 1243
def to_hash: -> {
|