Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs
Defined Under Namespace
Modules: CollectionSchedule, QuantityManagementMode
Classes: BillingCycleConfig, BillingPeriods, Proration, QuantitySchedule, SeatConfig, SubscriptionRate
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:) ⇒ Object
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2056
|
Instance Attribute Details
2021
2022
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2021
optional :billing_cycle_config,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingCycleConfig }
|
Previous, current, and next billing periods for the subscription.
1964
1965
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1964
required :billing_periods,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingPeriods }
|
1970
1971
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1970
required :collection_schedule,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::CollectionSchedule }
|
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg. { "key1": "value1", "key2": "value2" }
2028
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2028
optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String]
|
#description ⇒ String?
2033
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2033
optional :description, String
|
#ending_before ⇒ Time?
2038
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2038
optional :ending_before, Time
|
#fiat_credit_type_id ⇒ String?
2043
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2043
optional :fiat_credit_type_id, String
|
#id ⇒ String?
2016
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2016
optional :id, String
|
#name ⇒ String?
2048
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2048
optional :name, String
|
1976
1977
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1976
required :proration,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::Proration }
|
Determines how the subscription's quantity is controlled. Defaults to
QUANTITY_ONLY. QUANTITY_ONLY: The subscription quantity is specified
directly on the subscription. initial_quantity must be provided with this
option. Compatible with recurring commits/credits that use POOLED allocation.
SEAT_BASED: Use when you want to pass specific seat identifiers (e.g. add
user_123) to increment and decrement a subscription quantity, rather than
directly providing the quantity. You must use a SEAT_BASED subscription to
use a linked recurring credit with an allocation per seat. seat_config must be
provided with this option.
1991
1992
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1991
required :quantity_management_mode,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantityManagementMode }
|
List of quantity schedule items for the subscription. Only includes the current
quantity and future quantity changes.
1999
2000
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1999
required :quantity_schedule,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantitySchedule] }
|
2053
2054
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2053
optional :seat_config,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SeatConfig }
|
#starting_at ⇒ Time
2005
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2005
required :starting_at, Time
|
2010
2011
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2010
required :subscription_rate,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SubscriptionRate }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2178
|
Instance Method Details
#to_hash ⇒ {
2030
|
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 2030
def to_hash: -> {
|