Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs

Defined Under Namespace

Modules: RateType Classes: AccessSchedule, InvoiceSchedule

Constant Summary collapse

MetronomeSDK =

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount: nil, quantity: nil, timestamp: nil, unit_price: nil) ⇒ Object



# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2581


Instance Attribute Details

#access_scheduleMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit::AccessSchedule?



2498
2499
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2498

optional :access_schedule,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit::AccessSchedule }

#applicable_product_idsArray<String>?

Which products the commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.



2507
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2507

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true

#applicable_product_tagsArray<String>?

Which tags the commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.



2515
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2515

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true

#descriptionString?



2520
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2520

optional :description, String

#hierarchy_configurationMetronomeSDK::Models::CommitHierarchyConfiguration?

Optional configuration for commit hierarchy access control



2526
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2526

optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration }

#idString



2493
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2493

required :id, String

#invoice_scheduleMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit::InvoiceSchedule?



2531
2532
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2531

optional :invoice_schedule,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit::InvoiceSchedule }

#nameString?



2537
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2537

optional :name, String

#netsuite_sales_order_idString?



2542
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2542

optional :netsuite_sales_order_id, String, nil?: true

#priorityFloat?

If multiple commits are applicable, the one with the lower priority will apply first.



2549
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2549

optional :priority, Float, nil?: true

#product_idString?



2554
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2554

optional :product_id, String

#rate_typeSymbol, ...

If set, the commit's rate type was updated to the specified value.



2560
2561
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2560

optional :rate_type,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateCommit::RateType }

#rollover_fractionFloat?



2566
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2566

optional :rollover_fraction, Float, nil?: true

#specifiersArray<MetronomeSDK::Models::CommitSpecifierInput>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer's usage needs to meet the condition of at least one of the specifiers to contribute to a commit's or credit's drawdown. This field cannot be used together with applicable_product_ids or applicable_product_tags. Instead, to target usage by product or product tag, pass those values in the body of specifiers.



2577
2578
2579
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2577

optional :specifiers,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] },
nil?: true

Instance Method Details

#to_hash{



2498
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 2498

def to_hash: -> {