Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdatePrepaidBalanceThresholdConfiguration

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb

Overview

Defined Under Namespace

Classes: Commit, DiscountConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(applicable_product_ids: nil, applicable_product_tags: nil, specifiers: nil) ⇒ Object

Some parameter documentations has been truncated, see Commit for more details.

Parameters:

  • applicable_product_ids (Array<String>, nil) (defaults to: nil)

    Which products the threshold commit applies to. If both applicable_product_ids a

  • applicable_product_tags (Array<String>, nil) (defaults to: nil)

    Which tags the threshold commit applies to. If both applicable_product_ids and a

  • specifiers (Array<MetronomeSDK::Models::CommitSpecifierInput>, nil) (defaults to: nil)

    List of filters that determine what kind of customer usage draws down a commit o



# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2731

Instance Attribute Details

#custom_credit_type_idString?

If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.

Returns:

  • (String, nil)


2696
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2696

optional :custom_credit_type_id, String, nil?: true

#is_enabledBoolean?

When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.

Returns:

  • (Boolean, nil)


2711
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2711

optional :is_enabled, MetronomeSDK::Internal::Type::Boolean

#payment_gate_configMetronomeSDK::Models::PaymentGateConfigV2?



2716
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2716

optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 }

#recharge_to_amountFloat?

Specify the amount the balance should be recharged to.

Returns:

  • (Float, nil)


2722
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2722

optional :recharge_to_amount, Float

#threshold_amountFloat?

Specify the threshold amount for the contract. Each time the contract’s balance lowers to this amount, a threshold charge will be initiated.

Returns:

  • (Float, nil)


2729
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2729

optional :threshold_amount, Float