Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdatePrepaidBalanceThresholdConfiguration::Commit
- Inherits:
-
UpdateBaseThresholdCommit
- Object
- Internal::Type::BaseModel
- UpdateBaseThresholdCommit
- MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdatePrepaidBalanceThresholdConfiguration::Commit
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs
Overview
Instance Attribute Summary collapse
-
#applicable_product_ids ⇒ Array<String>?
Which products the threshold commit applies to.
-
#applicable_product_tags ⇒ Array<String>?
Which tags the threshold commit applies to.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
Attributes inherited from UpdateBaseThresholdCommit
#description, #name, #priority, #product_id
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
3287 |
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 3287
def initialize: (
|
Instance Attribute Details
#applicable_product_ids ⇒ Array<String>?
Which products the threshold commit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the commit applies to all products.
3402 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3402 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#applicable_product_tags ⇒ Array<String>?
Which tags the threshold commit applies to. If both applicable_product_ids and applicable_product_tags are not provided, the commit applies to all products.
3409 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3409 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String], nil?: true |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit
or credit. A customer's usage needs to meet the condition of at least one of the
specifiers to contribute to a commit's or credit's drawdown. This field cannot
be used together with applicable_product_ids or applicable_product_tags.
Instead, to target usage by product or product tag, pass those values in the
body of specifiers.
3420 3421 3422 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3420 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
3293 |
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 3293
def to_hash: -> {
|