Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb
Overview
Defined Under Namespace
Classes: DiscountConfiguration
Instance Attribute Summary collapse
- #commit ⇒ MetronomeSDK::Models::UpdateBaseThresholdCommit?
- #discount_configuration ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration::DiscountConfiguration?
-
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount.
- #payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
-
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract.
Instance Method Summary collapse
-
#initialize(commit: nil, discount_configuration: nil, is_enabled: nil, payment_gate_config: nil, threshold_amount: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateSpendThresholdConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(commit: nil, discount_configuration: nil, is_enabled: nil, payment_gate_config: nil, threshold_amount: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3140
|
Instance Attribute Details
#commit ⇒ MetronomeSDK::Models::UpdateBaseThresholdCommit?
3111 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3111 optional :commit, -> { MetronomeSDK::UpdateBaseThresholdCommit } |
#discount_configuration ⇒ MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration::DiscountConfiguration?
3116 3117 3118 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3116 optional :discount_configuration, -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSpendThresholdConfiguration::DiscountConfiguration }, nil?: true |
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.
3126 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3126 optional :is_enabled, MetronomeSDK::Internal::Type::Boolean |
#payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
3131 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3131 optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 } |
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract. Each time the contract’s usage hits this amount, a threshold charge will be initiated.
3138 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3138 optional :threshold_amount, Float |