Class: MetronomeSDK::Models::ContractV2::Credit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::Credit
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb
Defined Under Namespace
Modules: Ledger, Type Classes: Contract, Product, RolledOverFrom
Instance Attribute Summary collapse
-
#access_schedule ⇒ MetronomeSDK::Models::ScheduleDuration?
The schedule that the customer will gain access to the credits.
- #applicable_contract_ids ⇒ Array<String>?
- #applicable_product_ids ⇒ Array<String>?
- #applicable_product_tags ⇒ Array<String>?
-
#balance ⇒ Float?
The current balance of the credit or commit.
- #contract ⇒ MetronomeSDK::Models::ContractV2::Credit::Contract?
-
#created_at ⇒ Time?
Timestamp of when the credit was created.
-
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg.
- #description ⇒ String?
-
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control.
- #id ⇒ String
-
#ledger ⇒ Array<MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSegmentStartLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditAutomatedInvoiceDeductionLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditExpirationLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCanceledLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCreditedLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditManualLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSeatBasedAdjustmentLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditRolloverLedgerEntry>?
A list of ordered events that impact the balance of a credit.
- #name ⇒ String?
-
#netsuite_sales_order_id ⇒ String?
This field’s availability is dependent on your client’s configuration.
-
#priority ⇒ Float?
If multiple credits or commits are applicable, the one with the lower priority will apply first.
- #product ⇒ MetronomeSDK::Models::ContractV2::Credit::Product
-
#recurring_credit_id ⇒ String?
The ID of the recurring credit that created this credit.
- #rolled_over_from ⇒ MetronomeSDK::Models::ContractV2::Credit::RolledOverFrom?
-
#salesforce_opportunity_id ⇒ String?
This field’s availability is dependent on your client’s configuration.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
- #type ⇒ Symbol, MetronomeSDK::Models::ContractV2::Credit::Type
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSegmentStartLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditAutomatedInvoiceDeductionLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditExpirationLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCanceledLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCreditedLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditManualLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSeatBasedAdjustmentLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditRolloverLedgerEntry)
Instance Method Summary collapse
- #initialize(id:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1749
|
Instance Attribute Details
#access_schedule ⇒ MetronomeSDK::Models::ScheduleDuration?
The schedule that the customer will gain access to the credits.
1631 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1631 optional :access_schedule, -> { MetronomeSDK::ScheduleDuration } |
#applicable_contract_ids ⇒ Array<String>?
1636 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1636 optional :applicable_contract_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_ids ⇒ Array<String>?
1641 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1641 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
1646 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1646 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#balance ⇒ Float?
The current balance of the credit or commit. This balance reflects the amount of credit or commit that the customer has access to use at this moment - thus, expired and upcoming credit or commit segments contribute 0 to the balance. The balance will match the sum of all ledger entries with the exception of the case where the sum of negative manual ledger entries exceeds the positive amount remaining on the credit or commit - in that case, the balance will be 0. All manual ledger entries associated with active credit or commit segments are included in the balance, including future-dated manual ledger entries.
1659 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1659 optional :balance, Float |
#contract ⇒ MetronomeSDK::Models::ContractV2::Credit::Contract?
1664 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1664 optional :contract, -> { MetronomeSDK::ContractV2::Credit::Contract } |
#created_at ⇒ Time?
Timestamp of when the credit was created.
-
Recurring credits: latter of credit service period date and parent credit start date
1673 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1673 optional :created_at, Time |
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg. { “key1”: “value1”, “key2”: “value2” }
1679 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1679 optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String] |
#description ⇒ String?
1684 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1684 optional :description, String |
#hierarchy_configuration ⇒ MetronomeSDK::Models::CommitHierarchyConfiguration?
Optional configuration for credit hierarchy access control
1690 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1690 optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration } |
#id ⇒ String
1615 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1615 required :id, String |
#ledger ⇒ Array<MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSegmentStartLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditAutomatedInvoiceDeductionLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditExpirationLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCanceledLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCreditedLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditManualLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSeatBasedAdjustmentLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditRolloverLedgerEntry>?
A list of ordered events that impact the balance of a credit. For example, an invoice deduction or an expiration.
1697 1698 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1697 optional :ledger, -> { MetronomeSDK::Internal::Type::ArrayOf[union: MetronomeSDK::ContractV2::Credit::Ledger] } |
#name ⇒ String?
1703 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1703 optional :name, String |
#netsuite_sales_order_id ⇒ String?
This field’s availability is dependent on your client’s configuration.
1709 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1709 optional :netsuite_sales_order_id, String |
#priority ⇒ Float?
If multiple credits or commits are applicable, the one with the lower priority will apply first.
1716 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1716 optional :priority, Float |
#product ⇒ MetronomeSDK::Models::ContractV2::Credit::Product
1620 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1620 required :product, -> { MetronomeSDK::ContractV2::Credit::Product } |
#recurring_credit_id ⇒ String?
The ID of the recurring credit that created this credit
1722 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1722 optional :recurring_credit_id, String |
#rolled_over_from ⇒ MetronomeSDK::Models::ContractV2::Credit::RolledOverFrom?
1727 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1727 optional :rolled_over_from, -> { MetronomeSDK::ContractV2::Credit::RolledOverFrom } |
#salesforce_opportunity_id ⇒ String?
This field’s availability is dependent on your client’s configuration.
1733 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1733 optional :salesforce_opportunity_id, String |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifier>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown.
1741 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1741 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifier] } |
#subscription_config ⇒ MetronomeSDK::Models::RecurringCommitSubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1747 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1747 optional :subscription_config, -> { MetronomeSDK::RecurringCommitSubscriptionConfig } |
#type ⇒ Symbol, MetronomeSDK::Models::ContractV2::Credit::Type
1625 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1625 required :type, enum: -> { MetronomeSDK::ContractV2::Credit::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1820
|
.variants ⇒ Array(MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSegmentStartLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditAutomatedInvoiceDeductionLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditExpirationLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCanceledLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditCreditedLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditManualLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditSeatBasedAdjustmentLedgerEntry, MetronomeSDK::Models::ContractV2::Credit::Ledger::CreditRolloverLedgerEntry)
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 2202
|