Class: MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Overview
Defined Under Namespace
Modules: DeliveryMethod, Provider
Instance Attribute Summary collapse
- #archived_at ⇒ Time?
-
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the revenue system.
- #customer_id ⇒ String
-
#delivery_method ⇒ Symbol, ...
The method to use for delivering data to the revenue system.
-
#delivery_method_configuration ⇒ Hash{Symbol=>Object}?
Configuration for the delivery method.
-
#delivery_method_id ⇒ String
ID of the delivery method used for this customer configuration.
-
#id ⇒ String
ID of the revenue system configuration.
-
#provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration::Provider
The revenue system provider (e.g. netsuite).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, configuration:, customer_id:, delivery_method_id:, provider:, archived_at: nil, delivery_method: nil, delivery_method_configuration: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RevenueSystemConfiguration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, configuration:, customer_id:, delivery_method_id:, provider:, archived_at: nil, delivery_method: nil, delivery_method_configuration: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3817
|
Instance Attribute Details
#archived_at ⇒ Time?
3800 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3800 optional :archived_at, Time, nil?: true |
#configuration ⇒ Hash{Symbol=>Object}
Configuration for the revenue system. The structure of this object is specific to the provider.
3777 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3777 required :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#customer_id ⇒ String
3782 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3782 required :customer_id, String |
#delivery_method ⇒ Symbol, ...
The method to use for delivering data to the revenue system.
3806 3807 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3806 optional :delivery_method, enum: -> { MetronomeSDK::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration::DeliveryMethod } |
#delivery_method_configuration ⇒ Hash{Symbol=>Object}?
Configuration for the delivery method. The structure of this object is specific to the delivery method.
3814 3815 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3814 optional :delivery_method_configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#delivery_method_id ⇒ String
ID of the delivery method used for this customer configuration.
3788 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3788 required :delivery_method_id, String |
#id ⇒ String
ID of the revenue system configuration.
3770 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3770 required :id, String |
#provider ⇒ Symbol, MetronomeSDK::Models::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration::Provider
The revenue system provider (e.g. netsuite).
3794 3795 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3794 required :provider, enum: -> { MetronomeSDK::ContractV2::RevenueSystemConfigurationSchedule::RevenueSystemConfiguration::Provider } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/contract_v2.rb', line 3846
|
Instance Method Details
#to_hash ⇒ {
3675 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 3675
def to_hash: -> {
|