Class: MetronomeSDK::Models::ContractV2::UsageFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::ContractV2::UsageFilter
- Defined in:
- lib/metronome_sdk/models/contract_v2.rb,
sig/metronome_sdk/models/contract_v2.rbs
Instance Attribute Summary collapse
-
#ending_before ⇒ Time?
This will match contract ending_before value if usage filter is active until the end of the contract.
- #group_key ⇒ String
- #group_values ⇒ Array<String>
-
#starting_at ⇒ Time
This will match contract starting_at value if usage filter is active from the beginning of the contract.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1655 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 1655
def initialize: (
|
Instance Attribute Details
#ending_before ⇒ Time?
This will match contract ending_before value if usage filter is active until the end of the contract. It will be undefined if the contract is open-ended.
1635 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1635 optional :ending_before, Time |
#group_key ⇒ String
1616 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1616 required :group_key, String |
#group_values ⇒ Array<String>
1621 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1621 required :group_values, MetronomeSDK::Internal::Type::ArrayOf[String] |
#starting_at ⇒ Time
This will match contract starting_at value if usage filter is active from the beginning of the contract.
1628 |
# File 'lib/metronome_sdk/models/contract_v2.rb', line 1628 required :starting_at, Time |
Instance Method Details
#to_hash ⇒ {
1662 |
# File 'sig/metronome_sdk/models/contract_v2.rbs', line 1662
def to_hash: -> {
|