Class: MetronomeSDK::Models::PrepaidBalanceThresholdConfiguration::Commit

Inherits:
BaseThresholdCommit show all
Defined in:
lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb

Overview

See Also:

Instance Attribute Summary collapse

Attributes inherited from BaseThresholdCommit

#description, #name, #priority, #product_id

Method Summary

Methods inherited from BaseThresholdCommit

#initialize

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from MetronomeSDK::Models::BaseThresholdCommit

Instance Attribute Details

#applicable_product_idsArray<String>?

Which products the threshold commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.

Returns:

  • (Array<String>, nil)


76
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 76

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#applicable_product_tagsArray<String>?

Which tags the threshold commit applies to. If applicable_product_ids, applicable_product_tags or specifiers are not provided, the commit applies to all products.

Returns:

  • (Array<String>, nil)


84
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 84

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#specifiersArray<MetronomeSDK::Models::CommitSpecifierInput>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown. This field cannot be used together with ‘applicable_product_ids` or `applicable_product_tags`.



93
# File 'lib/metronome_sdk/models/prepaid_balance_threshold_configuration.rb', line 93

optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] }