Class: MetronomeSDK::Models::SpendThresholdConfigurationV2::DiscountConfiguration::Cap
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::SpendThresholdConfigurationV2::DiscountConfiguration::Cap
- Defined in:
- lib/metronome_sdk/models/spend_threshold_configuration_v2.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
Accumulated spend ceiling above which the discount stops applying.
-
#spend_tracker_alias ⇒ String
Alias of the spend tracker this cap is measured against.
Instance Method Summary collapse
-
#initialize(amount:, spend_tracker_alias:) ⇒ Object
constructor
If provided, the discount stops applying once the spend tracker has accumulated this much spend in the billing period.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, spend_tracker_alias:) ⇒ Object
If provided, the discount stops applying once the spend tracker has accumulated this much spend in the billing period.
|
|
# File 'lib/metronome_sdk/models/spend_threshold_configuration_v2.rb', line 91
|
Instance Attribute Details
#amount ⇒ Float
Accumulated spend ceiling above which the discount stops applying.
83 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration_v2.rb', line 83 required :amount, Float |
#spend_tracker_alias ⇒ String
Alias of the spend tracker this cap is measured against.
89 |
# File 'lib/metronome_sdk/models/spend_threshold_configuration_v2.rb', line 89 required :spend_tracker_alias, String |