Class: MetronomeSDK::Models::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_amend_params.rb

Overview

Defined Under Namespace

Modules: AmountDistribution, Frequency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule for more details.

Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.

Parameters:



# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1034

Instance Attribute Details

#amountFloat?

Amount for the charge. Can be provided instead of unit_price and quantity. If amount is sent, the unit_price is assumed to be the amount and quantity is inferred to be 1.

Returns:

  • (Float, nil)


1016
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1016

optional :amount, Float

#amount_distributionSymbol, MetronomeSDK::Models::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule::AmountDistribution



989
990
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 989

required :amount_distribution,
enum: -> { MetronomeSDK::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule::AmountDistribution }

#ending_beforeTime

RFC 3339 timestamp (exclusive).

Returns:

  • (Time)


996
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 996

required :ending_before, Time

#frequencySymbol, MetronomeSDK::Models::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule::Frequency



1001
1002
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1001

required :frequency,
enum: -> { MetronomeSDK::V1::ContractAmendParams::Discount::Schedule::RecurringSchedule::Frequency }

#quantityFloat?

Quantity for the charge. Will be multiplied by unit_price to determine the amount and must be specified with unit_price. If specified amount cannot be provided.

Returns:

  • (Float, nil)


1024
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1024

optional :quantity, Float

#starting_atTime

RFC 3339 timestamp (inclusive).

Returns:

  • (Time)


1008
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1008

required :starting_at, Time

#unit_priceFloat?

Unit price for the charge. Will be multiplied by quantity to determine the amount and must be specified with quantity. If specified amount cannot be provided.

Returns:

  • (Float, nil)


1032
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1032

optional :unit_price, Float

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1065