Class: MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier
- Defined in:
- lib/metronome_sdk/models/v1/contract_amend_params.rb,
sig/metronome_sdk/models/v1/contract_amend_params.rbs
Defined Under Namespace
Modules: BillingFrequency
Instance Attribute Summary collapse
-
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
- #billing_frequency ⇒ Symbol, ...
-
#commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
-
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values.
-
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values.
-
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
-
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
-
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
Instance Method Summary collapse
-
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OverrideSpecifier for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier for more details.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1104 class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel # @!attribute any_commit_or_credit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. Must be used instead of both `commit_ids` and # `recurring_commit_ids` If provided, the override will apply to any specified # commit, credit, recurring commit or recurring credit IDs. # # @return [Array<String>, nil] optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute billing_frequency # # @return [Symbol, MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency, nil] optional :billing_frequency, enum: -> { MetronomeSDK::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency } # @!attribute commit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. If provided, the override will only apply to the # specified commits. If not provided, the override will apply to all commits. # # @return [Array<String>, nil] optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute presentation_group_values # A map of group names to values. The override will only apply to line items with # the specified presentation group values. # # @return [Hash{Symbol=>String}, nil] optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute pricing_group_values # A map of pricing group names to values. The override will only apply to products # with the specified pricing group values. # # @return [Hash{Symbol=>String}, nil] optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute product_id # If provided, the override will only apply to the product with the specified ID. # # @return [String, nil] optional :product_id, String # @!attribute product_tags # If provided, the override will only apply to products with all the specified # tags. # # @return [Array<String>, nil] optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute recurring_commit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. If provided, the override will only apply to # commits created by the specified recurring commit ids. # # @return [Array<String>, nil] optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!method initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) # Some parameter documentations has been truncated, see # {MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier} for # more details. # # @param any_commit_or_credit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # # @param billing_frequency [Symbol, MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency] # # @param commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # # @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with # # @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products # # @param product_id [String] If provided, the override will only apply to the product with the specified ID. # # @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag # # @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # @see MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier#billing_frequency module BillingFrequency extend MetronomeSDK::Internal::Type::Enum MONTHLY = :MONTHLY QUARTERLY = :QUARTERLY ANNUAL = :ANNUAL WEEKLY = :WEEKLY # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. Must be used instead of both commit_ids and
recurring_commit_ids If provided, the override will apply to any specified
commit, credit, recurring commit or recurring credit IDs.
1113 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1113 optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#billing_frequency ⇒ Symbol, ...
1118 1119 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1118 optional :billing_frequency, enum: -> { MetronomeSDK::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency } |
#commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. If provided, the override will only apply to the
specified commits. If not provided, the override will apply to all commits.
1128 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1128 optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values. The override will only apply to line items with the specified presentation group values.
1135 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1135 optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values. The override will only apply to products with the specified pricing group values.
1142 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1142 optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
1148 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1148 optional :product_id, String |
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
1155 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1155 optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. If provided, the override will only apply to
commits created by the specified recurring commit ids.
1164 |
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1164 optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
1050 |
# File 'sig/metronome_sdk/models/v1/contract_amend_params.rbs', line 1050
def to_hash: -> {
|