Class: MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_amend_params.rb

Defined Under Namespace

Modules: BillingFrequency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier for more details.

Parameters:

  • billing_frequency (Symbol, MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency) (defaults to: nil)
  • commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with

  • presentation_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of group names to values. The override will only apply to line items with

  • pricing_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of pricing group names to values. The override will only apply to products

  • product_id (String) (defaults to: nil)

    If provided, the override will only apply to the product with the specified ID.

  • product_tags (Array<String>) (defaults to: nil)

    If provided, the override will only apply to products with all the specified tag

  • recurring_commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with



1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1075

class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel
  # @!attribute billing_frequency
  #
  #   @return [Symbol, MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency, nil]
  optional :billing_frequency,
           enum: -> { MetronomeSDK::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency }

  # @!attribute commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to the
  #   specified commits. If not provided, the override will apply to all commits.
  #
  #   @return [Array<String>, nil]
  optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute presentation_group_values
  #   A map of group names to values. The override will only apply to line items with
  #   the specified presentation group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute pricing_group_values
  #   A map of pricing group names to values. The override will only apply to products
  #   with the specified pricing group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute product_id
  #   If provided, the override will only apply to the product with the specified ID.
  #
  #   @return [String, nil]
  optional :product_id, String

  # @!attribute product_tags
  #   If provided, the override will only apply to products with all the specified
  #   tags.
  #
  #   @return [Array<String>, nil]
  optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute recurring_commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to
  #   commits created by the specified recurring commit ids.
  #
  #   @return [Array<String>, nil]
  optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!method initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil)
  #   Some parameter documentations has been truncated, see
  #   {MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier} for
  #   more details.
  #
  #   @param billing_frequency [Symbol, MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency]
  #
  #   @param commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with
  #
  #   @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with
  #
  #   @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products
  #
  #   @param product_id [String] If provided, the override will only apply to the product with the specified ID.
  #
  #   @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag
  #
  #   @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with

  # @see MetronomeSDK::Models::V1::ContractAmendParams::Override::OverrideSpecifier#billing_frequency
  module BillingFrequency
    extend MetronomeSDK::Internal::Type::Enum

    MONTHLY = :MONTHLY
    QUARTERLY = :QUARTERLY
    ANNUAL = :ANNUAL
    WEEKLY = :WEEKLY

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#billing_frequencySymbol, ...



1079
1080
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1079

optional :billing_frequency,
enum: -> { MetronomeSDK::V1::ContractAmendParams::Override::OverrideSpecifier::BillingFrequency }

#commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to the specified commits. If not provided, the override will apply to all commits.

Returns:

  • (Array<String>, nil)


1089
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1089

optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#presentation_group_valuesHash{Symbol=>String}?

A map of group names to values. The override will only apply to line items with the specified presentation group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1096
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1096

optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#pricing_group_valuesHash{Symbol=>String}?

A map of pricing group names to values. The override will only apply to products with the specified pricing group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1103
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1103

optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#product_idString?

If provided, the override will only apply to the product with the specified ID.

Returns:

  • (String, nil)


1109
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1109

optional :product_id, String

#product_tagsArray<String>?

If provided, the override will only apply to products with all the specified tags.

Returns:

  • (Array<String>, nil)


1116
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1116

optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#recurring_commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to commits created by the specified recurring commit ids.

Returns:

  • (Array<String>, nil)


1125
# File 'lib/metronome_sdk/models/v1/contract_amend_params.rb', line 1125

optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]