Class: MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier
- Defined in:
- lib/metronome_sdk/models/v1/contract_create_params.rb,
sig/metronome_sdk/models/v1/contract_create_params.rbs
Defined Under Namespace
Modules: BillingFrequency
Instance Attribute Summary collapse
-
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
- #billing_frequency ⇒ Symbol, ...
-
#commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
-
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values.
-
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values.
-
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
-
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
-
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
Instance Method Summary collapse
-
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OverrideSpecifier for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier for more details.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1519 class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel # @!attribute any_commit_or_credit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. Must be used instead of both `commit_ids` and # `recurring_commit_ids` If provided, the override will apply to any specified # commit, credit, recurring commit or recurring credit IDs. # # @return [Array<String>, nil] optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute billing_frequency # # @return [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency, nil] optional :billing_frequency, enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency } # @!attribute commit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. If provided, the override will only apply to the # specified commits. If not provided, the override will apply to all commits. # # @return [Array<String>, nil] optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute presentation_group_values # A map of group names to values. The override will only apply to line items with # the specified presentation group values. # # @return [Hash{Symbol=>String}, nil] optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute pricing_group_values # A map of pricing group names to values. The override will only apply to products # with the specified pricing group values. # # @return [Hash{Symbol=>String}, nil] optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute product_id # If provided, the override will only apply to the product with the specified ID. # # @return [String, nil] optional :product_id, String # @!attribute product_tags # If provided, the override will only apply to products with all the specified # tags. # # @return [Array<String>, nil] optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute recurring_commit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. If provided, the override will only apply to # commits created by the specified recurring commit ids. # # @return [Array<String>, nil] optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!method initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) # Some parameter documentations has been truncated, see # {MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier} # for more details. # # @param any_commit_or_credit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # # @param billing_frequency [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency] # # @param commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # # @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with # # @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products # # @param product_id [String] If provided, the override will only apply to the product with the specified ID. # # @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag # # @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # @see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier#billing_frequency module BillingFrequency extend MetronomeSDK::Internal::Type::Enum MONTHLY = :MONTHLY QUARTERLY = :QUARTERLY ANNUAL = :ANNUAL WEEKLY = :WEEKLY # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. Must be used instead of both commit_ids and
recurring_commit_ids If provided, the override will apply to any specified
commit, credit, recurring commit or recurring credit IDs.
1528 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1528 optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#billing_frequency ⇒ Symbol, ...
1533 1534 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1533 optional :billing_frequency, enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency } |
#commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. If provided, the override will only apply to the
specified commits. If not provided, the override will apply to all commits.
1543 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1543 optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values. The override will only apply to line items with the specified presentation group values.
1550 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1550 optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values. The override will only apply to products with the specified pricing group values.
1557 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1557 optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
1563 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1563 optional :product_id, String |
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
1570 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1570 optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. If provided, the override will only apply to
commits created by the specified recurring commit ids.
1579 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1579 optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
1422 |
# File 'sig/metronome_sdk/models/v1/contract_create_params.rbs', line 1422
def to_hash: -> {
|