Class: MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb

Defined Under Namespace

Modules: BillingFrequency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier for more details.

Parameters:

  • billing_frequency (Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency) (defaults to: nil)
  • commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with

  • presentation_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of group names to values. The override will only apply to line items with

  • pricing_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of pricing group names to values. The override will only apply to products

  • product_id (String) (defaults to: nil)

    If provided, the override will only apply to the product with the specified ID.

  • product_tags (Array<String>) (defaults to: nil)

    If provided, the override will only apply to products with all the specified tag

  • recurring_commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with



1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1480

class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel
  # @!attribute billing_frequency
  #
  #   @return [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency, nil]
  optional :billing_frequency,
           enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency }

  # @!attribute commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to the
  #   specified commits. If not provided, the override will apply to all commits.
  #
  #   @return [Array<String>, nil]
  optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute presentation_group_values
  #   A map of group names to values. The override will only apply to line items with
  #   the specified presentation group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute pricing_group_values
  #   A map of pricing group names to values. The override will only apply to products
  #   with the specified pricing group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute product_id
  #   If provided, the override will only apply to the product with the specified ID.
  #
  #   @return [String, nil]
  optional :product_id, String

  # @!attribute product_tags
  #   If provided, the override will only apply to products with all the specified
  #   tags.
  #
  #   @return [Array<String>, nil]
  optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute recurring_commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to
  #   commits created by the specified recurring commit ids.
  #
  #   @return [Array<String>, nil]
  optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!method initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil)
  #   Some parameter documentations has been truncated, see
  #   {MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier}
  #   for more details.
  #
  #   @param billing_frequency [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency]
  #
  #   @param commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with
  #
  #   @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with
  #
  #   @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products
  #
  #   @param product_id [String] If provided, the override will only apply to the product with the specified ID.
  #
  #   @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag
  #
  #   @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with

  # @see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier#billing_frequency
  module BillingFrequency
    extend MetronomeSDK::Internal::Type::Enum

    MONTHLY = :MONTHLY
    QUARTERLY = :QUARTERLY
    ANNUAL = :ANNUAL
    WEEKLY = :WEEKLY

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#billing_frequencySymbol, ...



1484
1485
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1484

optional :billing_frequency,
enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency }

#commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to the specified commits. If not provided, the override will apply to all commits.

Returns:

  • (Array<String>, nil)


1494
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1494

optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#presentation_group_valuesHash{Symbol=>String}?

A map of group names to values. The override will only apply to line items with the specified presentation group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1501
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1501

optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#pricing_group_valuesHash{Symbol=>String}?

A map of pricing group names to values. The override will only apply to products with the specified pricing group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1508
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1508

optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#product_idString?

If provided, the override will only apply to the product with the specified ID.

Returns:

  • (String, nil)


1514
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1514

optional :product_id, String

#product_tagsArray<String>?

If provided, the override will only apply to products with all the specified tags.

Returns:

  • (Array<String>, nil)


1521
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1521

optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#recurring_commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to commits created by the specified recurring commit ids.

Returns:

  • (Array<String>, nil)


1530
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1530

optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]