Class: MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v1/contract_create_params.rb

Defined Under Namespace

Modules: BillingFrequency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier for more details.

Parameters:

  • billing_frequency (Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency) (defaults to: nil)
  • commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with

  • presentation_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of group names to values. The override will only apply to line items with

  • pricing_group_values (Hash{Symbol=>String}) (defaults to: nil)

    A map of pricing group names to values. The override will only apply to products

  • product_id (String) (defaults to: nil)

    If provided, the override will only apply to the product with the specified ID.

  • product_tags (Array<String>) (defaults to: nil)

    If provided, the override will only apply to products with all the specified tag

  • recurring_commit_ids (Array<String>) (defaults to: nil)

    Can only be used for commit specific overrides. Must be used in conjunction with



1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1657

class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel
  # @!attribute billing_frequency
  #
  #   @return [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency, nil]
  optional :billing_frequency,
           enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency }

  # @!attribute commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to the
  #   specified commits. If not provided, the override will apply to all commits.
  #
  #   @return [Array<String>, nil]
  optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute presentation_group_values
  #   A map of group names to values. The override will only apply to line items with
  #   the specified presentation group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute pricing_group_values
  #   A map of pricing group names to values. The override will only apply to products
  #   with the specified pricing group values.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

  # @!attribute product_id
  #   If provided, the override will only apply to the product with the specified ID.
  #
  #   @return [String, nil]
  optional :product_id, String

  # @!attribute product_tags
  #   If provided, the override will only apply to products with all the specified
  #   tags.
  #
  #   @return [Array<String>, nil]
  optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!attribute recurring_commit_ids
  #   Can only be used for commit specific overrides. Must be used in conjunction with
  #   one of `product_id`, `product_tags`, `pricing_group_values`, or
  #   `presentation_group_values`. If provided, the override will only apply to
  #   commits created by the specified recurring commit ids.
  #
  #   @return [Array<String>, nil]
  optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

  # @!method initialize(billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil)
  #   Some parameter documentations has been truncated, see
  #   {MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier}
  #   for more details.
  #
  #   @param billing_frequency [Symbol, MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency]
  #
  #   @param commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with
  #
  #   @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with
  #
  #   @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products
  #
  #   @param product_id [String] If provided, the override will only apply to the product with the specified ID.
  #
  #   @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag
  #
  #   @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with

  # @see MetronomeSDK::Models::V1::ContractCreateParams::Override::OverrideSpecifier#billing_frequency
  module BillingFrequency
    extend MetronomeSDK::Internal::Type::Enum

    MONTHLY = :MONTHLY
    QUARTERLY = :QUARTERLY
    ANNUAL = :ANNUAL
    WEEKLY = :WEEKLY

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#billing_frequencySymbol, ...



1661
1662
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1661

optional :billing_frequency,
enum: -> { MetronomeSDK::V1::ContractCreateParams::Override::OverrideSpecifier::BillingFrequency }

#commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to the specified commits. If not provided, the override will apply to all commits.

Returns:

  • (Array<String>, nil)


1671
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1671

optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#presentation_group_valuesHash{Symbol=>String}?

A map of group names to values. The override will only apply to line items with the specified presentation group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1678
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1678

optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#pricing_group_valuesHash{Symbol=>String}?

A map of pricing group names to values. The override will only apply to products with the specified pricing group values.

Returns:

  • (Hash{Symbol=>String}, nil)


1685
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1685

optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String]

#product_idString?

If provided, the override will only apply to the product with the specified ID.

Returns:

  • (String, nil)


1691
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1691

optional :product_id, String

#product_tagsArray<String>?

If provided, the override will only apply to products with all the specified tags.

Returns:

  • (Array<String>, nil)


1698
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1698

optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#recurring_commit_idsArray<String>?

Can only be used for commit specific overrides. Must be used in conjunction with one of ‘product_id`, `product_tags`, `pricing_group_values`, or `presentation_group_values`. If provided, the override will only apply to commits created by the specified recurring commit ids.

Returns:

  • (Array<String>, nil)


1707
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 1707

optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String]