Class: MetronomeSDK::Models::V1::ContractCreateParams::RevenueSystemConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractCreateParams::RevenueSystemConfiguration
- Defined in:
- lib/metronome_sdk/models/v1/contract_create_params.rb
Defined Under Namespace
Modules: DeliveryMethod, Provider
Instance Attribute Summary collapse
-
#delivery_method ⇒ Symbol, ...
How revenue recognition records should be delivered to the revenue system.
-
#provider ⇒ Symbol, ...
The system that is providing services for revenue recognition.
-
#revenue_system_configuration_id ⇒ String?
The Metronome ID of the revenue system configuration.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(delivery_method: nil, provider: nil, revenue_system_configuration_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RevenueSystemConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delivery_method: nil, provider: nil, revenue_system_configuration_id: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractCreateParams::RevenueSystemConfiguration for more details.
The revenue system configuration associated with a contract. Provide either an ID or the provider and delivery method.
|
|
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 2815
|
Instance Attribute Details
#delivery_method ⇒ Symbol, ...
How revenue recognition records should be delivered to the revenue system. Do not specify if using revenue_system_configuration_id.
2796 2797 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 2796 optional :delivery_method, enum: -> { MetronomeSDK::V1::ContractCreateParams::RevenueSystemConfiguration::DeliveryMethod } |
#provider ⇒ Symbol, ...
The system that is providing services for revenue recognition. Do not specify if using revenue_system_configuration_id.
2804 2805 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 2804 optional :provider, enum: -> { MetronomeSDK::V1::ContractCreateParams::RevenueSystemConfiguration::Provider } |
#revenue_system_configuration_id ⇒ String?
The Metronome ID of the revenue system configuration. Use when a customer has multiple configurations with the same provider and delivery method. Otherwise, specify the provider and delivery_method.
2813 |
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 2813 optional :revenue_system_configuration_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/contract_create_params.rb', line 2838
|