Class: MetronomeSDK::Models::V1::ContractGetSubscriptionSeatsHistoryResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractGetSubscriptionSeatsHistoryResponse::Data
- Defined in:
- lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb,
sig/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rbs
Instance Attribute Summary collapse
-
#assigned_seat_ids ⇒ Array<String>
Array of seat IDs that are assigned in this period.
-
#ending_before ⇒ Time?
The end time of this seat schedule period (null if ongoing).
-
#starting_at ⇒ Time
The start time of this seat schedule period.
-
#total_quantity ⇒ Integer
Total number of assigned and unassigned seats in this period.
Instance Method Summary collapse
- #initialize(assigned_seat_ids:, ending_before:, starting_at:, total_quantity:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assigned_seat_ids:, ending_before:, starting_at:, total_quantity:) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb', line 25 class Data < MetronomeSDK::Internal::Type::BaseModel # @!attribute assigned_seat_ids # Array of seat IDs that are assigned in this period # # @return [Array<String>] required :assigned_seat_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute ending_before # The end time of this seat schedule period (null if ongoing) # # @return [Time, nil] required :ending_before, Time, nil?: true # @!attribute starting_at # The start time of this seat schedule period # # @return [Time] required :starting_at, Time # @!attribute total_quantity # Total number of assigned and unassigned seats in this period # # @return [Integer] required :total_quantity, Integer # @!method initialize(assigned_seat_ids:, ending_before:, starting_at:, total_quantity:) # @param assigned_seat_ids [Array<String>] Array of seat IDs that are assigned in this period # # @param ending_before [Time, nil] The end time of this seat schedule period (null if ongoing) # # @param starting_at [Time] The start time of this seat schedule period # # @param total_quantity [Integer] Total number of assigned and unassigned seats in this period end |
Instance Attribute Details
#assigned_seat_ids ⇒ Array<String>
Array of seat IDs that are assigned in this period
30 |
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb', line 30 required :assigned_seat_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#ending_before ⇒ Time?
The end time of this seat schedule period (null if ongoing)
36 |
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb', line 36 required :ending_before, Time, nil?: true |
#starting_at ⇒ Time
The start time of this seat schedule period
42 |
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb', line 42 required :starting_at, Time |
#total_quantity ⇒ Integer
Total number of assigned and unassigned seats in this period
48 |
# File 'lib/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rb', line 48 required :total_quantity, Integer |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/metronome_sdk/models/v1/contract_get_subscription_seats_history_response.rbs', line 49
def to_hash: -> {
|