Class: MetronomeSDK::Models::V1::ContractListSeatBalancesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::ContractListSeatBalancesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb
Overview
Instance Attribute Summary collapse
-
#contract_id ⇒ String
The contract ID to retrieve seat balances for.
-
#covering_date ⇒ Time?
Include only commits or credits with access that cover this specific date (cannot be used with starting_at or ending_before).
-
#cursor ⇒ String?
Page token from a previous response to retrieve the next page.
-
#customer_id ⇒ String
The customer ID to retrieve seat balances for.
-
#effective_before ⇒ Time?
Include only commits or credits with access effective on or before this date (cannot be used with covering_date).
-
#include_credits_and_commits ⇒ Boolean?
Include credits and commits in the response.
-
#include_ledgers ⇒ Boolean?
Include ledger entries for each commit and commit.
-
#limit ⇒ Integer?
Maximum number of seats to return.
-
#seat_ids ⇒ Array<String>?
Optional filter to only include specific seats.
-
#starting_at ⇒ Time?
Include only commits or credits with access effective on or after this date (cannot be used with covering_date).
-
#subscription_ids ⇒ Array<String>?
Optional filter to only include seats from specific subscriptions.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(contract_id:, customer_id:, covering_date: nil, cursor: nil, effective_before: nil, include_credits_and_commits: nil, include_ledgers: nil, limit: nil, seat_ids: nil, starting_at: nil, subscription_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContractListSeatBalancesParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contract_id:, customer_id:, covering_date: nil, cursor: nil, effective_before: nil, include_credits_and_commits: nil, include_ledgers: nil, limit: nil, seat_ids: nil, starting_at: nil, subscription_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::ContractListSeatBalancesParams for more details.
|
|
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 89
|
Instance Attribute Details
#contract_id ⇒ String
The contract ID to retrieve seat balances for
15 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 15 required :contract_id, String |
#covering_date ⇒ Time?
Include only commits or credits with access that cover this specific date (cannot be used with starting_at or ending_before).
28 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 28 optional :covering_date, Time |
#cursor ⇒ String?
Page token from a previous response to retrieve the next page
34 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 34 optional :cursor, String |
#customer_id ⇒ String
The customer ID to retrieve seat balances for
21 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 21 required :customer_id, String |
#effective_before ⇒ Time?
Include only commits or credits with access effective on or before this date (cannot be used with covering_date).
41 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 41 optional :effective_before, Time |
#include_credits_and_commits ⇒ Boolean?
Include credits and commits in the response
47 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 47 optional :include_credits_and_commits, MetronomeSDK::Internal::Type::Boolean |
#include_ledgers ⇒ Boolean?
Include ledger entries for each commit and commit. ‘include_credits_and_commits` must be set to `true` for `include_ledgers=true` to apply.
54 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 54 optional :include_ledgers, MetronomeSDK::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of seats to return. Range: 1-100. Default: 25. When ‘include_credits_and_commits = true`, if the total commits/credits across all seats exceeds 100, a limit of 100 applies to the total credits and commits. Seats are included greedily to maximize the number of seats returned. Example: if seat 1 has 98 commits and seat 2 has 10 commits, both seats will be returned (total: 108 commits). Each returned seat includes all of its associated credits and commits.
66 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 66 optional :limit, Integer |
#seat_ids ⇒ Array<String>?
Optional filter to only include specific seats.
72 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 72 optional :seat_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#starting_at ⇒ Time?
Include only commits or credits with access effective on or after this date (cannot be used with covering_date).
79 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 79 optional :starting_at, Time |
#subscription_ids ⇒ Array<String>?
Optional filter to only include seats from specific subscriptions. If subscriptions ids are not mapped to SEAT_BASED subscriptions, error will be returned.
87 |
# File 'lib/metronome_sdk/models/v1/contract_list_seat_balances_params.rb', line 87 optional :subscription_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |