Class: MetronomeSDK::Models::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration
- Defined in:
- lib/metronome_sdk/models/v1/customer_create_params.rb
Defined Under Namespace
Modules: DeliveryMethod, Provider
Instance Attribute Summary collapse
-
#configuration ⇒ Hash{Symbol=>Object}?
Configuration for the revenue system provider.
-
#delivery_method ⇒ Symbol, ...
The method to use for delivering invoices to this customer.
-
#delivery_method_id ⇒ String?
ID of the delivery method to use for this customer.
-
#provider ⇒ Symbol, MetronomeSDK::Models::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration::Provider
The revenue system provider set for this configuration.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(provider:, configuration: nil, delivery_method: nil, delivery_method_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerRevenueSystemConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(provider:, configuration: nil, delivery_method: nil, delivery_method_id: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration for more details.
|
|
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 347
|
Instance Attribute Details
#configuration ⇒ Hash{Symbol=>Object}?
Configuration for the revenue system provider. The structure of this object is specific to the revenue system provider. For NetSuite, this should contain ‘netsuite_customer_id`.
330 |
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 330 optional :configuration, MetronomeSDK::Internal::Type::HashOf[MetronomeSDK::Internal::Type::Unknown] |
#delivery_method ⇒ Symbol, ...
The method to use for delivering invoices to this customer. If not provided, the ‘delivery_method_id` must be provided.
337 338 |
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 337 optional :delivery_method, enum: -> { MetronomeSDK::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration::DeliveryMethod } |
#delivery_method_id ⇒ String?
ID of the delivery method to use for this customer. If not provided, the ‘delivery_method` must be provided.
345 |
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 345 optional :delivery_method_id, String |
#provider ⇒ Symbol, MetronomeSDK::Models::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration::Provider
The revenue system provider set for this configuration.
321 322 |
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 321 required :provider, enum: -> { MetronomeSDK::V1::CustomerCreateParams::CustomerRevenueSystemConfiguration::Provider } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/customer_create_params.rb', line 368
|