Class: MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit
- Defined in:
- lib/metronome_sdk/models/v1/package_create_params.rb
Defined Under Namespace
Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Duration, StartingAtOffset, SubscriptionConfig
Instance Attribute Summary collapse
-
#access_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::AccessAmount
The amount of commit to grant.
-
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits.
-
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits.
-
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::CommitDuration
Defines the length of the access schedule for each created commit/credit.
-
#description ⇒ String?
Will be passed down to the individual commits.
-
#duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits.
-
#name ⇒ String?
displayed on invoices.
-
#priority ⇒ Float
Will be passed down to the individual commits.
- #product_id ⇒ String
-
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated.
-
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate.
-
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created.
-
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits.
-
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit.
-
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit.
-
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
-
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id:, unit_price:, quantity: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccessAmount for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id:, unit_price:, quantity: nil) ⇒ Object
Some parameter documentations has been truncated, see AccessAmount for more details.
The amount of commit to grant.
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1842
|
Instance Attribute Details
#access_amount ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::AccessAmount
The amount of commit to grant.
1727 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1727 required :access_amount, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::AccessAmount } |
#applicable_product_ids ⇒ Array<String>?
Will be passed down to the individual commits
1760 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1760 optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#applicable_product_tags ⇒ Array<String>?
Will be passed down to the individual commits
1766 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1766 optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#commit_duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::CommitDuration
Defines the length of the access schedule for each created commit/credit. The value represents the number of units. Unit defaults to “PERIODS”, where the length of a period is determined by the recurrence_frequency.
1735 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1735 required :commit_duration, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::CommitDuration } |
#description ⇒ String?
Will be passed down to the individual commits
1772 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1772 optional :description, String |
#duration ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::Duration?
Offset relative to the recurring credit start that determines when the contract will stop creating recurring commits. optional
1779 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1779 optional :duration, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::Duration } |
#name ⇒ String?
displayed on invoices. will be passed through to the individual commits
1785 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1785 optional :name, String |
#priority ⇒ Float
Will be passed down to the individual commits
1741 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1741 required :priority, Float |
#product_id ⇒ String
1746 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1746 required :product_id, String |
#proration ⇒ Symbol, ...
Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).
1792 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1792 optional :proration, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::Proration } |
#rate_type ⇒ Symbol, ...
Whether the created commits will use the commit rate or list rate
1798 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1798 optional :rate_type, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::RateType } |
#recurrence_frequency ⇒ Symbol, ...
The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit’s starting_at rather than the usage invoice dates.
1808 1809 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1808 optional :recurrence_frequency, enum: -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::RecurrenceFrequency } |
#rollover_fraction ⇒ Float?
Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.
1817 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1817 optional :rollover_fraction, Float |
#specifiers ⇒ Array<MetronomeSDK::Models::CommitSpecifierInput>?
List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown. This field cannot be used together with ‘applicable_product_ids` or `applicable_product_tags`.
1826 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1826 optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifierInput] } |
#starting_at_offset ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::StartingAtOffset
Offset relative to the contract start date that determines the start time for the first commit
1753 1754 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1753 required :starting_at_offset, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::StartingAtOffset } |
#subscription_config ⇒ MetronomeSDK::Models::V1::PackageCreateParams::RecurringCredit::SubscriptionConfig?
Attach a subscription to the recurring commit/credit.
1832 1833 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1832 optional :subscription_config, -> { MetronomeSDK::V1::PackageCreateParams::RecurringCredit::SubscriptionConfig } |
#temporary_id ⇒ String?
A temporary ID that can be used to reference the recurring commit for commit specific overrides.
1840 |
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1840 optional :temporary_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 1940
|