Class: MetronomeSDK::Models::V1::PackageCreateParams::UsageStatementSchedule::InvoiceGenerationStartingAtOffset

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v1/package_create_params.rb

Overview

Defined Under Namespace

Modules: Unit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(unit:, value:) ⇒ Object

The offset at which Metronome should start generating usage invoices, relative to the contract start date. If unspecified, contract start date will be used. This is useful to set if you want to import historical invoices via our ‘Create Historical Invoices’ API rather than having Metronome automatically generate them.



# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2659

Instance Attribute Details

#unitSymbol, MetronomeSDK::Models::V1::PackageCreateParams::UsageStatementSchedule::InvoiceGenerationStartingAtOffset::Unit



2651
2652
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2651

required :unit,
enum: -> { MetronomeSDK::V1::PackageCreateParams::UsageStatementSchedule::InvoiceGenerationStartingAtOffset::Unit }

#valueInteger

Returns:

  • (Integer)


2657
# File 'lib/metronome_sdk/models/v1/package_create_params.rb', line 2657

required :value, Integer