Class: MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Overview
Defined Under Namespace
Modules: PaymentGateType, TaxType Classes: PrecalculatedTaxConfig, StripeConfig
Instance Attribute Summary collapse
-
#payment_gate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::PaymentGateType
Gate access to the commit balance based on successful collection of payment.
-
#precalculated_tax_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::PrecalculatedTaxConfig?
Only applicable if using PRECALCULATED as your tax type.
-
#stripe_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig?
Only applicable if using STRIPE as your payment gateway type.
-
#tax_type ⇒ Symbol, ...
Stripe tax is only supported for Stripe payment gateway.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(tax_amount:, tax_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PrecalculatedTaxConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tax_amount:, tax_name: nil) ⇒ Object
Some parameter documentations has been truncated, see PrecalculatedTaxConfig for more details.
Only applicable if using PRECALCULATED as your tax type.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 898
|
Instance Attribute Details
#payment_gate_type ⇒ Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::PaymentGateType
Gate access to the commit balance based on successful collection of payment. Select STRIPE for Metronome to facilitate payment via Stripe. Select EXTERNAL to facilitate payment using your own payment integration. Select NONE if you do not wish to payment gate the commit balance.
872 873 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 872 required :payment_gate_type, enum: -> { MetronomeSDK::V2::ContractEditParams::AddCommit::PaymentGateConfig::PaymentGateType } |
#precalculated_tax_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::PrecalculatedTaxConfig?
Only applicable if using PRECALCULATED as your tax type.
879 880 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 879 optional :precalculated_tax_config, -> { MetronomeSDK::V2::ContractEditParams::AddCommit::PaymentGateConfig::PrecalculatedTaxConfig } |
#stripe_config ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig?
Only applicable if using STRIPE as your payment gateway type.
886 887 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 886 optional :stripe_config, -> { MetronomeSDK::V2::ContractEditParams::AddCommit::PaymentGateConfig::StripeConfig } |
#tax_type ⇒ Symbol, ...
Stripe tax is only supported for Stripe payment gateway. Select NONE if you do not wish Metronome to calculate tax on your behalf. Leaving this field blank will default to NONE.
895 896 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 895 optional :tax_type, enum: -> { MetronomeSDK::V2::ContractEditParams::AddCommit::PaymentGateConfig::TaxType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 926
|
Instance Method Details
#to_hash ⇒ {
848 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 848
def to_hash: -> {
|