Class: MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Defined Under Namespace
Modules: BillingFrequency
Instance Attribute Summary collapse
-
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
- #billing_frequency ⇒ Symbol, ...
-
#commit_ids ⇒ Array<String>?
If provided, the override will only apply to the specified commits.
-
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values.
-
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values.
-
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
-
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
-
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides.
Instance Method Summary collapse
-
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OverrideSpecifier for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier for more details.
1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1588 class OverrideSpecifier < MetronomeSDK::Internal::Type::BaseModel # @!attribute any_commit_or_credit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of `product_id`, `product_tags`, `pricing_group_values`, or # `presentation_group_values`. Must be used instead of both `commit_ids` and # `recurring_commit_ids` If provided, the override will apply to any specified # commit, credit, recurring commit or recurring credit IDs. # # @return [Array<String>, nil] optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute billing_frequency # # @return [Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier::BillingFrequency, nil] optional :billing_frequency, enum: -> { MetronomeSDK::V2::ContractEditParams::AddOverride::OverrideSpecifier::BillingFrequency } # @!attribute commit_ids # If provided, the override will only apply to the specified commits. Can only be # used for commit specific overrides. If not provided, the override will apply to # all commits. # # @return [Array<String>, nil] optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute presentation_group_values # A map of group names to values. The override will only apply to line items with # the specified presentation group values. Can only be used for multiplier # overrides. # # @return [Hash{Symbol=>String}, nil] optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute pricing_group_values # A map of pricing group names to values. The override will only apply to products # with the specified pricing group values. # # @return [Hash{Symbol=>String}, nil] optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] # @!attribute product_id # If provided, the override will only apply to the product with the specified ID. # # @return [String, nil] optional :product_id, String # @!attribute product_tags # If provided, the override will only apply to products with all the specified # tags. # # @return [Array<String>, nil] optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] # @!attribute recurring_commit_ids # Can only be used for commit specific overrides. Must be used in conjunction with # one of product_id, product_tags, pricing_group_values, or # presentation_group_values. If provided, the override will only apply to commits # created by the specified recurring commit ids. # # @return [Array<String>, nil] optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] # @!method initialize(any_commit_or_credit_ids: nil, billing_frequency: nil, commit_ids: nil, presentation_group_values: nil, pricing_group_values: nil, product_id: nil, product_tags: nil, recurring_commit_ids: nil) # Some parameter documentations has been truncated, see # {MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier} # for more details. # # @param any_commit_or_credit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # # @param billing_frequency [Symbol, MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier::BillingFrequency] # # @param commit_ids [Array<String>] If provided, the override will only apply to the specified commits. Can only be # # @param presentation_group_values [Hash{Symbol=>String}] A map of group names to values. The override will only apply to line items with # # @param pricing_group_values [Hash{Symbol=>String}] A map of pricing group names to values. The override will only apply to products # # @param product_id [String] If provided, the override will only apply to the product with the specified ID. # # @param product_tags [Array<String>] If provided, the override will only apply to products with all the specified tag # # @param recurring_commit_ids [Array<String>] Can only be used for commit specific overrides. Must be used in conjunction with # @see MetronomeSDK::Models::V2::ContractEditParams::AddOverride::OverrideSpecifier#billing_frequency module BillingFrequency extend MetronomeSDK::Internal::Type::Enum MONTHLY = :MONTHLY QUARTERLY = :QUARTERLY ANNUAL = :ANNUAL WEEKLY = :WEEKLY # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#any_commit_or_credit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with
one of product_id, product_tags, pricing_group_values, or
presentation_group_values. Must be used instead of both commit_ids and
recurring_commit_ids If provided, the override will apply to any specified
commit, credit, recurring commit or recurring credit IDs.
1597 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1597 optional :any_commit_or_credit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#billing_frequency ⇒ Symbol, ...
1602 1603 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1602 optional :billing_frequency, enum: -> { MetronomeSDK::V2::ContractEditParams::AddOverride::OverrideSpecifier::BillingFrequency } |
#commit_ids ⇒ Array<String>?
If provided, the override will only apply to the specified commits. Can only be used for commit specific overrides. If not provided, the override will apply to all commits.
1611 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1611 optional :commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
#presentation_group_values ⇒ Hash{Symbol=>String}?
A map of group names to values. The override will only apply to line items with the specified presentation group values. Can only be used for multiplier overrides.
1619 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1619 optional :presentation_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#pricing_group_values ⇒ Hash{Symbol=>String}?
A map of pricing group names to values. The override will only apply to products with the specified pricing group values.
1626 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1626 optional :pricing_group_values, MetronomeSDK::Internal::Type::HashOf[String] |
#product_id ⇒ String?
If provided, the override will only apply to the product with the specified ID.
1632 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1632 optional :product_id, String |
#product_tags ⇒ Array<String>?
If provided, the override will only apply to products with all the specified tags.
1639 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1639 optional :product_tags, MetronomeSDK::Internal::Type::ArrayOf[String] |
#recurring_commit_ids ⇒ Array<String>?
Can only be used for commit specific overrides. Must be used in conjunction with one of product_id, product_tags, pricing_group_values, or presentation_group_values. If provided, the override will only apply to commits created by the specified recurring commit ids.
1648 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 1648 optional :recurring_commit_ids, MetronomeSDK::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
1502 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 1502
def to_hash: -> {
|