Class: MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb
Defined Under Namespace
Classes: RevenueSystemConfiguration, Schedule
Instance Attribute Summary collapse
- #revenue_system_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::RevenueSystemConfiguration
- #schedule ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::Schedule
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(revenue_system_configuration:, schedule:) ⇒ Object
constructor
Update the revenue system configuration on the contract.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(revenue_system_configuration:, schedule:) ⇒ Object
Update the revenue system configuration on the contract. Currently only supports adding a revenue system configuration to a contract that does not already have one.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2694
|
Instance Attribute Details
#revenue_system_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::RevenueSystemConfiguration
2685 2686 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2685 required :revenue_system_configuration, -> { MetronomeSDK::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::RevenueSystemConfiguration } |
#schedule ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::Schedule
2691 2692 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2691 required :schedule, -> { MetronomeSDK::V2::ContractEditParams::AddRevenueSystemConfigurationUpdate::Schedule } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2750
|