Class: MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb
Overview
Defined Under Namespace
Classes: RecurringSchedule, ScheduleItem
Instance Attribute Summary collapse
-
#credit_type_id ⇒ String?
Defaults to USD (cents) if not passed.
-
#do_not_invoice ⇒ Boolean?
This field is only applicable to commit invoice schedules.
-
#recurring_schedule ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule?
Enter the unit price and quantity for the charge or instead only send the amount.
-
#schedule_items ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::ScheduleItem>?
Either provide amount or provide both unit_price and quantity.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(credit_type_id: nil, do_not_invoice: nil, recurring_schedule: nil, schedule_items: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Schedule for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_type_id: nil, do_not_invoice: nil, recurring_schedule: nil, schedule_items: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule for more details.
Must provide either schedule_items or recurring_schedule.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2853
|
Instance Attribute Details
#credit_type_id ⇒ String?
Defaults to USD (cents) if not passed.
2828 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2828 optional :credit_type_id, String |
#do_not_invoice ⇒ Boolean?
This field is only applicable to commit invoice schedules. If true, this schedule will not generate an invoice.
2835 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2835 optional :do_not_invoice, MetronomeSDK::Internal::Type::Boolean |
#recurring_schedule ⇒ MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule?
Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.
2843 2844 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2843 optional :recurring_schedule, -> { MetronomeSDK::V2::ContractEditParams::AddScheduledCharge::Schedule::RecurringSchedule } |
#schedule_items ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::AddScheduledCharge::Schedule::ScheduleItem>?
Either provide amount or provide both unit_price and quantity.
2850 2851 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2850 optional :schedule_items, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::AddScheduledCharge::Schedule::ScheduleItem] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 2963
|