Class: MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb
Defined Under Namespace
Classes: Commit, DiscountConfiguration, ThresholdBalanceSpecifier
Instance Attribute Summary collapse
- #commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
-
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
- #discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
-
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount.
- #payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
-
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
-
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract.
- #threshold_balance_specifiers ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier>?
Instance Method Summary collapse
-
#initialize(amount:, spend_tracker_alias:) ⇒ Object
constructor
Update the discount cap.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, spend_tracker_alias:) ⇒ Object
Update the discount cap. Set to null to remove an existing cap.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4043
|
Instance Attribute Details
#commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
3987 3988 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3987 optional :commit, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit } |
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
3995 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3995 optional :custom_credit_type_id, String, nil?: true |
#discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
4000 4001 4002 4003 4004 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4000 optional :discount_configuration, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration }, nil?: true |
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.
4012 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4012 optional :is_enabled, MetronomeSDK::Internal::Type::Boolean |
#payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
4017 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4017 optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 } |
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
4023 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4023 optional :recharge_to_amount, Float |
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract. Each time the contract’s balance lowers to this amount, a threshold charge will be initiated.
4030 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4030 optional :threshold_amount, Float |
#threshold_balance_specifiers ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier>?
4035 4036 4037 4038 4039 4040 4041 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 4035 optional :threshold_balance_specifiers, -> do MetronomeSDK::Internal::Type::ArrayOf[ MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::ThresholdBalanceSpecifier ] end, nil?: true |