Class: MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb
Defined Under Namespace
Classes: Commit, DiscountConfiguration
Instance Attribute Summary collapse
- #commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
-
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
- #discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
-
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount.
- #payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
-
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
-
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract.
Instance Method Summary collapse
-
#initialize(applicable_product_ids: nil, applicable_product_tags: nil, specifiers: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Commit for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(applicable_product_ids: nil, applicable_product_tags: nil, specifiers: nil) ⇒ Object
Some parameter documentations has been truncated, see Commit for more details.
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3880
|
Instance Attribute Details
#commit ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit?
3835 3836 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3835 optional :commit, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::Commit } |
#custom_credit_type_id ⇒ String?
If provided, the threshold, recharge-to amount, and the resulting threshold commit amount will be in terms of this credit type instead of the fiat currency.
3843 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3843 optional :custom_credit_type_id, String, nil?: true |
#discount_configuration ⇒ MetronomeSDK::Models::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration?
3848 3849 3850 3851 3852 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3848 optional :discount_configuration, -> { MetronomeSDK::V2::ContractEditParams::UpdatePrepaidBalanceThresholdConfiguration::DiscountConfiguration }, nil?: true |
#is_enabled ⇒ Boolean?
When set to false, the contract will not be evaluated against the threshold_amount. Toggling to true will result an immediate evaluation, regardless of prior state.
3860 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3860 optional :is_enabled, MetronomeSDK::Internal::Type::Boolean |
#payment_gate_config ⇒ MetronomeSDK::Models::PaymentGateConfigV2?
3865 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3865 optional :payment_gate_config, -> { MetronomeSDK::PaymentGateConfigV2 } |
#recharge_to_amount ⇒ Float?
Specify the amount the balance should be recharged to.
3871 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3871 optional :recharge_to_amount, Float |
#threshold_amount ⇒ Float?
Specify the threshold amount for the contract. Each time the contract’s balance lowers to this amount, a threshold charge will be initiated.
3878 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 3878 optional :threshold_amount, Float |