Class: MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_params.rb,
sig/metronome_sdk/models/v2/contract_edit_params.rbs
Overview
Defined Under Namespace
Classes: AddSeatID, AddUnassignedSeat, RemoveSeatID, RemoveUnassignedSeat
Instance Attribute Summary collapse
-
#add_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddSeatID>?
Adds seat IDs to the subscription.
-
#add_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?
Adds unassigned seats to the subscription.
-
#remove_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveSeatID>?
Removes seat IDs from the subscription, if possible.
-
#remove_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?
Removes unassigned seats from the subscription.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(seat_ids:, starting_at:) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5307
|
Instance Attribute Details
#add_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddSeatID>?
Adds seat IDs to the subscription. If there are unassigned seats, the new seat IDs will fill these unassigned seats and not increase the total subscription quantity. Otherwise, if there are more new seat IDs than unassigned seats, the total subscription quantity will increase.
5254 5255 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5254 optional :add_seat_ids, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddSeatID] } |
#add_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?
Adds unassigned seats to the subscription. This will increase the total subscription quantity.
5262 5263 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5262 optional :add_unassigned_seats, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription::SeatUpdates::AddUnassignedSeat] } |
#remove_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveSeatID>?
Removes seat IDs from the subscription, if possible. If a seat ID is removed, the total subscription quantity will decrease. Otherwise, if the seat ID is not found on the subscription, this is a no-op.
5271 5272 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5271 optional :remove_seat_ids, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveSeatID] } |
#remove_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?
Removes unassigned seats from the subscription. This will decrease the total subscription quantity if there are are unassigned seats.
5279 5280 |
# File 'lib/metronome_sdk/models/v2/contract_edit_params.rb', line 5279 optional :remove_unassigned_seats, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::V2::ContractEditParams::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat] } |
Instance Method Details
#to_hash ⇒ {
4951 |
# File 'sig/metronome_sdk/models/v2/contract_edit_params.rbs', line 4951
def to_hash: -> {
|