Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates
- Defined in:
- lib/metronome_sdk/models/v2/contract_edit_response.rb,
sig/metronome_sdk/models/v2/contract_edit_response.rbs
Overview
Defined Under Namespace
Classes: AddSeatID, AddUnassignedSeat, RemoveSeatID, RemoveUnassignedSeat
Instance Attribute Summary collapse
-
#add_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddSeatID>?
Adds seat IDs to the subscription.
-
#add_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?
Adds unassigned seats to the subscription.
-
#remove_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveSeatID>?
Removes seat IDs from the subscription, if possible.
-
#remove_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?
Removes unassigned seats from the subscription.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(seat_ids:, starting_at:) ⇒ Object
|
|
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4251
|
Instance Attribute Details
#add_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddSeatID>?
Adds seat IDs to the subscription. If there are unassigned seats, the new seat IDs will fill these unassigned seats and not increase the total subscription quantity. Otherwise, if there are more new seat IDs than unassigned seats, the total subscription quantity will increase.
4188 4189 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4188 optional :add_seat_ids, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddSeatID] } |
#add_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?
Adds unassigned seats to the subscription. This will increase the total subscription quantity.
4196 4197 4198 4199 4200 4201 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4196 optional :add_unassigned_seats, -> do MetronomeSDK::Internal::Type::ArrayOf[ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat ] end |
#remove_seat_ids ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveSeatID>?
Removes seat IDs from the subscription, if possible. If a seat ID is removed, the total subscription quantity will decrease. Otherwise, if the seat ID is not found on the subscription, this is a no-op.
4209 4210 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4209 optional :remove_seat_ids, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveSeatID] } |
#remove_unassigned_seats ⇒ Array<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?
Removes unassigned seats from the subscription. This will decrease the total subscription quantity if there are are unassigned seats.
4217 4218 4219 4220 4221 4222 |
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 4217 optional :remove_unassigned_seats, -> do MetronomeSDK::Internal::Type::ArrayOf[ MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat ] end |
Instance Method Details
#to_hash ⇒ {
4149 |
# File 'sig/metronome_sdk/models/v2/contract_edit_response.rbs', line 4149
def to_hash: -> {
|