Class: MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v2/contract_edit_response.rb

Overview

See Also:

Defined Under Namespace

Classes: AddSeatID, AddUnassignedSeat, RemoveSeatID, RemoveUnassignedSeat

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(seat_ids:, starting_at:) ⇒ Object

Parameters:

  • seat_ids (Array<String>)
  • starting_at (Time)

    Assigned seats will be added/removed starting at this date.



# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3799

Instance Attribute Details

#add_seat_idsArray<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddSeatID>?

Adds seat IDs to the subscription. If there are unassigned seats, the new seat IDs will fill these unassigned seats and not increase the total subscription quantity. Otherwise, if there are more new seat IDs than unassigned seats, the total subscription quantity will increase.



3736
3737
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3736

optional :add_seat_ids,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddSeatID] }

#add_unassigned_seatsArray<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?

Adds unassigned seats to the subscription. This will increase the total subscription quantity.



3744
3745
3746
3747
3748
3749
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3744

optional :add_unassigned_seats,
-> do
  MetronomeSDK::Internal::Type::ArrayOf[
    MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::AddUnassignedSeat
  ]
end

#remove_seat_idsArray<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveSeatID>?

Removes seat IDs from the subscription, if possible. If a seat ID is removed, the total subscription quantity will decrease. Otherwise, if the seat ID is not found on the subscription, this is a no-op.



3757
3758
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3757

optional :remove_seat_ids,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveSeatID] }

#remove_unassigned_seatsArray<MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?

Removes unassigned seats from the subscription. This will decrease the total subscription quantity if there are are unassigned seats.



3765
3766
3767
3768
3769
3770
# File 'lib/metronome_sdk/models/v2/contract_edit_response.rb', line 3765

optional :remove_unassigned_seats,
-> do
  MetronomeSDK::Internal::Type::ArrayOf[
    MetronomeSDK::Models::V2::ContractEditResponse::Data::Edit::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat
  ]
end