Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb

Defined Under Namespace

Modules: Proration, RateType, RecurrenceFrequency Classes: AccessAmount, CommitDuration, Contract, InvoiceAmount, Product

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_type_id:, quantity:, unit_price:) ⇒ Object

The amount the customer should be billed for the commit. Not required.

Parameters:

  • credit_type_id (String)
  • quantity (Float)
  • unit_price (Float)


# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1109

Instance Attribute Details

#access_amountMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::AccessAmount

The amount of commit to grant.



978
979
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 978

required :access_amount,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::AccessAmount }

#applicable_product_idsArray<String>?

Will be passed down to the individual commits

Returns:

  • (Array<String>, nil)


1017
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1017

optional :applicable_product_ids, MetronomeSDK::Internal::Type::ArrayOf[String]

#applicable_product_tagsArray<String>?

Will be passed down to the individual commits

Returns:

  • (Array<String>, nil)


1023
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1023

optional :applicable_product_tags, MetronomeSDK::Internal::Type::ArrayOf[String]

#commit_durationMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration

The amount of time the created commits will be valid for



985
986
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 985

required :commit_duration,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::CommitDuration }

#descriptionString?

Will be passed down to the individual commits

Returns:

  • (String, nil)


1035
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1035

optional :description, String

#ending_beforeTime?

Determines when the contract will stop creating recurring commits. Optional

Returns:

  • (Time, nil)


1041
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1041

optional :ending_before, Time

#hierarchy_configurationMetronomeSDK::Models::CommitHierarchyConfiguration?

Optional configuration for recurring credit hierarchy access control



1047
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1047

optional :hierarchy_configuration, -> { MetronomeSDK::CommitHierarchyConfiguration }

#idString

Returns:

  • (String)


972
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 972

required :id, String

#invoice_amountMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::InvoiceAmount?

The amount the customer should be billed for the commit. Not required.



1053
1054
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1053

optional :invoice_amount,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::InvoiceAmount }

#nameString?

Displayed on invoices. Will be passed through to the individual commits

Returns:

  • (String, nil)


1060
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1060

optional :name, String

#netsuite_sales_order_idString?

Will be passed down to the individual commits

Returns:

  • (String, nil)


1066
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1066

optional :netsuite_sales_order_id, String

#priorityFloat

Will be passed down to the individual commits

Returns:

  • (Float)


992
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 992

required :priority, Float

#prorationSymbol, ...

Determines whether the first and last commit will be prorated. If not provided, the default is FIRST_AND_LAST (i.e. prorate both the first and last commits).



1073
1074
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1073

optional :proration,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::Proration }

#rate_typeSymbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RateType

Whether the created commits will use the commit rate or list rate



1004
1005
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1004

required :rate_type,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RateType }

#recurrence_frequencySymbol, ...

The frequency at which the recurring commits will be created. If not provided: - The commits will be created on the usage invoice frequency. If provided: - The period defined in the duration will correspond to this frequency. - Commits will be created aligned with the recurring commit’s starting_at rather than the usage invoice dates.



1084
1085
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1084

optional :recurrence_frequency,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddRecurringCommit::RecurrenceFrequency }

#rollover_fractionFloat?

Will be passed down to the individual commits. This controls how much of an individual unexpired commit will roll over upon contract transition. Must be between 0 and 1.

Returns:

  • (Float, nil)


1093
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1093

optional :rollover_fraction, Float

#specifiersArray<MetronomeSDK::Models::CommitSpecifier>?

List of filters that determine what kind of customer usage draws down a commit or credit. A customer’s usage needs to meet the condition of at least one of the specifiers to contribute to a commit’s or credit’s drawdown.

Returns:



1101
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1101

optional :specifiers, -> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::CommitSpecifier] }

#starting_atTime

Determines the start time for the first commit

Returns:

  • (Time)


1011
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1011

required :starting_at, Time

#subscription_configMetronomeSDK::Models::RecurringCommitSubscriptionConfig?

Attach a subscription to the recurring commit/credit.



1107
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1107

optional :subscription_config, -> { MetronomeSDK::RecurringCommitSubscriptionConfig }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1206