Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb,
sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs
Defined Under Namespace
Modules: CollectionSchedule, QuantityManagementMode
Classes: BillingCycleConfig, BillingPeriods, Proration, QuantitySchedule, SeatConfig, SubscriptionRate
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:) ⇒ Object
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2052
|
Instance Attribute Details
2017
2018
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2017
optional :billing_cycle_config,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingCycleConfig }
|
Previous, current, and next billing periods for the subscription.
1960
1961
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1960
required :billing_periods,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingPeriods }
|
1966
1967
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1966
required :collection_schedule,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::CollectionSchedule }
|
#custom_fields ⇒ Hash{Symbol=>String}?
Custom fields to be added eg. { "key1": "value1", "key2": "value2" }
2024
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2024
optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String]
|
#description ⇒ String?
2029
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2029
optional :description, String
|
#ending_before ⇒ Time?
2034
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2034
optional :ending_before, Time
|
#fiat_credit_type_id ⇒ String?
2039
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2039
optional :fiat_credit_type_id, String
|
#id ⇒ String?
2012
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2012
optional :id, String
|
#name ⇒ String?
2044
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2044
optional :name, String
|
1972
1973
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1972
required :proration,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::Proration }
|
Determines how the subscription's quantity is controlled. Defaults to
QUANTITY_ONLY. QUANTITY_ONLY: The subscription quantity is specified
directly on the subscription. initial_quantity must be provided with this
option. Compatible with recurring commits/credits that use POOLED allocation.
SEAT_BASED: Use when you want to pass specific seat identifiers (e.g. add
user_123) to increment and decrement a subscription quantity, rather than
directly providing the quantity. You must use a SEAT_BASED subscription to
use a linked recurring credit with an allocation per seat. seat_config must be
provided with this option.
1987
1988
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1987
required :quantity_management_mode,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantityManagementMode }
|
List of quantity schedule items for the subscription. Only includes the current
quantity and future quantity changes.
1995
1996
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1995
required :quantity_schedule,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantitySchedule] }
|
2049
2050
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2049
optional :seat_config,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SeatConfig }
|
#starting_at ⇒ Time
2001
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2001
required :starting_at, Time
|
2006
2007
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2006
required :subscription_rate,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SubscriptionRate }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2174
|
Instance Method Details
#to_hash ⇒ {
2030
|
# File 'sig/metronome_sdk/models/v2/contract_get_edit_history_response.rbs', line 2030
def to_hash: -> {
|