Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb

Defined Under Namespace

Modules: CollectionSchedule, QuantityManagementMode Classes: BillingPeriods, Proration, QuantitySchedule, SeatConfig, SubscriptionRate

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, name:) ⇒ Object

Parameters:

  • id (String)
  • name (String)


# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1869

Instance Attribute Details

#billing_periodsMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingPeriods

Previous, current, and next billing periods for the subscription.



1783
1784
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1783

required :billing_periods,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::BillingPeriods }

#collection_scheduleSymbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::CollectionSchedule



1789
1790
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1789

required :collection_schedule,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::CollectionSchedule }

#custom_fieldsHash{Symbol=>String}?

Custom fields to be added eg. { “key1”: “value1”, “key2”: “value2” }

Returns:

  • (Hash{Symbol=>String}, nil)


1841
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1841

optional :custom_fields, MetronomeSDK::Internal::Type::HashOf[String]

#descriptionString?

Returns:

  • (String, nil)


1846
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1846

optional :description, String

#ending_beforeTime?

Returns:

  • (Time, nil)


1851
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1851

optional :ending_before, Time

#fiat_credit_type_idString?

Returns:

  • (String, nil)


1856
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1856

optional :fiat_credit_type_id, String

#idString?

Returns:

  • (String, nil)


1835
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1835

optional :id, String

#nameString?

Returns:

  • (String, nil)


1861
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1861

optional :name, String

#quantity_management_modeSymbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantityManagementMode

Determines how the subscription’s quantity is controlled. Defaults to QUANTITY_ONLY. QUANTITY_ONLY: The subscription quantity is specified directly on the subscription. ‘initial_quantity` must be provided with this option. Compatible with recurring commits/credits that use POOLED allocation. SEAT_BASED: Use when you want to pass specific seat identifiers (e.g. add user_123) to increment and decrement a subscription quantity, rather than directly providing the quantity. You must use a SEAT_BASED subscription to use a linked recurring credit with an allocation per seat. `seat_config` must be provided with this option.



1810
1811
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1810

required :quantity_management_mode,
enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantityManagementMode }

#quantity_scheduleArray<MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantitySchedule>

List of quantity schedule items for the subscription. Only includes the current quantity and future quantity changes.



1818
1819
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1818

required :quantity_schedule,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::QuantitySchedule] }

#seat_configMetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SeatConfig?



1866
1867
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1866

optional :seat_config,
-> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::AddSubscription::SeatConfig }

#starting_atTime

Returns:

  • (Time)


1824
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1824

required :starting_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 1989