Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule
- Defined in:
- lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb
Overview
Defined Under Namespace
Modules: AmountDistribution, Frequency
Instance Attribute Summary collapse
-
#amount ⇒ Float?
Amount for the charge.
- #amount_distribution ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::AmountDistribution
-
#ending_before ⇒ Time
RFC 3339 timestamp (exclusive).
- #frequency ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::Frequency
-
#quantity ⇒ Float?
Quantity for the charge.
-
#starting_at ⇒ Time
RFC 3339 timestamp (inclusive).
-
#unit_price ⇒ Float?
Unit price for the charge.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RecurringSchedule for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount_distribution:, ending_before:, frequency:, starting_at:, amount: nil, quantity: nil, unit_price: nil) ⇒ Object
Some parameter documentations has been truncated, see MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule for more details.
Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2586
|
Instance Attribute Details
#amount ⇒ Float?
Amount for the charge. Can be provided instead of unit_price and quantity. If amount is sent, the unit_price is assumed to be the amount and quantity is inferred to be 1.
2568 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2568 optional :amount, Float |
#amount_distribution ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::AmountDistribution
2541 2542 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2541 required :amount_distribution, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::AmountDistribution } |
#ending_before ⇒ Time
RFC 3339 timestamp (exclusive).
2548 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2548 required :ending_before, Time |
#frequency ⇒ Symbol, MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::Frequency
2553 2554 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2553 required :frequency, enum: -> { MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateDiscount::Schedule::RecurringSchedule::Frequency } |
#quantity ⇒ Float?
Quantity for the charge. Will be multiplied by unit_price to determine the amount and must be specified with unit_price. If specified amount cannot be provided.
2576 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2576 optional :quantity, Float |
#starting_at ⇒ Time
RFC 3339 timestamp (inclusive).
2560 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2560 required :starting_at, Time |
#unit_price ⇒ Float?
Unit price for the charge. Will be multiplied by quantity to determine the amount and must be specified with quantity. If specified amount cannot be provided.
2584 |
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2584 optional :unit_price, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 2617
|