Class: MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb

Overview

See Also:

Defined Under Namespace

Classes: AddSeatID, AddUnassignedSeat, RemoveSeatID, RemoveUnassignedSeat

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(seat_ids:, starting_at:) ⇒ Object

Parameters:

  • seat_ids (Array<String>)
  • starting_at (Time)

    Assigned seats will be added/removed starting at this date.



# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3305

Instance Attribute Details

#add_seat_idsArray<MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::AddSeatID>?

Adds seat IDs to the subscription. If there are unassigned seats, the new seat IDs will fill these unassigned seats and not increase the total subscription quantity. Otherwise, if there are more new seat IDs than unassigned seats, the total subscription quantity will increase.



3238
3239
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3238

optional :add_seat_ids,
-> { MetronomeSDK::Internal::Type::ArrayOf[MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::AddSeatID] }

#add_unassigned_seatsArray<MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::AddUnassignedSeat>?

Adds unassigned seats to the subscription. This will increase the total subscription quantity.



3246
3247
3248
3249
3250
3251
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3246

optional :add_unassigned_seats,
-> do
  MetronomeSDK::Internal::Type::ArrayOf[
    MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::AddUnassignedSeat
  ]
end

#remove_seat_idsArray<MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::RemoveSeatID>?

Removes seat IDs from the subscription, if possible. If a seat ID is removed, the total subscription quantity will decrease. Otherwise, if the seat ID is not found on the subscription, this is a no-op.



3259
3260
3261
3262
3263
3264
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3259

optional :remove_seat_ids,
-> do
  MetronomeSDK::Internal::Type::ArrayOf[
    MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::RemoveSeatID
  ]
end

#remove_unassigned_seatsArray<MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat>?

Removes unassigned seats from the subscription. This will decrease the total subscription quantity if there are are unassigned seats.



3271
3272
3273
3274
3275
3276
# File 'lib/metronome_sdk/models/v2/contract_get_edit_history_response.rb', line 3271

optional :remove_unassigned_seats,
-> do
  MetronomeSDK::Internal::Type::ArrayOf[
    MetronomeSDK::Models::V2::ContractGetEditHistoryResponse::Data::UpdateSubscription::SeatUpdates::RemoveUnassignedSeat
  ]
end